"""This module contains the general information for ChangeChangedObjectRef ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ChangeChangedObjectRefConsts:
    CHANGED_MO_CLASS_ID_AAA_AUTH_METHOD = "aaaAuthMethod"
    CHANGED_MO_CLASS_ID_AAA_AUTH_REALM = "aaaAuthRealm"
    CHANGED_MO_CLASS_ID_AAA_AUTH_REALM_FSM = "aaaAuthRealmFsm"
    CHANGED_MO_CLASS_ID_AAA_AUTH_REALM_FSM_STAGE = "aaaAuthRealmFsmStage"
    CHANGED_MO_CLASS_ID_AAA_BANNER = "aaaBanner"
    CHANGED_MO_CLASS_ID_AAA_CIMC_SESSION = "aaaCimcSession"
    CHANGED_MO_CLASS_ID_AAA_CONFIG = "aaaConfig"
    CHANGED_MO_CLASS_ID_AAA_CONSOLE_AUTH = "aaaConsoleAuth"
    CHANGED_MO_CLASS_ID_AAA_DEFAULT_AUTH = "aaaDefaultAuth"
    CHANGED_MO_CLASS_ID_AAA_DEFINITION = "aaaDefinition"
    CHANGED_MO_CLASS_ID_AAA_DOMAIN = "aaaDomain"
    CHANGED_MO_CLASS_ID_AAA_DOMAIN_AUTH = "aaaDomainAuth"
    CHANGED_MO_CLASS_ID_AAA_EP = "aaaEp"
    CHANGED_MO_CLASS_ID_AAA_EP_AUTH_PROFILE = "aaaEpAuthProfile"
    CHANGED_MO_CLASS_ID_AAA_EP_FSM = "aaaEpFsm"
    CHANGED_MO_CLASS_ID_AAA_EP_FSM_STAGE = "aaaEpFsmStage"
    CHANGED_MO_CLASS_ID_AAA_EP_FSM_TASK = "aaaEpFsmTask"
    CHANGED_MO_CLASS_ID_AAA_EP_LOGIN = "aaaEpLogin"
    CHANGED_MO_CLASS_ID_AAA_EP_USER = "aaaEpUser"
    CHANGED_MO_CLASS_ID_AAA_EXT_MGMT_CUT_THRU_TKN = "aaaExtMgmtCutThruTkn"
    CHANGED_MO_CLASS_ID_AAA_ITEM = "aaaItem"
    CHANGED_MO_CLASS_ID_AAA_LDAP_EP = "aaaLdapEp"
    CHANGED_MO_CLASS_ID_AAA_LDAP_EP_FSM = "aaaLdapEpFsm"
    CHANGED_MO_CLASS_ID_AAA_LDAP_EP_FSM_STAGE = "aaaLdapEpFsmStage"
    CHANGED_MO_CLASS_ID_AAA_LDAP_GROUP = "aaaLdapGroup"
    CHANGED_MO_CLASS_ID_AAA_LDAP_GROUP_RULE = "aaaLdapGroupRule"
    CHANGED_MO_CLASS_ID_AAA_LDAP_PROVIDER = "aaaLdapProvider"
    CHANGED_MO_CLASS_ID_AAA_LOCAL_MGMT_CMD_LOG = "aaaLocalMgmtCmdLog"
    CHANGED_MO_CLASS_ID_AAA_LOCALE = "aaaLocale"
    CHANGED_MO_CLASS_ID_AAA_LOG = "aaaLog"
    CHANGED_MO_CLASS_ID_AAA_LOGIN_PROFILE = "aaaLoginProfile"
    CHANGED_MO_CLASS_ID_AAA_MOD_LR = "aaaModLR"
    CHANGED_MO_CLASS_ID_AAA_ORG = "aaaOrg"
    CHANGED_MO_CLASS_ID_AAA_PRE_LOGIN_BANNER = "aaaPreLoginBanner"
    CHANGED_MO_CLASS_ID_AAA_PROVIDER = "aaaProvider"
    CHANGED_MO_CLASS_ID_AAA_PROVIDER_GROUP = "aaaProviderGroup"
    CHANGED_MO_CLASS_ID_AAA_PROVIDER_REF = "aaaProviderRef"
    CHANGED_MO_CLASS_ID_AAA_PWD_PROFILE = "aaaPwdProfile"
    CHANGED_MO_CLASS_ID_AAA_RADIUS_EP = "aaaRadiusEp"
    CHANGED_MO_CLASS_ID_AAA_RADIUS_EP_FSM = "aaaRadiusEpFsm"
    CHANGED_MO_CLASS_ID_AAA_RADIUS_EP_FSM_STAGE = "aaaRadiusEpFsmStage"
    CHANGED_MO_CLASS_ID_AAA_RADIUS_PROVIDER = "aaaRadiusProvider"
    CHANGED_MO_CLASS_ID_AAA_REALM = "aaaRealm"
    CHANGED_MO_CLASS_ID_AAA_REALM_FSM = "aaaRealmFsm"
    CHANGED_MO_CLASS_ID_AAA_REALM_FSM_STAGE = "aaaRealmFsmStage"
    CHANGED_MO_CLASS_ID_AAA_REALM_FSM_TASK = "aaaRealmFsmTask"
    CHANGED_MO_CLASS_ID_AAA_REMOTE_USER = "aaaRemoteUser"
    CHANGED_MO_CLASS_ID_AAA_ROLE = "aaaRole"
    CHANGED_MO_CLASS_ID_AAA_SESSION = "aaaSession"
    CHANGED_MO_CLASS_ID_AAA_SESSION_INFO = "aaaSessionInfo"
    CHANGED_MO_CLASS_ID_AAA_SESSION_INFO_TABLE = "aaaSessionInfoTable"
    CHANGED_MO_CLASS_ID_AAA_SESSION_LR = "aaaSessionLR"
    CHANGED_MO_CLASS_ID_AAA_SHELL_LOGIN = "aaaShellLogin"
    CHANGED_MO_CLASS_ID_AAA_SSH_AUTH = "aaaSshAuth"
    CHANGED_MO_CLASS_ID_AAA_SYSTEM_USER = "aaaSystemUser"
    CHANGED_MO_CLASS_ID_AAA_TACACS_PLUS_EP = "aaaTacacsPlusEp"
    CHANGED_MO_CLASS_ID_AAA_TACACS_PLUS_EP_FSM = "aaaTacacsPlusEpFsm"
    CHANGED_MO_CLASS_ID_AAA_TACACS_PLUS_EP_FSM_STAGE = "aaaTacacsPlusEpFsmStage"
    CHANGED_MO_CLASS_ID_AAA_TACACS_PLUS_PROVIDER = "aaaTacacsPlusProvider"
    CHANGED_MO_CLASS_ID_AAA_USER = "aaaUser"
    CHANGED_MO_CLASS_ID_AAA_USER_ACTION = "aaaUserAction"
    CHANGED_MO_CLASS_ID_AAA_USER_DATA = "aaaUserData"
    CHANGED_MO_CLASS_ID_AAA_USER_EP = "aaaUserEp"
    CHANGED_MO_CLASS_ID_AAA_USER_EP_FSM = "aaaUserEpFsm"
    CHANGED_MO_CLASS_ID_AAA_USER_EP_FSM_STAGE = "aaaUserEpFsmStage"
    CHANGED_MO_CLASS_ID_AAA_USER_EP_FSM_TASK = "aaaUserEpFsmTask"
    CHANGED_MO_CLASS_ID_AAA_USER_GROUP = "aaaUserGroup"
    CHANGED_MO_CLASS_ID_AAA_USER_LOCALE = "aaaUserLocale"
    CHANGED_MO_CLASS_ID_AAA_USER_LOGIN = "aaaUserLogin"
    CHANGED_MO_CLASS_ID_AAA_USER_ROLE = "aaaUserRole"
    CHANGED_MO_CLASS_ID_AAA_WEB_LOGIN = "aaaWebLogin"
    CHANGED_MO_CLASS_ID_ADAPTOR_AZURE_QOS_PROFILE = "adaptorAzureQosProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_BEH_CAP = "adaptorBehCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_CIO_EP = "adaptorCIoEp"
    CHANGED_MO_CLASS_ID_ADAPTOR_CAP_DEF = "adaptorCapDef"
    CHANGED_MO_CLASS_ID_ADAPTOR_CAP_QUAL = "adaptorCapQual"
    CHANGED_MO_CLASS_ID_ADAPTOR_CAP_SPEC = "adaptorCapSpec"
    CHANGED_MO_CLASS_ID_ADAPTOR_DIAG_CAP = "adaptorDiagCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_DYNAMIC_CONFIG_CAP = "adaptorDynamicConfigCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_ADV_FILTER_PROFILE = "adaptorEthAdvFilterProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_ARFS_PROFILE = "adaptorEthArfsProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_COMP_QUEUE_PROFILE = "adaptorEthCompQueueProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_FAILOVER_PROFILE = "adaptorEthFailoverProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_GENEVEPROFILE = "adaptorEthGENEVEProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_INTERRUPT_PROFILE = "adaptorEthInterruptProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_INTERRUPT_SCALING_PROFILE = "adaptorEthInterruptScalingProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_NVGREPROFILE = "adaptorEthNVGREProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_OFFLOAD_PROFILE = "adaptorEthOffloadProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_PORT_BY_SIZE_LARGE_STATS = "adaptorEthPortBySizeLargeStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_PORT_BY_SIZE_LARGE_STATS_HIST = "adaptorEthPortBySizeLargeStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_PORT_BY_SIZE_SMALL_STATS = "adaptorEthPortBySizeSmallStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_PORT_BY_SIZE_SMALL_STATS_HIST = "adaptorEthPortBySizeSmallStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_PORT_ERR_STATS = "adaptorEthPortErrStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_PORT_ERR_STATS_HIST = "adaptorEthPortErrStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_PORT_MCAST_STATS = "adaptorEthPortMcastStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_PORT_MCAST_STATS_HIST = "adaptorEthPortMcastStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_PORT_OUTSIZED_STATS = "adaptorEthPortOutsizedStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_PORT_OUTSIZED_STATS_HIST = "adaptorEthPortOutsizedStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_PORT_STATS = "adaptorEthPortStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_PORT_STATS_HIST = "adaptorEthPortStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_QUEUE_PROFILE = "adaptorEthQueueProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_RECV_QUEUE_PROFILE = "adaptorEthRecvQueueProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_RO_CEPROFILE = "adaptorEthRoCEProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_VX_LANPROFILE = "adaptorEthVxLANProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETH_WORK_QUEUE_PROFILE = "adaptorEthWorkQueueProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETHER_IF_STATS = "adaptorEtherIfStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_ETHER_IF_STATS_HIST = "adaptorEtherIfStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_EXT_ETH_IF = "adaptorExtEthIf"
    CHANGED_MO_CLASS_ID_ADAPTOR_EXT_ETH_IF_FSM = "adaptorExtEthIfFsm"
    CHANGED_MO_CLASS_ID_ADAPTOR_EXT_ETH_IF_FSM_STAGE = "adaptorExtEthIfFsmStage"
    CHANGED_MO_CLASS_ID_ADAPTOR_EXT_ETH_IF_FSM_TASK = "adaptorExtEthIfFsmTask"
    CHANGED_MO_CLASS_ID_ADAPTOR_EXT_ETH_IF_PC = "adaptorExtEthIfPc"
    CHANGED_MO_CLASS_ID_ADAPTOR_EXT_ETH_IF_PC_EP = "adaptorExtEthIfPcEp"
    CHANGED_MO_CLASS_ID_ADAPTOR_EXT_IF = "adaptorExtIf"
    CHANGED_MO_CLASS_ID_ADAPTOR_EXT_IF_EP = "adaptorExtIfEp"
    CHANGED_MO_CLASS_ID_ADAPTOR_EXT_IF_PC = "adaptorExtIfPc"
    CHANGED_MO_CLASS_ID_ADAPTOR_EXT_IP_V6_RSS_HASH_PROFILE = "adaptorExtIpV6RssHashProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_EXTERNAL_EP = "adaptorExternalEp"
    CHANGED_MO_CLASS_ID_ADAPTOR_EXTERNAL_PC = "adaptorExternalPc"
    CHANGED_MO_CLASS_ID_ADAPTOR_FAMILY_TYPE_DEF = "adaptorFamilyTypeDef"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_CDB_WORK_QUEUE_PROFILE = "adaptorFcCdbWorkQueueProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_ERROR_RECOVERY_PROFILE = "adaptorFcErrorRecoveryProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_FNIC_PROFILE = "adaptorFcFnicProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_IF_EVENT_STATS = "adaptorFcIfEventStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_IF_EVENT_STATS_HIST = "adaptorFcIfEventStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_IF_FC4_STATS = "adaptorFcIfFC4Stats"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_IF_FC4_STATS_HIST = "adaptorFcIfFC4StatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_IF_FRAME_STATS = "adaptorFcIfFrameStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_IF_FRAME_STATS_HIST = "adaptorFcIfFrameStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_INTERRUPT_PROFILE = "adaptorFcInterruptProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_LOGI_PROFILE = "adaptorFcLogiProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_OEIF = "adaptorFcOEIf"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_PORT_FLOGI_PROFILE = "adaptorFcPortFLogiProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_PORT_PLOGI_PROFILE = "adaptorFcPortPLogiProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_PORT_PROFILE = "adaptorFcPortProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_PORT_STATS = "adaptorFcPortStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_PORT_STATS_HIST = "adaptorFcPortStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_QUEUE_PROFILE = "adaptorFcQueueProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_RECV_QUEUE_PROFILE = "adaptorFcRecvQueueProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_VHBA_TYPE_PROFILE = "adaptorFcVhbaTypeProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_FC_WORK_QUEUE_PROFILE = "adaptorFcWorkQueueProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_FRU_CAP_PROVIDER = "adaptorFruCapProvider"
    CHANGED_MO_CLASS_ID_ADAPTOR_FRU_CAP_REF = "adaptorFruCapRef"
    CHANGED_MO_CLASS_ID_ADAPTOR_FW_CAP_PROVIDER = "adaptorFwCapProvider"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_ETH_IF = "adaptorHostEthIf"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_ETH_IF_FSM = "adaptorHostEthIfFsm"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_ETH_IF_FSM_STAGE = "adaptorHostEthIfFsmStage"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_ETH_IF_FSM_TASK = "adaptorHostEthIfFsmTask"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_ETH_IF_PROFILE = "adaptorHostEthIfProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_FC_IF = "adaptorHostFcIf"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_FC_IF_FSM = "adaptorHostFcIfFsm"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_FC_IF_FSM_STAGE = "adaptorHostFcIfFsmStage"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_FC_IF_FSM_TASK = "adaptorHostFcIfFsmTask"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_FC_IF_PROFILE = "adaptorHostFcIfProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_IF = "adaptorHostIf"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_IF_CONFIG = "adaptorHostIfConfig"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_IF_CONN_DEF = "adaptorHostIfConnDef"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_IF_PROFILE = "adaptorHostIfProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_ISCSI_IF = "adaptorHostIscsiIf"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_ISCSI_IF_PROFILE = "adaptorHostIscsiIfProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_MGMT_CAP = "adaptorHostMgmtCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_PORT = "adaptorHostPort"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_PORT_CAP = "adaptorHostPortCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_SCSI_IF = "adaptorHostScsiIf"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_SCSI_LUN_REF = "adaptorHostScsiLunRef"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_SERVICE_ETH_IF = "adaptorHostServiceEthIf"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOST_VNIC_HW_ADDR_CAP = "adaptorHostVnicHwAddrCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOSTETH_HW_ADDR_CAP = "adaptorHostethHwAddrCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_HOSTFC_HW_ADDR_CAP = "adaptorHostfcHwAddrCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_HW_ADDR_CAP = "adaptorHwAddrCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_ISCSI_CAP = "adaptorIScsiCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_IP_V4_RSS_HASH_PROFILE = "adaptorIpV4RssHashProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_IP_V6_RSS_HASH_PROFILE = "adaptorIpV6RssHashProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_ISCSI_AUTH = "adaptorIscsiAuth"
    CHANGED_MO_CLASS_ID_ADAPTOR_ISCSI_PROT = "adaptorIscsiProt"
    CHANGED_MO_CLASS_ID_ADAPTOR_ISCSI_TARGET_IF = "adaptorIscsiTargetIf"
    CHANGED_MO_CLASS_ID_ADAPTOR_LAN_CAP = "adaptorLanCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_LLDP_CAP = "adaptorLldpCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_BASE_ERROR_STATS = "adaptorMenloBaseErrorStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_BASE_ERROR_STATS_HIST = "adaptorMenloBaseErrorStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_DCE_PORT_STATS = "adaptorMenloDcePortStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_DCE_PORT_STATS_HIST = "adaptorMenloDcePortStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_ETH_ERROR_STATS = "adaptorMenloEthErrorStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_ETH_ERROR_STATS_HIST = "adaptorMenloEthErrorStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_ETH_STATS = "adaptorMenloEthStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_ETH_STATS_HIST = "adaptorMenloEthStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_FC_ERROR_STATS = "adaptorMenloFcErrorStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_FC_ERROR_STATS_HIST = "adaptorMenloFcErrorStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_FC_STATS = "adaptorMenloFcStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_FC_STATS_HIST = "adaptorMenloFcStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_HOST_PORT_STATS = "adaptorMenloHostPortStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_HOST_PORT_STATS_HIST = "adaptorMenloHostPortStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_MCPU_ERROR_STATS = "adaptorMenloMcpuErrorStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_MCPU_ERROR_STATS_HIST = "adaptorMenloMcpuErrorStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_MCPU_STATS = "adaptorMenloMcpuStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_MCPU_STATS_HIST = "adaptorMenloMcpuStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_NET_EG_STATS = "adaptorMenloNetEgStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_NET_EG_STATS_HIST = "adaptorMenloNetEgStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_NET_IN_STATS = "adaptorMenloNetInStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_NET_IN_STATS_HIST = "adaptorMenloNetInStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_QERROR_STATS = "adaptorMenloQErrorStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_QERROR_STATS_HIST = "adaptorMenloQErrorStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_QSTATS = "adaptorMenloQStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_MENLO_QSTATS_HIST = "adaptorMenloQStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_MGMT_CAP = "adaptorMgmtCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_MGMT_VNIC_ETH_CONFIG = "adaptorMgmtVnicEthConfig"
    CHANGED_MO_CLASS_ID_ADAPTOR_NW_MGMT_CAP = "adaptorNwMgmtCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_NW_STATS_MGMT_CAP = "adaptorNwStatsMgmtCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_PIO_EP = "adaptorPIoEp"
    CHANGED_MO_CLASS_ID_ADAPTOR_PROFILE_ITEM = "adaptorProfileItem"
    CHANGED_MO_CLASS_ID_ADAPTOR_PROTOCOL_PROFILE = "adaptorProtocolProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_QUAL = "adaptorQual"
    CHANGED_MO_CLASS_ID_ADAPTOR_QUEUE_PROFILE = "adaptorQueueProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_RNIC_CAP_SPEC = "adaptorRnicCapSpec"
    CHANGED_MO_CLASS_ID_ADAPTOR_RSS_HASH_PROFILE = "adaptorRssHashProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_RSS_PROFILE = "adaptorRssProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_SAN_CAP = "adaptorSanCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_TCP_IP_RSS_HASH_PROFILE = "adaptorTcpIpRssHashProfile"
    CHANGED_MO_CLASS_ID_ADAPTOR_UNIT = "adaptorUnit"
    CHANGED_MO_CLASS_ID_ADAPTOR_UNIT_ASSOC_CTX = "adaptorUnitAssocCtx"
    CHANGED_MO_CLASS_ID_ADAPTOR_UNIT_EXTN = "adaptorUnitExtn"
    CHANGED_MO_CLASS_ID_ADAPTOR_UPLINK_HW_ADDR_CAP = "adaptorUplinkHwAddrCap"
    CHANGED_MO_CLASS_ID_ADAPTOR_UPLINK_PORT_STATS = "adaptorUplinkPortStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_USNIC_CONN_DEF = "adaptorUsnicConnDef"
    CHANGED_MO_CLASS_ID_ADAPTOR_VLAN = "adaptorVlan"
    CHANGED_MO_CLASS_ID_ADAPTOR_VMMQ_CONN_DEF = "adaptorVmmqConnDef"
    CHANGED_MO_CLASS_ID_ADAPTOR_VNIC_STATS = "adaptorVnicStats"
    CHANGED_MO_CLASS_ID_ADAPTOR_VNIC_STATS_HIST = "adaptorVnicStatsHist"
    CHANGED_MO_CLASS_ID_ADAPTOR_VSAN = "adaptorVsan"
    CHANGED_MO_CLASS_ID_APE_ADAPTER = "apeAdapter"
    CHANGED_MO_CLASS_ID_APE_ADAPTER_VNIC = "apeAdapterVnic"
    CHANGED_MO_CLASS_ID_APE_ATTRIBUTE = "apeAttribute"
    CHANGED_MO_CLASS_ID_APE_BOOT_METHOD = "apeBootMethod"
    CHANGED_MO_CLASS_ID_APE_CONTROLLER_CHASSIS = "apeControllerChassis"
    CHANGED_MO_CLASS_ID_APE_CONTROLLER_EEPROM = "apeControllerEeprom"
    CHANGED_MO_CLASS_ID_APE_CONTROLLER_MANAGER = "apeControllerManager"
    CHANGED_MO_CLASS_ID_APE_DCOS_AG_MANAGER = "apeDcosAgManager"
    CHANGED_MO_CLASS_ID_APE_FRU = "apeFru"
    CHANGED_MO_CLASS_ID_APE_HOST_AGENT = "apeHostAgent"
    CHANGED_MO_CLASS_ID_APE_LANBOOT = "apeLANBoot"
    CHANGED_MO_CLASS_ID_APE_LOCAL_DISK_BOOT = "apeLocalDiskBoot"
    CHANGED_MO_CLASS_ID_APE_MANAGER = "apeManager"
    CHANGED_MO_CLASS_ID_APE_MC = "apeMc"
    CHANGED_MO_CLASS_ID_APE_MC_STATS = "apeMcStats"
    CHANGED_MO_CLASS_ID_APE_MC_TABLE = "apeMcTable"
    CHANGED_MO_CLASS_ID_APE_MENLO = "apeMenlo"
    CHANGED_MO_CLASS_ID_APE_MENLO_VNIC = "apeMenloVnic"
    CHANGED_MO_CLASS_ID_APE_MENLO_VNIC_STATS = "apeMenloVnicStats"
    CHANGED_MO_CLASS_ID_APE_NIC_AG_MANAGER = "apeNicAgManager"
    CHANGED_MO_CLASS_ID_APE_PALO = "apePalo"
    CHANGED_MO_CLASS_ID_APE_PALO_VNIC = "apePaloVnic"
    CHANGED_MO_CLASS_ID_APE_PALO_VNIC_STATS = "apePaloVnicStats"
    CHANGED_MO_CLASS_ID_APE_PARAM = "apeParam"
    CHANGED_MO_CLASS_ID_APE_READING = "apeReading"
    CHANGED_MO_CLASS_ID_APE_SANBOOT = "apeSANBoot"
    CHANGED_MO_CLASS_ID_APE_SDR = "apeSdr"
    CHANGED_MO_CLASS_ID_APE_SWITCH_FIRMWARE_INV = "apeSwitchFirmwareInv"
    CHANGED_MO_CLASS_ID_APE_VIRTUAL_MEDIA_BOOT = "apeVirtualMediaBoot"
    CHANGED_MO_CLASS_ID_APE_VNIC_STATS = "apeVnicStats"
    CHANGED_MO_CLASS_ID_BIOS_AREF = "biosARef"
    CHANGED_MO_CLASS_ID_BIOS_BOT = "biosBOT"
    CHANGED_MO_CLASS_ID_BIOS_BOOT_DEV = "biosBootDev"
    CHANGED_MO_CLASS_ID_BIOS_BOOT_DEV_GRP = "biosBootDevGrp"
    CHANGED_MO_CLASS_ID_BIOS_FEATURE_REF = "biosFeatureRef"
    CHANGED_MO_CLASS_ID_BIOS_PARAMETER_REF = "biosParameterRef"
    CHANGED_MO_CLASS_ID_BIOS_REF = "biosRef"
    CHANGED_MO_CLASS_ID_BIOS_SETTING_REF = "biosSettingRef"
    CHANGED_MO_CLASS_ID_BIOS_SETTINGS = "biosSettings"
    CHANGED_MO_CLASS_ID_BIOS_TOKEN_FEATURE_GROUP = "biosTokenFeatureGroup"
    CHANGED_MO_CLASS_ID_BIOS_TOKEN_PARAM = "biosTokenParam"
    CHANGED_MO_CLASS_ID_BIOS_TOKEN_SETTINGS = "biosTokenSettings"
    CHANGED_MO_CLASS_ID_BIOS_UNIT = "biosUnit"
    CHANGED_MO_CLASS_ID_BIOS_VFEAT = "biosVFeat"
    CHANGED_MO_CLASS_ID_BIOS_VIDENTITY_PARAMS = "biosVIdentityParams"
    CHANGED_MO_CLASS_ID_BIOS_VPROFILE = "biosVProfile"
    CHANGED_MO_CLASS_ID_BIOS_VF_ACPI10_SUPPORT = "biosVfACPI10Support"
    CHANGED_MO_CLASS_ID_BIOS_VF_ASPMSUPPORT = "biosVfASPMSupport"
    CHANGED_MO_CLASS_ID_BIOS_VF_ALL_USBDEVICES = "biosVfAllUSBDevices"
    CHANGED_MO_CLASS_ID_BIOS_VF_ALTITUDE = "biosVfAltitude"
    CHANGED_MO_CLASS_ID_BIOS_VF_ASSERT_NMION_PERR = "biosVfAssertNMIOnPERR"
    CHANGED_MO_CLASS_ID_BIOS_VF_ASSERT_NMION_SERR = "biosVfAssertNMIOnSERR"
    CHANGED_MO_CLASS_ID_BIOS_VF_BMEDMAMITIGATION = "biosVfBMEDMAMitigation"
    CHANGED_MO_CLASS_ID_BIOS_VF_BOOT_OPTION_RETRY = "biosVfBootOptionRetry"
    CHANGED_MO_CLASS_ID_BIOS_VF_CPUHARDWARE_POWER_MANAGEMENT = "biosVfCPUHardwarePowerManagement"
    CHANGED_MO_CLASS_ID_BIOS_VF_CPUPERFORMANCE = "biosVfCPUPerformance"
    CHANGED_MO_CLASS_ID_BIOS_VF_CONSISTENT_DEVICE_NAME_CONTROL = "biosVfConsistentDeviceNameControl"
    CHANGED_MO_CLASS_ID_BIOS_VF_CONSOLE_REDIRECTION = "biosVfConsoleRedirection"
    CHANGED_MO_CLASS_ID_BIOS_VF_CORE_MULTI_PROCESSING = "biosVfCoreMultiProcessing"
    CHANGED_MO_CLASS_ID_BIOS_VF_DDR3_VOLTAGE_SELECTION = "biosVfDDR3VoltageSelection"
    CHANGED_MO_CLASS_ID_BIOS_VF_DRAMCLOCK_THROTTLING = "biosVfDRAMClockThrottling"
    CHANGED_MO_CLASS_ID_BIOS_VF_DIRECT_CACHE_ACCESS = "biosVfDirectCacheAccess"
    CHANGED_MO_CLASS_ID_BIOS_VF_DRAM_REFRESH_RATE = "biosVfDramRefreshRate"
    CHANGED_MO_CLASS_ID_BIOS_VF_ENERGY_PERFORMANCE_TUNING = "biosVfEnergyPerformanceTuning"
    CHANGED_MO_CLASS_ID_BIOS_VF_ENHANCED_INTEL_SPEED_STEP_TECH = "biosVfEnhancedIntelSpeedStepTech"
    CHANGED_MO_CLASS_ID_BIOS_VF_ENHANCED_POWER_CAPPING_SUPPORT = "biosVfEnhancedPowerCappingSupport"
    CHANGED_MO_CLASS_ID_BIOS_VF_EXECUTE_DISABLE_BIT = "biosVfExecuteDisableBit"
    CHANGED_MO_CLASS_ID_BIOS_VF_FRB2_TIMER = "biosVfFRB2Timer"
    CHANGED_MO_CLASS_ID_BIOS_VF_FREQUENCY_FLOOR_OVERRIDE = "biosVfFrequencyFloorOverride"
    CHANGED_MO_CLASS_ID_BIOS_VF_FRONT_PANEL_LOCKOUT = "biosVfFrontPanelLockout"
    CHANGED_MO_CLASS_ID_BIOS_VF_IOEMEZZ1_OPTION_ROM = "biosVfIOEMezz1OptionROM"
    CHANGED_MO_CLASS_ID_BIOS_VF_IOENVME1_OPTION_ROM = "biosVfIOENVMe1OptionROM"
    CHANGED_MO_CLASS_ID_BIOS_VF_IOENVME2_OPTION_ROM = "biosVfIOENVMe2OptionROM"
    CHANGED_MO_CLASS_ID_BIOS_VF_IOESLOT1_OPTION_ROM = "biosVfIOESlot1OptionROM"
    CHANGED_MO_CLASS_ID_BIOS_VF_IOESLOT2_OPTION_ROM = "biosVfIOESlot2OptionROM"
    CHANGED_MO_CLASS_ID_BIOS_VF_INTEGRATED_GRAPHICS = "biosVfIntegratedGraphics"
    CHANGED_MO_CLASS_ID_BIOS_VF_INTEGRATED_GRAPHICS_APERTURE_SIZE = "biosVfIntegratedGraphicsApertureSize"
    CHANGED_MO_CLASS_ID_BIOS_VF_INTEL_ENTRY_SASRAIDMODULE = "biosVfIntelEntrySASRAIDModule"
    CHANGED_MO_CLASS_ID_BIOS_VF_INTEL_HYPER_THREADING_TECH = "biosVfIntelHyperThreadingTech"
    CHANGED_MO_CLASS_ID_BIOS_VF_INTEL_TRUSTED_EXECUTION_TECHNOLOGY = "biosVfIntelTrustedExecutionTechnology"
    CHANGED_MO_CLASS_ID_BIOS_VF_INTEL_TURBO_BOOST_TECH = "biosVfIntelTurboBoostTech"
    CHANGED_MO_CLASS_ID_BIOS_VF_INTEL_VTFOR_DIRECTED_IO = "biosVfIntelVTForDirectedIO"
    CHANGED_MO_CLASS_ID_BIOS_VF_INTEL_VIRTUALIZATION_TECHNOLOGY = "biosVfIntelVirtualizationTechnology"
    CHANGED_MO_CLASS_ID_BIOS_VF_INTERLEAVE_CONFIGURATION = "biosVfInterleaveConfiguration"
    CHANGED_MO_CLASS_ID_BIOS_VF_LOCAL_X2_APIC = "biosVfLocalX2Apic"
    CHANGED_MO_CLASS_ID_BIOS_VF_LV_DIMMSUPPORT = "biosVfLvDIMMSupport"
    CHANGED_MO_CLASS_ID_BIOS_VF_MAX_VARIABLE_MTRRSETTING = "biosVfMaxVariableMTRRSetting"
    CHANGED_MO_CLASS_ID_BIOS_VF_MAXIMUM_MEMORY_BELOW4_GB = "biosVfMaximumMemoryBelow4GB"
    CHANGED_MO_CLASS_ID_BIOS_VF_MEMORY_MAPPED_IOABOVE4_GB = "biosVfMemoryMappedIOAbove4GB"
    CHANGED_MO_CLASS_ID_BIOS_VF_MIRRORING_MODE = "biosVfMirroringMode"
    CHANGED_MO_CLASS_ID_BIOS_VF_NUMAOPTIMIZED = "biosVfNUMAOptimized"
    CHANGED_MO_CLASS_ID_BIOS_VF_OSBOOT_WATCHDOG_TIMER = "biosVfOSBootWatchdogTimer"
    CHANGED_MO_CLASS_ID_BIOS_VF_OSBOOT_WATCHDOG_TIMER_POLICY = "biosVfOSBootWatchdogTimerPolicy"
    CHANGED_MO_CLASS_ID_BIOS_VF_OSBOOT_WATCHDOG_TIMER_TIMEOUT = "biosVfOSBootWatchdogTimerTimeout"
    CHANGED_MO_CLASS_ID_BIOS_VF_ONBOARD_GRAPHICS = "biosVfOnboardGraphics"
    CHANGED_MO_CLASS_ID_BIOS_VF_ONBOARD_SATACONTROLLER = "biosVfOnboardSATAController"
    CHANGED_MO_CLASS_ID_BIOS_VF_ONBOARD_STORAGE = "biosVfOnboardStorage"
    CHANGED_MO_CLASS_ID_BIOS_VF_OPTION_ROMENABLE = "biosVfOptionROMEnable"
    CHANGED_MO_CLASS_ID_BIOS_VF_OPTION_ROMLOAD = "biosVfOptionROMLoad"
    CHANGED_MO_CLASS_ID_BIOS_VF_OUT_OF_BAND_MANAGEMENT = "biosVfOutOfBandManagement"
    CHANGED_MO_CLASS_ID_BIOS_VF_PCHSATAMODE = "biosVfPCHSATAMode"
    CHANGED_MO_CLASS_ID_BIOS_VF_PCILOMPORTS_CONFIGURATION = "biosVfPCILOMPortsConfiguration"
    CHANGED_MO_CLASS_ID_BIOS_VF_PCIROMCLP = "biosVfPCIROMCLP"
    CHANGED_MO_CLASS_ID_BIOS_VF_PCISLOT_LINK_SPEED = "biosVfPCISlotLinkSpeed"
    CHANGED_MO_CLASS_ID_BIOS_VF_PCISLOT_OPTION_ROMENABLE = "biosVfPCISlotOptionROMEnable"
    CHANGED_MO_CLASS_ID_BIOS_VF_POSTERROR_PAUSE = "biosVfPOSTErrorPause"
    CHANGED_MO_CLASS_ID_BIOS_VF_PSTATECOORDINATION = "biosVfPSTATECoordination"
    CHANGED_MO_CLASS_ID_BIOS_VF_PACKAGE_CSTATE_LIMIT = "biosVfPackageCStateLimit"
    CHANGED_MO_CLASS_ID_BIOS_VF_PANIC_AND_HIGH_WATERMARK = "biosVfPanicAndHighWatermark"
    CHANGED_MO_CLASS_ID_BIOS_VF_PROCESSOR_C1_E = "biosVfProcessorC1E"
    CHANGED_MO_CLASS_ID_BIOS_VF_PROCESSOR_C3_REPORT = "biosVfProcessorC3Report"
    CHANGED_MO_CLASS_ID_BIOS_VF_PROCESSOR_C6_REPORT = "biosVfProcessorC6Report"
    CHANGED_MO_CLASS_ID_BIOS_VF_PROCESSOR_C7_REPORT = "biosVfProcessorC7Report"
    CHANGED_MO_CLASS_ID_BIOS_VF_PROCESSOR_CMCI = "biosVfProcessorCMCI"
    CHANGED_MO_CLASS_ID_BIOS_VF_PROCESSOR_CSTATE = "biosVfProcessorCState"
    CHANGED_MO_CLASS_ID_BIOS_VF_PROCESSOR_ENERGY_CONFIGURATION = "biosVfProcessorEnergyConfiguration"
    CHANGED_MO_CLASS_ID_BIOS_VF_PROCESSOR_PREFETCH_CONFIG = "biosVfProcessorPrefetchConfig"
    CHANGED_MO_CLASS_ID_BIOS_VF_QPILINK_FREQUENCY_SELECT = "biosVfQPILinkFrequencySelect"
    CHANGED_MO_CLASS_ID_BIOS_VF_QPISNOOP_MODE = "biosVfQPISnoopMode"
    CHANGED_MO_CLASS_ID_BIOS_VF_QUIET_BOOT = "biosVfQuietBoot"
    CHANGED_MO_CLASS_ID_BIOS_VF_REDIRECTION_AFTER_BIOSPOST = "biosVfRedirectionAfterBIOSPOST"
    CHANGED_MO_CLASS_ID_BIOS_VF_RESUME_ON_ACPOWER_LOSS = "biosVfResumeOnACPowerLoss"
    CHANGED_MO_CLASS_ID_BIOS_VF_SBMEZZ1_OPTION_ROM = "biosVfSBMezz1OptionROM"
    CHANGED_MO_CLASS_ID_BIOS_VF_SBNVME1_OPTION_ROM = "biosVfSBNVMe1OptionROM"
    CHANGED_MO_CLASS_ID_BIOS_VF_SIOC1_OPTION_ROM = "biosVfSIOC1OptionROM"
    CHANGED_MO_CLASS_ID_BIOS_VF_SIOC2_OPTION_ROM = "biosVfSIOC2OptionROM"
    CHANGED_MO_CLASS_ID_BIOS_VF_SCRUB_POLICIES = "biosVfScrubPolicies"
    CHANGED_MO_CLASS_ID_BIOS_VF_SELECT_MEMORY_RASCONFIGURATION = "biosVfSelectMemoryRASConfiguration"
    CHANGED_MO_CLASS_ID_BIOS_VF_SERIAL_PORT_AENABLE = "biosVfSerialPortAEnable"
    CHANGED_MO_CLASS_ID_BIOS_VF_SPARING_MODE = "biosVfSparingMode"
    CHANGED_MO_CLASS_ID_BIOS_VF_SRIOV_CONFIG = "biosVfSriovConfig"
    CHANGED_MO_CLASS_ID_BIOS_VF_TPMPENDING_OPERATION = "biosVfTPMPendingOperation"
    CHANGED_MO_CLASS_ID_BIOS_VF_TPMSUPPORT = "biosVfTPMSupport"
    CHANGED_MO_CLASS_ID_BIOS_VF_TRUSTED_PLATFORM_MODULE = "biosVfTrustedPlatformModule"
    CHANGED_MO_CLASS_ID_BIOS_VF_UCSMBOOT_MODE_CONTROL = "biosVfUCSMBootModeControl"
    CHANGED_MO_CLASS_ID_BIOS_VF_UCSMBOOT_ORDER_RULE_CONTROL = "biosVfUCSMBootOrderRuleControl"
    CHANGED_MO_CLASS_ID_BIOS_VF_UEFIOSUSE_LEGACY_VIDEO = "biosVfUEFIOSUseLegacyVideo"
    CHANGED_MO_CLASS_ID_BIOS_VF_USBBOOT_CONFIG = "biosVfUSBBootConfig"
    CHANGED_MO_CLASS_ID_BIOS_VF_USBCONFIGURATION = "biosVfUSBConfiguration"
    CHANGED_MO_CLASS_ID_BIOS_VF_USBFRONT_PANEL_ACCESS_LOCK = "biosVfUSBFrontPanelAccessLock"
    CHANGED_MO_CLASS_ID_BIOS_VF_USBPORT_CONFIGURATION = "biosVfUSBPortConfiguration"
    CHANGED_MO_CLASS_ID_BIOS_VF_USBSYSTEM_IDLE_POWER_OPTIMIZING_SETTING = "biosVfUSBSystemIdlePowerOptimizingSetting"
    CHANGED_MO_CLASS_ID_BIOS_VF_VGAPRIORITY = "biosVfVGAPriority"
    CHANGED_MO_CLASS_ID_BIOS_VF_WORKLOAD_CONFIGURATION = "biosVfWorkloadConfiguration"
    CHANGED_MO_CLASS_ID_BMC_SELCOUNTER = "bmcSELCounter"
    CHANGED_MO_CLASS_ID_CALLHOME_ANONYMOUS_REPORTING = "callhomeAnonymousReporting"
    CHANGED_MO_CLASS_ID_CALLHOME_DEST = "callhomeDest"
    CHANGED_MO_CLASS_ID_CALLHOME_EP = "callhomeEp"
    CHANGED_MO_CLASS_ID_CALLHOME_EP_FSM = "callhomeEpFsm"
    CHANGED_MO_CLASS_ID_CALLHOME_EP_FSM_STAGE = "callhomeEpFsmStage"
    CHANGED_MO_CLASS_ID_CALLHOME_EP_FSM_TASK = "callhomeEpFsmTask"
    CHANGED_MO_CLASS_ID_CALLHOME_ITEM = "callhomeItem"
    CHANGED_MO_CLASS_ID_CALLHOME_PERIODIC_SYSTEM_INVENTORY = "callhomePeriodicSystemInventory"
    CHANGED_MO_CLASS_ID_CALLHOME_POLICY = "callhomePolicy"
    CHANGED_MO_CLASS_ID_CALLHOME_PROFILE = "callhomeProfile"
    CHANGED_MO_CLASS_ID_CALLHOME_SMTP = "callhomeSmtp"
    CHANGED_MO_CLASS_ID_CALLHOME_SOURCE = "callhomeSource"
    CHANGED_MO_CLASS_ID_CALLHOME_TEST_ALERT = "callhomeTestAlert"
    CHANGED_MO_CLASS_ID_CAPABILITY_AEND_POINT_CONFIG = "capabilityAEndPointConfig"
    CHANGED_MO_CLASS_ID_CAPABILITY_ASOLUTION_STACK = "capabilityASolutionStack"
    CHANGED_MO_CLASS_ID_CAPABILITY_CATALOGUE = "capabilityCatalogue"
    CHANGED_MO_CLASS_ID_CAPABILITY_CATALOGUE_FSM = "capabilityCatalogueFsm"
    CHANGED_MO_CLASS_ID_CAPABILITY_CATALOGUE_FSM_STAGE = "capabilityCatalogueFsmStage"
    CHANGED_MO_CLASS_ID_CAPABILITY_CATALOGUE_FSM_TASK = "capabilityCatalogueFsmTask"
    CHANGED_MO_CLASS_ID_CAPABILITY_DEF = "capabilityDef"
    CHANGED_MO_CLASS_ID_CAPABILITY_EP = "capabilityEp"
    CHANGED_MO_CLASS_ID_CAPABILITY_FEATURE_LIMITS = "capabilityFeatureLimits"
    CHANGED_MO_CLASS_ID_CAPABILITY_ITEM = "capabilityItem"
    CHANGED_MO_CLASS_ID_CAPABILITY_MGMT_EXTENSION = "capabilityMgmtExtension"
    CHANGED_MO_CLASS_ID_CAPABILITY_MGMT_EXTENSION_FSM = "capabilityMgmtExtensionFsm"
    CHANGED_MO_CLASS_ID_CAPABILITY_MGMT_EXTENSION_FSM_STAGE = "capabilityMgmtExtensionFsmStage"
    CHANGED_MO_CLASS_ID_CAPABILITY_MGMT_EXTENSION_FSM_TASK = "capabilityMgmtExtensionFsmTask"
    CHANGED_MO_CLASS_ID_CAPABILITY_NETWORK_LIMITS = "capabilityNetworkLimits"
    CHANGED_MO_CLASS_ID_CAPABILITY_PROVIDER = "capabilityProvider"
    CHANGED_MO_CLASS_ID_CAPABILITY_STORAGE_LIMITS = "capabilityStorageLimits"
    CHANGED_MO_CLASS_ID_CAPABILITY_SYSTEM_LIMITS = "capabilitySystemLimits"
    CHANGED_MO_CLASS_ID_CAPABILITY_UPDATE = "capabilityUpdate"
    CHANGED_MO_CLASS_ID_CAPABILITY_UPDATER = "capabilityUpdater"
    CHANGED_MO_CLASS_ID_CAPABILITY_UPDATER_FSM = "capabilityUpdaterFsm"
    CHANGED_MO_CLASS_ID_CAPABILITY_UPDATER_FSM_STAGE = "capabilityUpdaterFsmStage"
    CHANGED_MO_CLASS_ID_CAPABILITY_UPDATER_FSM_TASK = "capabilityUpdaterFsmTask"
    CHANGED_MO_CLASS_ID_CHANGE_CHANGED_OBJECT_REF = "changeChangedObjectRef"
    CHANGED_MO_CLASS_ID_CIMCVMEDIA_ACTUAL_MOUNT_ENTRY = "cimcvmediaActualMountEntry"
    CHANGED_MO_CLASS_ID_CIMCVMEDIA_ACTUAL_MOUNT_LIST = "cimcvmediaActualMountList"
    CHANGED_MO_CLASS_ID_CIMCVMEDIA_CONFIG_MOUNT_ENTRY = "cimcvmediaConfigMountEntry"
    CHANGED_MO_CLASS_ID_CIMCVMEDIA_EXT_MGMT_RULE_ENTRY = "cimcvmediaExtMgmtRuleEntry"
    CHANGED_MO_CLASS_ID_CIMCVMEDIA_ITEM = "cimcvmediaItem"
    CHANGED_MO_CLASS_ID_CIMCVMEDIA_MOUNT_CONFIG = "cimcvmediaMountConfig"
    CHANGED_MO_CLASS_ID_CIMCVMEDIA_MOUNT_CONFIG_DEF = "cimcvmediaMountConfigDef"
    CHANGED_MO_CLASS_ID_CIMCVMEDIA_MOUNT_CONFIG_POLICY = "cimcvmediaMountConfigPolicy"
    CHANGED_MO_CLASS_ID_CIMCVMEDIA_MOUNT_INFO = "cimcvmediaMountInfo"
    CHANGED_MO_CLASS_ID_CLITEST_TYPE_TEST = "clitestTypeTest"
    CHANGED_MO_CLASS_ID_CLITEST_TYPE_TEST2 = "clitestTypeTest2"
    CHANGED_MO_CLASS_ID_CLITEST_TYPE_TEST_CHILD = "clitestTypeTestChild"
    CHANGED_MO_CLASS_ID_CLITEST_TYPE_TEST_PARENT = "clitestTypeTestParent"
    CHANGED_MO_CLASS_ID_CLOUD_DEVICE_CONNECTOR_EP = "cloudDeviceConnectorEp"
    CHANGED_MO_CLASS_ID_CLOUD_MGMT_SVC = "cloudMgmtSvc"
    CHANGED_MO_CLASS_ID_COMM_CIMC_WEB_SERVICE = "commCimcWebService"
    CHANGED_MO_CLASS_ID_COMM_CIMXML = "commCimxml"
    CHANGED_MO_CLASS_ID_COMM_CLIENT = "commClient"
    CHANGED_MO_CLASS_ID_COMM_CLIENT_ITEM = "commClientItem"
    CHANGED_MO_CLASS_ID_COMM_DATE_TIME = "commDateTime"
    CHANGED_MO_CLASS_ID_COMM_DEFINITION = "commDefinition"
    CHANGED_MO_CLASS_ID_COMM_DNS = "commDns"
    CHANGED_MO_CLASS_ID_COMM_DNS_PROVIDER = "commDnsProvider"
    CHANGED_MO_CLASS_ID_COMM_EVT_CHANNEL = "commEvtChannel"
    CHANGED_MO_CLASS_ID_COMM_HTTP = "commHttp"
    CHANGED_MO_CLASS_ID_COMM_HTTPS = "commHttps"
    CHANGED_MO_CLASS_ID_COMM_ITEM = "commItem"
    CHANGED_MO_CLASS_ID_COMM_LOCALE = "commLocale"
    CHANGED_MO_CLASS_ID_COMM_NTP_PROVIDER = "commNtpProvider"
    CHANGED_MO_CLASS_ID_COMM_SHELL = "commShell"
    CHANGED_MO_CLASS_ID_COMM_SHELL_SVC_LIMITS = "commShellSvcLimits"
    CHANGED_MO_CLASS_ID_COMM_SMASH_CLP = "commSmashCLP"
    CHANGED_MO_CLASS_ID_COMM_SNMP = "commSnmp"
    CHANGED_MO_CLASS_ID_COMM_SNMP_TRAP = "commSnmpTrap"
    CHANGED_MO_CLASS_ID_COMM_SNMP_USER = "commSnmpUser"
    CHANGED_MO_CLASS_ID_COMM_SSH = "commSsh"
    CHANGED_MO_CLASS_ID_COMM_SVC = "commSvc"
    CHANGED_MO_CLASS_ID_COMM_SVC_CHANNEL = "commSvcChannel"
    CHANGED_MO_CLASS_ID_COMM_SVC_EP = "commSvcEp"
    CHANGED_MO_CLASS_ID_COMM_SVC_EP_FSM = "commSvcEpFsm"
    CHANGED_MO_CLASS_ID_COMM_SVC_EP_FSM_STAGE = "commSvcEpFsmStage"
    CHANGED_MO_CLASS_ID_COMM_SVC_EP_FSM_TASK = "commSvcEpFsmTask"
    CHANGED_MO_CLASS_ID_COMM_SVC_LIMITS = "commSvcLimits"
    CHANGED_MO_CLASS_ID_COMM_SVC_POLICY = "commSvcPolicy"
    CHANGED_MO_CLASS_ID_COMM_SYSLOG = "commSyslog"
    CHANGED_MO_CLASS_ID_COMM_SYSLOG_CLIENT = "commSyslogClient"
    CHANGED_MO_CLASS_ID_COMM_SYSLOG_CONSOLE = "commSyslogConsole"
    CHANGED_MO_CLASS_ID_COMM_SYSLOG_FILE = "commSyslogFile"
    CHANGED_MO_CLASS_ID_COMM_SYSLOG_MONITOR = "commSyslogMonitor"
    CHANGED_MO_CLASS_ID_COMM_SYSLOG_SOURCE = "commSyslogSource"
    CHANGED_MO_CLASS_ID_COMM_TELNET = "commTelnet"
    CHANGED_MO_CLASS_ID_COMM_WEB = "commWeb"
    CHANGED_MO_CLASS_ID_COMM_WEB_CHANNEL = "commWebChannel"
    CHANGED_MO_CLASS_ID_COMM_WEB_SVC_LIMITS = "commWebSvcLimits"
    CHANGED_MO_CLASS_ID_COMM_WSMAN = "commWsman"
    CHANGED_MO_CLASS_ID_COMM_XML_CL_CONN_POLICY = "commXmlClConnPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_ABOARD = "computeABoard"
    CHANGED_MO_CLASS_ID_COMPUTE_ACHASSIS_DISC_POLICY = "computeAChassisDiscPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_ADMIN_ACK = "computeAdminAck"
    CHANGED_MO_CLASS_ID_COMPUTE_AUTOCONFIG_POLICY = "computeAutoconfigPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_BEH_CAP = "computeBehCap"
    CHANGED_MO_CLASS_ID_COMPUTE_BLADE = "computeBlade"
    CHANGED_MO_CLASS_ID_COMPUTE_BLADE_DISC_POLICY = "computeBladeDiscPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_BLADE_EP = "computeBladeEp"
    CHANGED_MO_CLASS_ID_COMPUTE_BLADE_FSM = "computeBladeFsm"
    CHANGED_MO_CLASS_ID_COMPUTE_BLADE_FSM_STAGE = "computeBladeFsmStage"
    CHANGED_MO_CLASS_ID_COMPUTE_BLADE_FSM_TASK = "computeBladeFsmTask"
    CHANGED_MO_CLASS_ID_COMPUTE_BLADE_INHERIT_POLICY = "computeBladeInheritPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_BLADE_POS_QUAL = "computeBladePosQual"
    CHANGED_MO_CLASS_ID_COMPUTE_BOARD = "computeBoard"
    CHANGED_MO_CLASS_ID_COMPUTE_BOARD_CONNECTOR = "computeBoardConnector"
    CHANGED_MO_CLASS_ID_COMPUTE_BOARD_CONTROLLER = "computeBoardController"
    CHANGED_MO_CLASS_ID_COMPUTE_CARTRIDGE = "computeCartridge"
    CHANGED_MO_CLASS_ID_COMPUTE_CHASSIS_CONN_POLICY = "computeChassisConnPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_CHASSIS_DISC_POLICY = "computeChassisDiscPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_CHASSIS_QUAL = "computeChassisQual"
    CHANGED_MO_CLASS_ID_COMPUTE_COMPUTE_DISC_POLICY = "computeComputeDiscPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_CONFIG_POLICY = "computeConfigPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_CONSTRAINT_DEF = "computeConstraintDef"
    CHANGED_MO_CLASS_ID_COMPUTE_CONTAINER = "computeContainer"
    CHANGED_MO_CLASS_ID_COMPUTE_DEFAULTS = "computeDefaults"
    CHANGED_MO_CLASS_ID_COMPUTE_DISC_POLICY = "computeDiscPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_EXT_BOARD = "computeExtBoard"
    CHANGED_MO_CLASS_ID_COMPUTE_FACTORY_RESET_OPERATION = "computeFactoryResetOperation"
    CHANGED_MO_CLASS_ID_COMPUTE_FAN_POLICY = "computeFanPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_FW_SYNC_ACK = "computeFwSyncAck"
    CHANGED_MO_CLASS_ID_COMPUTE_GRAPHICS_CARD_POLICY = "computeGraphicsCardPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_HEALTH_LED_SENSOR_ALARM = "computeHealthLedSensorAlarm"
    CHANGED_MO_CLASS_ID_COMPUTE_HOST_UTILITY_OS = "computeHostUtilityOs"
    CHANGED_MO_CLASS_ID_COMPUTE_HW_CHANGE_DISC_POLICY = "computeHwChangeDiscPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_IOHUB = "computeIOHub"
    CHANGED_MO_CLASS_ID_COMPUTE_IOHUB_ENV_STATS = "computeIOHubEnvStats"
    CHANGED_MO_CLASS_ID_COMPUTE_IOHUB_ENV_STATS_HIST = "computeIOHubEnvStatsHist"
    CHANGED_MO_CLASS_ID_COMPUTE_INIT_CONFIG_POLICY = "computeInitConfigPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_INSTANCE_ID_QUAL = "computeInstanceIdQual"
    CHANGED_MO_CLASS_ID_COMPUTE_ITEM = "computeItem"
    CHANGED_MO_CLASS_ID_COMPUTE_KVM_MGMT_POLICY = "computeKvmMgmtPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_LOGICAL = "computeLogical"
    CHANGED_MO_CLASS_ID_COMPUTE_MB_POWER_STATS = "computeMbPowerStats"
    CHANGED_MO_CLASS_ID_COMPUTE_MB_POWER_STATS_HIST = "computeMbPowerStatsHist"
    CHANGED_MO_CLASS_ID_COMPUTE_MB_TEMP_STATS = "computeMbTempStats"
    CHANGED_MO_CLASS_ID_COMPUTE_MB_TEMP_STATS_HIST = "computeMbTempStatsHist"
    CHANGED_MO_CLASS_ID_COMPUTE_MEMORY_CONFIG_POLICY = "computeMemoryConfigPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_MEMORY_CONFIGURATION = "computeMemoryConfiguration"
    CHANGED_MO_CLASS_ID_COMPUTE_MEMORY_UNIT_CONSTRAINT_DEF = "computeMemoryUnitConstraintDef"
    CHANGED_MO_CLASS_ID_COMPUTE_PCIE_FATAL_COMPLETION_STATS = "computePCIeFatalCompletionStats"
    CHANGED_MO_CLASS_ID_COMPUTE_PCIE_FATAL_PROTOCOL_STATS = "computePCIeFatalProtocolStats"
    CHANGED_MO_CLASS_ID_COMPUTE_PCIE_FATAL_RECEIVE_STATS = "computePCIeFatalReceiveStats"
    CHANGED_MO_CLASS_ID_COMPUTE_PCIE_FATAL_STATS = "computePCIeFatalStats"
    CHANGED_MO_CLASS_ID_COMPUTE_PARTITION = "computePartition"
    CHANGED_MO_CLASS_ID_COMPUTE_PCI_CAP = "computePciCap"
    CHANGED_MO_CLASS_ID_COMPUTE_PCI_SLOT_SCAN_DEF = "computePciSlotScanDef"
    CHANGED_MO_CLASS_ID_COMPUTE_PERSONALITY = "computePersonality"
    CHANGED_MO_CLASS_ID_COMPUTE_PHYSICAL = "computePhysical"
    CHANGED_MO_CLASS_ID_COMPUTE_PHYSICAL_ASSOC_CTX = "computePhysicalAssocCtx"
    CHANGED_MO_CLASS_ID_COMPUTE_PHYSICAL_EXTENSION = "computePhysicalExtension"
    CHANGED_MO_CLASS_ID_COMPUTE_PHYSICAL_FSM = "computePhysicalFsm"
    CHANGED_MO_CLASS_ID_COMPUTE_PHYSICAL_FSM_STAGE = "computePhysicalFsmStage"
    CHANGED_MO_CLASS_ID_COMPUTE_PHYSICAL_FSM_TASK = "computePhysicalFsmTask"
    CHANGED_MO_CLASS_ID_COMPUTE_PHYSICAL_QUAL = "computePhysicalQual"
    CHANGED_MO_CLASS_ID_COMPUTE_PLATFORM = "computePlatform"
    CHANGED_MO_CLASS_ID_COMPUTE_PNU_OSIMAGE = "computePnuOSImage"
    CHANGED_MO_CLASS_ID_COMPUTE_POOL = "computePool"
    CHANGED_MO_CLASS_ID_COMPUTE_POOL_POLICY_REF = "computePoolPolicyRef"
    CHANGED_MO_CLASS_ID_COMPUTE_POOLABLE = "computePoolable"
    CHANGED_MO_CLASS_ID_COMPUTE_POOLED = "computePooled"
    CHANGED_MO_CLASS_ID_COMPUTE_POOLED_ENCLOSURE_COMPUTE_SLOT = "computePooledEnclosureComputeSlot"
    CHANGED_MO_CLASS_ID_COMPUTE_POOLED_PHYSICAL = "computePooledPhysical"
    CHANGED_MO_CLASS_ID_COMPUTE_POOLED_RACK_UNIT = "computePooledRackUnit"
    CHANGED_MO_CLASS_ID_COMPUTE_POOLED_SLOT = "computePooledSlot"
    CHANGED_MO_CLASS_ID_COMPUTE_POOLING_POLICY = "computePoolingPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_PORT_DISC_POLICY = "computePortDiscPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_POWER_SAVE_POLICY = "computePowerSavePolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_POWER_SYNC_DEF = "computePowerSyncDef"
    CHANGED_MO_CLASS_ID_COMPUTE_POWER_SYNC_POLICY = "computePowerSyncPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_PSU_CONTROL = "computePsuControl"
    CHANGED_MO_CLASS_ID_COMPUTE_PSU_DEF = "computePsuDef"
    CHANGED_MO_CLASS_ID_COMPUTE_PSU_POLICY = "computePsuPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_QUAL = "computeQual"
    CHANGED_MO_CLASS_ID_COMPUTE_QUAL_BASE = "computeQualBase"
    CHANGED_MO_CLASS_ID_COMPUTE_QUAL_ITEM = "computeQualItem"
    CHANGED_MO_CLASS_ID_COMPUTE_QUALIFIED_POLICY = "computeQualifiedPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_RACK_CONN_LINK_POLICY = "computeRackConnLinkPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_RACK_POS_QUAL = "computeRackPosQual"
    CHANGED_MO_CLASS_ID_COMPUTE_RACK_QUAL = "computeRackQual"
    CHANGED_MO_CLASS_ID_COMPUTE_RACK_UNIT = "computeRackUnit"
    CHANGED_MO_CLASS_ID_COMPUTE_RACK_UNIT_FSM = "computeRackUnitFsm"
    CHANGED_MO_CLASS_ID_COMPUTE_RACK_UNIT_FSM_STAGE = "computeRackUnitFsmStage"
    CHANGED_MO_CLASS_ID_COMPUTE_RACK_UNIT_FSM_TASK = "computeRackUnitFsmTask"
    CHANGED_MO_CLASS_ID_COMPUTE_RACK_UNIT_MB_TEMP_STATS = "computeRackUnitMbTempStats"
    CHANGED_MO_CLASS_ID_COMPUTE_RACK_UNIT_MB_TEMP_STATS_HIST = "computeRackUnitMbTempStatsHist"
    CHANGED_MO_CLASS_ID_COMPUTE_REBOOT_LOG = "computeRebootLog"
    CHANGED_MO_CLASS_ID_COMPUTE_RTC_BATTERY = "computeRtcBattery"
    CHANGED_MO_CLASS_ID_COMPUTE_SCRUB_POLICY = "computeScrubPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_SERVER = "computeServer"
    CHANGED_MO_CLASS_ID_COMPUTE_SERVER_DISC_POLICY = "computeServerDiscPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_SERVER_DISC_POLICY_FSM = "computeServerDiscPolicyFsm"
    CHANGED_MO_CLASS_ID_COMPUTE_SERVER_DISC_POLICY_FSM_STAGE = "computeServerDiscPolicyFsmStage"
    CHANGED_MO_CLASS_ID_COMPUTE_SERVER_DISC_POLICY_FSM_TASK = "computeServerDiscPolicyFsmTask"
    CHANGED_MO_CLASS_ID_COMPUTE_SERVER_MGMT_POLICY = "computeServerMgmtPolicy"
    CHANGED_MO_CLASS_ID_COMPUTE_SERVER_TYPE_CAP = "computeServerTypeCap"
    CHANGED_MO_CLASS_ID_COMPUTE_SERVER_UNIT = "computeServerUnit"
    CHANGED_MO_CLASS_ID_COMPUTE_SERVER_UNIT_FSM = "computeServerUnitFsm"
    CHANGED_MO_CLASS_ID_COMPUTE_SERVER_UNIT_FSM_STAGE = "computeServerUnitFsmStage"
    CHANGED_MO_CLASS_ID_COMPUTE_SERVER_UNIT_FSM_TASK = "computeServerUnitFsmTask"
    CHANGED_MO_CLASS_ID_COMPUTE_SLOT_ENTITY = "computeSlotEntity"
    CHANGED_MO_CLASS_ID_COMPUTE_SLOT_QUAL = "computeSlotQual"
    CHANGED_MO_CLASS_ID_COMPUTE_VIRTUAL = "computeVirtual"
    CHANGED_MO_CLASS_ID_COMPUTE_VIRTUAL_CONTAINER = "computeVirtualContainer"
    CHANGED_MO_CLASS_ID_CONDITION_IMMUTABLE = "conditionImmutable"
    CHANGED_MO_CLASS_ID_CONDITION_INFO = "conditionInfo"
    CHANGED_MO_CLASS_ID_CONDITION_LOG = "conditionLog"
    CHANGED_MO_CLASS_ID_CONDITION_LOGGABLE = "conditionLoggable"
    CHANGED_MO_CLASS_ID_CONDITION_MULTI_INSTANCE_IMMUTABLE = "conditionMultiInstanceImmutable"
    CHANGED_MO_CLASS_ID_CONDITION_MUTABLE = "conditionMutable"
    CHANGED_MO_CLASS_ID_CONDITION_POLICY = "conditionPolicy"
    CHANGED_MO_CLASS_ID_CONDITION_REPORTABLE = "conditionReportable"
    CHANGED_MO_CLASS_ID_CONFIG_IMPACT = "configImpact"
    CHANGED_MO_CLASS_ID_CONFIG_IMPACT_RESPONSE = "configImpactResponse"
    CHANGED_MO_CLASS_ID_CONFIG_MANAGED_EP_IMPACT_RESPONSE = "configManagedEpImpactResponse"
    CHANGED_MO_CLASS_ID_CONFIG_SORTER = "configSorter"
    CHANGED_MO_CLASS_ID_CONTROLLER_HA_CONTROLLER = "controllerHaController"
    CHANGED_MO_CLASS_ID_CONTROLLER_MGMT_DB_CHECK_POL = "controllerMgmtDbCheckPol"
    CHANGED_MO_CLASS_ID_CONTROLLER_OPERATIONAL_VERSION_HOLDER = "controllerOperationalVersionHolder"
    CHANGED_MO_CLASS_ID_CONTROLLER_PREFERED_VERSION_HOLDER = "controllerPreferedVersionHolder"
    CHANGED_MO_CLASS_ID_COPROCESSOR_CARD = "coprocessorCard"
    CHANGED_MO_CLASS_ID_CPMAINT_ACK = "cpmaintAck"
    CHANGED_MO_CLASS_ID_CPMAINT_MAINT_POLICY = "cpmaintMaintPolicy"
    CHANGED_MO_CLASS_ID_DCX_FCOE_VIF_EP = "dcxFcoeVifEp"
    CHANGED_MO_CLASS_ID_DCX_NS = "dcxNs"
    CHANGED_MO_CLASS_ID_DCX_UNIVERSE = "dcxUniverse"
    CHANGED_MO_CLASS_ID_DCX_VIF = "dcxVIf"
    CHANGED_MO_CLASS_ID_DCX_VC = "dcxVc"
    CHANGED_MO_CLASS_ID_DCX_VIF_EP = "dcxVifEp"
    CHANGED_MO_CLASS_ID_DHCP_ACQUIRED = "dhcpAcquired"
    CHANGED_MO_CLASS_ID_DHCP_INST = "dhcpInst"
    CHANGED_MO_CLASS_ID_DHCP_LEASE = "dhcpLease"
    CHANGED_MO_CLASS_ID_DIAG_CTRL = "diagCtrl"
    CHANGED_MO_CLASS_ID_DIAG_LOG_EP = "diagLogEp"
    CHANGED_MO_CLASS_ID_DIAG_MEMORY_TEST = "diagMemoryTest"
    CHANGED_MO_CLASS_ID_DIAG_RSLT = "diagRslt"
    CHANGED_MO_CLASS_ID_DIAG_RUN_POLICY = "diagRunPolicy"
    CHANGED_MO_CLASS_ID_DIAG_SRV_CAP_PROVIDER = "diagSrvCapProvider"
    CHANGED_MO_CLASS_ID_DIAG_SRV_CTRL = "diagSrvCtrl"
    CHANGED_MO_CLASS_ID_DIAG_TEST = "diagTest"
    CHANGED_MO_CLASS_ID_DOMAIN_CHASSIS_FEATURE = "domainChassisFeature"
    CHANGED_MO_CLASS_ID_DOMAIN_CHASSIS_FEATURE_CONT = "domainChassisFeatureCont"
    CHANGED_MO_CLASS_ID_DOMAIN_CHASSIS_PARAM = "domainChassisParam"
    CHANGED_MO_CLASS_ID_DOMAIN_ENVIRONMENT_FEATURE = "domainEnvironmentFeature"
    CHANGED_MO_CLASS_ID_DOMAIN_ENVIRONMENT_FEATURE_CONT = "domainEnvironmentFeatureCont"
    CHANGED_MO_CLASS_ID_DOMAIN_ENVIRONMENT_PARAM = "domainEnvironmentParam"
    CHANGED_MO_CLASS_ID_DOMAIN_FEATURE = "domainFeature"
    CHANGED_MO_CLASS_ID_DOMAIN_FEATURE_CONT = "domainFeatureCont"
    CHANGED_MO_CLASS_ID_DOMAIN_NETWORK_FEATURE = "domainNetworkFeature"
    CHANGED_MO_CLASS_ID_DOMAIN_NETWORK_FEATURE_CONT = "domainNetworkFeatureCont"
    CHANGED_MO_CLASS_ID_DOMAIN_NETWORK_PARAM = "domainNetworkParam"
    CHANGED_MO_CLASS_ID_DOMAIN_PARAMETER = "domainParameter"
    CHANGED_MO_CLASS_ID_DOMAIN_SERVER_FEATURE = "domainServerFeature"
    CHANGED_MO_CLASS_ID_DOMAIN_SERVER_FEATURE_CONT = "domainServerFeatureCont"
    CHANGED_MO_CLASS_ID_DOMAIN_SERVER_PARAM = "domainServerParam"
    CHANGED_MO_CLASS_ID_DOMAIN_STORAGE_FEATURE = "domainStorageFeature"
    CHANGED_MO_CLASS_ID_DOMAIN_STORAGE_FEATURE_CONT = "domainStorageFeatureCont"
    CHANGED_MO_CLASS_ID_DOMAIN_STORAGE_PARAM = "domainStorageParam"
    CHANGED_MO_CLASS_ID_DPSEC_MAC = "dpsecMac"
    CHANGED_MO_CLASS_ID_DUPE_SCOPE = "dupeScope"
    CHANGED_MO_CLASS_ID_DUPE_SCOPE_RESULT = "dupeScopeResult"
    CHANGED_MO_CLASS_ID_EPQOS_DEFINITION = "epqosDefinition"
    CHANGED_MO_CLASS_ID_EPQOS_DEFINITION_DEL_TASK = "epqosDefinitionDelTask"
    CHANGED_MO_CLASS_ID_EPQOS_DEFINITION_DEL_TASK_FSM = "epqosDefinitionDelTaskFsm"
    CHANGED_MO_CLASS_ID_EPQOS_DEFINITION_DEL_TASK_FSM_STAGE = "epqosDefinitionDelTaskFsmStage"
    CHANGED_MO_CLASS_ID_EPQOS_DEFINITION_DEL_TASK_FSM_TASK = "epqosDefinitionDelTaskFsmTask"
    CHANGED_MO_CLASS_ID_EPQOS_DEFINITION_FSM = "epqosDefinitionFsm"
    CHANGED_MO_CLASS_ID_EPQOS_DEFINITION_FSM_STAGE = "epqosDefinitionFsmStage"
    CHANGED_MO_CLASS_ID_EPQOS_DEFINITION_FSM_TASK = "epqosDefinitionFsmTask"
    CHANGED_MO_CLASS_ID_EPQOS_EGRESS = "epqosEgress"
    CHANGED_MO_CLASS_ID_EPQOS_ITEM = "epqosItem"
    CHANGED_MO_CLASS_ID_EQUIPMENT_ADAPTOR_CONN_DEF = "equipmentAdaptorConnDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_ADAPTOR_DEF = "equipmentAdaptorDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_ADVANCED_BOOT_ORDER = "equipmentAdvancedBootOrder"
    CHANGED_MO_CLASS_ID_EQUIPMENT_ASSOC_CTX = "equipmentAssocCtx"
    CHANGED_MO_CLASS_ID_EQUIPMENT_AUTO_CONFIG_MODE = "equipmentAutoConfigMode"
    CHANGED_MO_CLASS_ID_EQUIPMENT_AUTOCONFIG_POLICY = "equipmentAutoconfigPolicy"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BASE_BOARD_CAP_PROVIDER = "equipmentBaseBoardCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BEACON_CAP_PROVIDER = "equipmentBeaconCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BEACON_LED = "equipmentBeaconLed"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BEACON_LED_FSM = "equipmentBeaconLedFsm"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BEACON_LED_FSM_STAGE = "equipmentBeaconLedFsmStage"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BEACON_LED_FSM_TASK = "equipmentBeaconLedFsmTask"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BEH_CAP = "equipmentBehCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BINDING = "equipmentBinding"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BIOS_DEF = "equipmentBiosDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BIOS_TOKEN_OVERRIDE = "equipmentBiosTokenOverride"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BLADE_AGLIBRARY = "equipmentBladeAGLibrary"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BLADE_AGGREGATION_CAP_REF = "equipmentBladeAggregationCapRef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BLADE_BIOS_CAP_PROVIDER = "equipmentBladeBiosCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BLADE_CAP_PROVIDER = "equipmentBladeCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BLADE_CAP_PROVIDER_TYPE_DEF = "equipmentBladeCapProviderTypeDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BLADE_CONN_DEF = "equipmentBladeConnDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BLADE_IOMCONN_DEF = "equipmentBladeIOMConnDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BLADE_SWITCH_CONN_DEF = "equipmentBladeSwitchConnDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BOARD_CONTROLLER_DEF = "equipmentBoardControllerDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BOOT_DEVICE_CONSTRAINTS = "equipmentBootDeviceConstraints"
    CHANGED_MO_CLASS_ID_EQUIPMENT_BREAKOUT_CAP = "equipmentBreakoutCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CAP_MOD_SPEC = "equipmentCapModSpec"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CARD = "equipmentCard"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CARTRIDGE_CAP_PROVIDER = "equipmentCartridgeCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CATALOG_CAP_PROVIDER = "equipmentCatalogCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS = "equipmentChassis"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_ASSOC_CTX = "equipmentChassisAssocCtx"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_CAP_PROVIDER = "equipmentChassisCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_FSM = "equipmentChassisFsm"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_FSM_STAGE = "equipmentChassisFsmStage"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_FSM_TASK = "equipmentChassisFsmTask"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_INHERIT_POLICY = "equipmentChassisInheritPolicy"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_ISSUES = "equipmentChassisIssues"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_POS_QUAL = "equipmentChassisPosQual"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_PROFILE = "equipmentChassisProfile"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_PROFILE_ASSOC_CTX = "equipmentChassisProfileAssocCtx"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_PROFILE_BINDING = "equipmentChassisProfileBinding"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_PROFILE_FSM = "equipmentChassisProfileFsm"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_PROFILE_FSM_STAGE = "equipmentChassisProfileFsmStage"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_PROFILE_FSM_TASK = "equipmentChassisProfileFsmTask"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_QUAL = "equipmentChassisQual"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_STATS = "equipmentChassisStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CHASSIS_STATS_HIST = "equipmentChassisStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CIMC_VMEDIA = "equipmentCimcVmedia"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CISCO_OS_OPEN_GATE = "equipmentCiscoOsOpenGate"
    CHANGED_MO_CLASS_ID_EQUIPMENT_COMPUTE_CONN = "equipmentComputeConn"
    CHANGED_MO_CLASS_ID_EQUIPMENT_COMPUTE_CONN_POLICY = "equipmentComputeConnPolicy"
    CHANGED_MO_CLASS_ID_EQUIPMENT_COMPUTE_PHYSICAL_CAP_PROVIDER = "equipmentComputePhysicalCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_CONFIG_POLICY = "equipmentConfigPolicy"
    CHANGED_MO_CLASS_ID_EQUIPMENT_COPROCESSOR_UNIT_CAP_PROVIDER = "equipmentCoprocessorUnitCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_DBG_PLUGIN_CAP_PROVIDER = "equipmentDbgPluginCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_DIAG_FEATURE_SUPPORT = "equipmentDiagFeatureSupport"
    CHANGED_MO_CLASS_ID_EQUIPMENT_DIMM_ENTRY = "equipmentDimmEntry"
    CHANGED_MO_CLASS_ID_EQUIPMENT_DIMM_MAPPING = "equipmentDimmMapping"
    CHANGED_MO_CLASS_ID_EQUIPMENT_DISCOVERY_CAP = "equipmentDiscoveryCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_DOWNGRADE_CONSTRAINT = "equipmentDowngradeConstraint"
    CHANGED_MO_CLASS_ID_EQUIPMENT_DRIVE_SEC_CAP = "equipmentDriveSecCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_EMBEDDED_CONTROLLER_CONFIG = "equipmentEmbeddedControllerConfig"
    CHANGED_MO_CLASS_ID_EQUIPMENT_EMBEDDED_STORAGE_DEF = "equipmentEmbeddedStorageDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_ENV_SENSOR = "equipmentEnvSensor"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FAN = "equipmentFan"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FAN_AGGRESSIVE_COOLING_CAP = "equipmentFanAggressiveCoolingCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FAN_MODULE = "equipmentFanModule"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FAN_MODULE_CAP_PROVIDER = "equipmentFanModuleCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FAN_MODULE_DEF = "equipmentFanModuleDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FAN_MODULE_STATS = "equipmentFanModuleStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FAN_MODULE_STATS_HIST = "equipmentFanModuleStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FAN_PRESENCE_DEF = "equipmentFanPresenceDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FAN_STATS = "equipmentFanStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FAN_STATS_HIST = "equipmentFanStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FEX = "equipmentFex"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FEX_CAP_PROVIDER = "equipmentFexCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FEX_ENV_STATS = "equipmentFexEnvStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FEX_ENV_STATS_HIST = "equipmentFexEnvStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FEX_FSM = "equipmentFexFsm"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FEX_FSM_STAGE = "equipmentFexFsmStage"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FEX_FSM_TASK = "equipmentFexFsmTask"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FEX_POWER_SUMMARY = "equipmentFexPowerSummary"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FEX_POWER_SUMMARY_HIST = "equipmentFexPowerSummaryHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FEX_PSU_INPUT_STATS = "equipmentFexPsuInputStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FEX_PSU_INPUT_STATS_HIST = "equipmentFexPsuInputStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FEX_SYSTEM_STATS = "equipmentFexSystemStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FEX_SYSTEM_STATS_HIST = "equipmentFexSystemStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FIRMWARE_CONSTRAINT = "equipmentFirmwareConstraint"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FLASH_LIFE = "equipmentFlashLife"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FLEX_FLASH_NON_REMOVABLE = "equipmentFlexFlashNonRemovable"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FRU_CAP_PROVIDER = "equipmentFruCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_FRU_VARIANT = "equipmentFruVariant"
    CHANGED_MO_CLASS_ID_EQUIPMENT_GEM_CAP_PROVIDER = "equipmentGemCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_GEM_PORT_CAP = "equipmentGemPortCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_GRAPHICS_CARD_CAP_PROVIDER = "equipmentGraphicsCardCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_GRAPHICS_CARD_CAP_REF = "equipmentGraphicsCardCapRef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_HDDFAULT_MON_DEF = "equipmentHDDFaultMonDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_HEALTH_LED = "equipmentHealthLed"
    CHANGED_MO_CLASS_ID_EQUIPMENT_HOLDER = "equipmentHolder"
    CHANGED_MO_CLASS_ID_EQUIPMENT_HOLDER_CAP_PROVIDER = "equipmentHolderCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_HOST_IF_CAP_PROVIDER = "equipmentHostIfCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_HOST_MGMT_CONTROLLER_CAP = "equipmentHostMgmtControllerCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_HW_CAP_DERIVATIVE_PROVIDER = "equipmentHwCapDerivativeProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_HW_CAP_PROVIDER = "equipmentHwCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_HW_REVISION_MODIFIER = "equipmentHwRevisionModifier"
    CHANGED_MO_CLASS_ID_EQUIPMENT_HX_CAP = "equipmentHxCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOCARD = "equipmentIOCard"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOCARD_BASE = "equipmentIOCardBase"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOCARD_BASE_FSM = "equipmentIOCardBaseFsm"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOCARD_BASE_FSM_STAGE = "equipmentIOCardBaseFsmStage"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOCARD_BASE_FSM_TASK = "equipmentIOCardBaseFsmTask"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOCARD_CAP_PROVIDER = "equipmentIOCardCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOCARD_FSM = "equipmentIOCardFsm"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOCARD_FSM_STAGE = "equipmentIOCardFsmStage"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOCARD_FSM_TASK = "equipmentIOCardFsmTask"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOCARD_STATS = "equipmentIOCardStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOCARD_STATS_HIST = "equipmentIOCardStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOCARD_TYPE_DEF = "equipmentIOCardTypeDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOEXPANDER = "equipmentIOExpander"
    CHANGED_MO_CLASS_ID_EQUIPMENT_IOEXPANDER_CAP_PROVIDER = "equipmentIOExpanderCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_INBAND_MGMT_CAP = "equipmentInbandMgmtCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_INDICATOR_LED = "equipmentIndicatorLed"
    CHANGED_MO_CLASS_ID_EQUIPMENT_INIT_CONFIG_POLICY = "equipmentInitConfigPolicy"
    CHANGED_MO_CLASS_ID_EQUIPMENT_INTEGRATED_COMPONENT_CAP_PROVIDER = "equipmentIntegratedComponentCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_INVENTORY_STATUS = "equipmentInventoryStatus"
    CHANGED_MO_CLASS_ID_EQUIPMENT_ITEM = "equipmentItem"
    CHANGED_MO_CLASS_ID_EQUIPMENT_KVM_MGMT_CAP = "equipmentKvmMgmtCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_LED = "equipmentLed"
    CHANGED_MO_CLASS_ID_EQUIPMENT_LOCAL_DISK_CAP_PROVIDER = "equipmentLocalDiskCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_LOCAL_DISK_CONTROLLER_CAP_PROVIDER = "equipmentLocalDiskControllerCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_LOCAL_DISK_CONTROLLER_CAP_REF = "equipmentLocalDiskControllerCapRef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_LOCAL_DISK_CONTROLLER_DEF = "equipmentLocalDiskControllerDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_LOCAL_DISK_CONTROLLER_TYPE_DEF = "equipmentLocalDiskControllerTypeDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_LOCAL_DISK_DEF = "equipmentLocalDiskDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_LOCATOR_LED = "equipmentLocatorLed"
    CHANGED_MO_CLASS_ID_EQUIPMENT_LOCATOR_LED_FSM = "equipmentLocatorLedFsm"
    CHANGED_MO_CLASS_ID_EQUIPMENT_LOCATOR_LED_FSM_STAGE = "equipmentLocatorLedFsmStage"
    CHANGED_MO_CLASS_ID_EQUIPMENT_LOCATOR_LED_FSM_TASK = "equipmentLocatorLedFsmTask"
    CHANGED_MO_CLASS_ID_EQUIPMENT_MANUFACTURING_DEF = "equipmentManufacturingDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_MEMORY_UNIT_CAP_PROVIDER = "equipmentMemoryUnitCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_MEMORY_UNIT_DISCOVERY_MODIFIER_DEF = "equipmentMemoryUnitDiscoveryModifierDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_MGMT_CAP_PROVIDER = "equipmentMgmtCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_MGMT_CONTROLLER_CAP = "equipmentMgmtControllerCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_MGMT_EXT_CAP_PROVIDER = "equipmentMgmtExtCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_MINI_STORAGE_CAP_PROVIDER = "equipmentMiniStorageCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_NETWORK_ELEMENT_FAN_STATS = "equipmentNetworkElementFanStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_NETWORK_ELEMENT_FAN_STATS_HIST = "equipmentNetworkElementFanStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_NON_COPPER_PASSIVE_CAP = "equipmentNonCopperPassiveCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_NVME_DEF = "equipmentNvmeDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_NVME_SWITCH_CONFIG = "equipmentNvmeSwitchConfig"
    CHANGED_MO_CLASS_ID_EQUIPMENT_ONBOARD_DEVICE_DEF = "equipmentOnboardDeviceDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POST = "equipmentPOST"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POSTCODE = "equipmentPOSTCode"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POSTCODE_CONTAINER = "equipmentPOSTCodeContainer"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POSTCODE_DATA = "equipmentPOSTCodeData"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POSTCODE_REPORTER = "equipmentPOSTCodeReporter"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POSTCODE_TEMPLATE = "equipmentPOSTCodeTemplate"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PCI_DEF = "equipmentPciDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PCI_SLOT_ID_ENTRY = "equipmentPciSlotIdEntry"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PCI_SLOT_ID_MAPPING = "equipmentPciSlotIdMapping"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PCI_SLOT_SUB_OEMID_ENTRY = "equipmentPciSlotSubOEMIdEntry"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PCI_SWITCH_CAP_PROVIDER = "equipmentPciSwitchCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PCIE_SLOT_ORIENTATION = "equipmentPcieSlotOrientation"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PERSISTENT_MEMORY_UNIT_CAP_PROVIDER = "equipmentPersistentMemoryUnitCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PERSONALITY = "equipmentPersonality"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PFC_MMU_CAP = "equipmentPfcMmuCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PHYS_DEVICES_PER_BOARD = "equipmentPhysDevicesPerBoard"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PHYSICAL_DEF = "equipmentPhysicalDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PHYSICAL_QUAL = "equipmentPhysicalQual"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PICTURE = "equipmentPicture"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PNUOS_BOOT_MODE = "equipmentPnuosBootMode"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POOL = "equipmentPool"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POOL_POLICY_REF = "equipmentPoolPolicyRef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POOLABLE = "equipmentPoolable"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POOLED = "equipmentPooled"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POOLED_CHASSIS = "equipmentPooledChassis"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POOLED_PHYSICAL = "equipmentPooledPhysical"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POOLING_POLICY = "equipmentPoolingPolicy"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PORT_CAP = "equipmentPortCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PORT_GROUP_AGGREGATION_DEF = "equipmentPortGroupAggregationDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PORT_GROUP_DEF = "equipmentPortGroupDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PORT_GROUP_SW_COMPLEX_DEF = "equipmentPortGroupSwComplexDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PORT_SW_COMPLEX_REF = "equipmentPortSwComplexRef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_POWER_CAP_DEF = "equipmentPowerCapDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PROCESSOR_UNIT_CAP_PROVIDER = "equipmentProcessorUnitCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PROCESSOR_UNIT_DEF = "equipmentProcessorUnitDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PSU = "equipmentPsu"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PSU_CAP_PROVIDER = "equipmentPsuCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PSU_DEF = "equipmentPsuDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PSU_FSM = "equipmentPsuFsm"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PSU_FSM_STAGE = "equipmentPsuFsmStage"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PSU_FSM_TASK = "equipmentPsuFsmTask"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PSU_INPUT_STATS = "equipmentPsuInputStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PSU_INPUT_STATS_HIST = "equipmentPsuInputStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PSU_OUTPUT_STATS = "equipmentPsuOutputStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PSU_OUTPUT_STATS_HIST = "equipmentPsuOutputStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PSU_STATS = "equipmentPsuStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_PSU_STATS_HIST = "equipmentPsuStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_QUAL = "equipmentQual"
    CHANGED_MO_CLASS_ID_EQUIPMENT_QUAL_BASE = "equipmentQualBase"
    CHANGED_MO_CLASS_ID_EQUIPMENT_QUAL_ITEM = "equipmentQualItem"
    CHANGED_MO_CLASS_ID_EQUIPMENT_QUALIFIED_POLICY = "equipmentQualifiedPolicy"
    CHANGED_MO_CLASS_ID_EQUIPMENT_RACK_ENCLOSURE = "equipmentRackEnclosure"
    CHANGED_MO_CLASS_ID_EQUIPMENT_RACK_ENCLOSURE_CAP_PROVIDER = "equipmentRackEnclosureCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_RACK_FAN_MODULE_DEF = "equipmentRackFanModuleDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_RACK_UNIT_CAP_PROVIDER = "equipmentRackUnitCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_RACK_UNIT_FAN_STATS = "equipmentRackUnitFanStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_RACK_UNIT_FAN_STATS_HIST = "equipmentRackUnitFanStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_RACK_UNIT_PSU_STATS = "equipmentRackUnitPsuStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_RACK_UNIT_PSU_STATS_HIST = "equipmentRackUnitPsuStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_RAID_DEF = "equipmentRaidDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_REQUIREMENT = "equipmentRequirement"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SECURE_BOOT = "equipmentSecureBoot"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SECURE_CONTROLLER = "equipmentSecureController"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SECURITY_UNIT_CAP_PROVIDER = "equipmentSecurityUnitCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SERVER_CORRECT_UUID_BEHAVIOR = "equipmentServerCorrectUuidBehavior"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SERVER_FEATURE_CAP = "equipmentServerFeatureCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SERVER_PORT_CAP_PROVIDER = "equipmentServerPortCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SERVER_UNIT_CAP_PROVIDER = "equipmentServerUnitCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SERVICE_DEF = "equipmentServiceDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SHARED_IOMODULE = "equipmentSharedIOModule"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SIOC_CAP_PROVIDER = "equipmentSiocCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SIOC_TEMP_STATS = "equipmentSiocTempStats"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SIOC_TEMP_STATS_HIST = "equipmentSiocTempStatsHist"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SLOT = "equipmentSlot"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SLOT_ARRAY = "equipmentSlotArray"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SLOT_ARRAY_REF = "equipmentSlotArrayRef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SLOT_ENCLOSURE = "equipmentSlotEnclosure"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SLOT_EP = "equipmentSlotEp"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SPDM_CERTIFICATE_CAP = "equipmentSpdmCertificateCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SPEED_COMPATIBILITY = "equipmentSpeedCompatibility"
    CHANGED_MO_CLASS_ID_EQUIPMENT_STATEFUL = "equipmentStateful"
    CHANGED_MO_CLASS_ID_EQUIPMENT_STATEFUL_BLADE_COMP = "equipmentStatefulBladeComp"
    CHANGED_MO_CLASS_ID_EQUIPMENT_STATEFUL_CH_COMP = "equipmentStatefulChComp"
    CHANGED_MO_CLASS_ID_EQUIPMENT_STORAGE_CONTROLLER_CONFIG = "equipmentStorageControllerConfig"
    CHANGED_MO_CLASS_ID_EQUIPMENT_STORAGE_CONTROLLER_SLOT_DEF = "equipmentStorageControllerSlotDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_STORAGE_ENC_CAP_PROVIDER = "equipmentStorageEncCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_STORAGE_LIMIT_CAP = "equipmentStorageLimitCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_STORAGE_NVME_SWITCH_CAP_PROVIDER = "equipmentStorageNvmeSwitchCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_STORAGE_NVME_SWITCH_DEF = "equipmentStorageNvmeSwitchDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_STORAGE_SAS_EXPANDER_CAP_PROVIDER = "equipmentStorageSasExpanderCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_STORAGE_SAS_EXPANDER_CAP_REF = "equipmentStorageSasExpanderCapRef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_STORAGE_SAS_EXPANDER_DEF = "equipmentStorageSasExpanderDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SWITCH_CAP = "equipmentSwitchCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SWITCH_CAP_PROVIDER = "equipmentSwitchCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SWITCH_CARD = "equipmentSwitchCard"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SWITCH_IOCARD = "equipmentSwitchIOCard"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SWITCH_IOCARD_CAP_PROVIDER = "equipmentSwitchIOCardCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SWITCH_IOCARD_FSM = "equipmentSwitchIOCardFsm"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SWITCH_IOCARD_FSM_STAGE = "equipmentSwitchIOCardFsmStage"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SWITCH_IOCARD_FSM_TASK = "equipmentSwitchIOCardFsmTask"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SWITCH_TYPE_DEF = "equipmentSwitchTypeDef"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SYSTEM_IOCONTROLLER = "equipmentSystemIOController"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SYSTEM_IOCONTROLLER_FSM = "equipmentSystemIOControllerFsm"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SYSTEM_IOCONTROLLER_FSM_STAGE = "equipmentSystemIOControllerFsmStage"
    CHANGED_MO_CLASS_ID_EQUIPMENT_SYSTEM_IOCONTROLLER_FSM_TASK = "equipmentSystemIOControllerFsmTask"
    CHANGED_MO_CLASS_ID_EQUIPMENT_TIER = "equipmentTier"
    CHANGED_MO_CLASS_ID_EQUIPMENT_TPM = "equipmentTpm"
    CHANGED_MO_CLASS_ID_EQUIPMENT_TPM_CAP_PROVIDER = "equipmentTpmCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_UNIFIED_PORT_CAP_PROVIDER = "equipmentUnifiedPortCapProvider"
    CHANGED_MO_CLASS_ID_EQUIPMENT_UUID_FEATURE_CAP = "equipmentUuidFeatureCap"
    CHANGED_MO_CLASS_ID_EQUIPMENT_VERSION_CONSTRAINT = "equipmentVersionConstraint"
    CHANGED_MO_CLASS_ID_EQUIPMENT_XCVR = "equipmentXcvr"
    CHANGED_MO_CLASS_ID_ETHER_CIO_EP = "etherCIoEp"
    CHANGED_MO_CLASS_ID_ETHER_CONFIG = "etherConfig"
    CHANGED_MO_CLASS_ID_ETHER_ERR_STATS = "etherErrStats"
    CHANGED_MO_CLASS_ID_ETHER_ERR_STATS_HIST = "etherErrStatsHist"
    CHANGED_MO_CLASS_ID_ETHER_EXTERNAL_EP = "etherExternalEp"
    CHANGED_MO_CLASS_ID_ETHER_EXTERNAL_PC = "etherExternalPc"
    CHANGED_MO_CLASS_ID_ETHER_FCOE_INTERFACE_STATS = "etherFcoeInterfaceStats"
    CHANGED_MO_CLASS_ID_ETHER_FCOE_INTERFACE_STATS_HIST = "etherFcoeInterfaceStatsHist"
    CHANGED_MO_CLASS_ID_ETHER_IF_CONFIG = "etherIfConfig"
    CHANGED_MO_CLASS_ID_ETHER_INT_FIO_EP = "etherIntFIoEp"
    CHANGED_MO_CLASS_ID_ETHER_INTERNAL_PC = "etherInternalPc"
    CHANGED_MO_CLASS_ID_ETHER_LOSS_STATS = "etherLossStats"
    CHANGED_MO_CLASS_ID_ETHER_LOSS_STATS_HIST = "etherLossStatsHist"
    CHANGED_MO_CLASS_ID_ETHER_NI_ERR_STATS = "etherNiErrStats"
    CHANGED_MO_CLASS_ID_ETHER_NI_ERR_STATS_HIST = "etherNiErrStatsHist"
    CHANGED_MO_CLASS_ID_ETHER_NIC_IF_CONFIG = "etherNicIfConfig"
    CHANGED_MO_CLASS_ID_ETHER_PIO = "etherPIo"
    CHANGED_MO_CLASS_ID_ETHER_PIO_END_POINT = "etherPIoEndPoint"
    CHANGED_MO_CLASS_ID_ETHER_PIO_EP = "etherPIoEp"
    CHANGED_MO_CLASS_ID_ETHER_PIO_FSM = "etherPIoFsm"
    CHANGED_MO_CLASS_ID_ETHER_PIO_FSM_STAGE = "etherPIoFsmStage"
    CHANGED_MO_CLASS_ID_ETHER_PAUSE_STATS = "etherPauseStats"
    CHANGED_MO_CLASS_ID_ETHER_PAUSE_STATS_HIST = "etherPauseStatsHist"
    CHANGED_MO_CLASS_ID_ETHER_PC = "etherPc"
    CHANGED_MO_CLASS_ID_ETHER_PORT_CHAN_ID_ELEM = "etherPortChanIdElem"
    CHANGED_MO_CLASS_ID_ETHER_PORT_CHAN_ID_UNIVERSE = "etherPortChanIdUniverse"
    CHANGED_MO_CLASS_ID_ETHER_RX_STATS = "etherRxStats"
    CHANGED_MO_CLASS_ID_ETHER_RX_STATS_HIST = "etherRxStatsHist"
    CHANGED_MO_CLASS_ID_ETHER_SERVER_INT_FIO = "etherServerIntFIo"
    CHANGED_MO_CLASS_ID_ETHER_SERVER_INT_FIO_FSM = "etherServerIntFIoFsm"
    CHANGED_MO_CLASS_ID_ETHER_SERVER_INT_FIO_FSM_STAGE = "etherServerIntFIoFsmStage"
    CHANGED_MO_CLASS_ID_ETHER_SERVER_INT_FIO_FSM_TASK = "etherServerIntFIoFsmTask"
    CHANGED_MO_CLASS_ID_ETHER_SERVER_INT_FIO_PC = "etherServerIntFIoPc"
    CHANGED_MO_CLASS_ID_ETHER_SERVER_INT_FIO_PC_EP = "etherServerIntFIoPcEp"
    CHANGED_MO_CLASS_ID_ETHER_SW_IF_CONFIG = "etherSwIfConfig"
    CHANGED_MO_CLASS_ID_ETHER_SWITCH_INT_FIO = "etherSwitchIntFIo"
    CHANGED_MO_CLASS_ID_ETHER_SWITCH_INT_FIO_PC = "etherSwitchIntFIoPc"
    CHANGED_MO_CLASS_ID_ETHER_SWITCH_INT_FIO_PC_EP = "etherSwitchIntFIoPcEp"
    CHANGED_MO_CLASS_ID_ETHER_TX_STATS = "etherTxStats"
    CHANGED_MO_CLASS_ID_ETHER_TX_STATS_HIST = "etherTxStatsHist"
    CHANGED_MO_CLASS_ID_EVENT_EP_CTRL = "eventEpCtrl"
    CHANGED_MO_CLASS_ID_EVENT_HOLDER = "eventHolder"
    CHANGED_MO_CLASS_ID_EVENT_INST = "eventInst"
    CHANGED_MO_CLASS_ID_EVENT_LOG = "eventLog"
    CHANGED_MO_CLASS_ID_EVENT_POLICY = "eventPolicy"
    CHANGED_MO_CLASS_ID_EVENT_RECORD = "eventRecord"
    CHANGED_MO_CLASS_ID_EXTMGMT_ARP_TARGETS = "extmgmtArpTargets"
    CHANGED_MO_CLASS_ID_EXTMGMT_GATEWAY_PING = "extmgmtGatewayPing"
    CHANGED_MO_CLASS_ID_EXTMGMT_IF = "extmgmtIf"
    CHANGED_MO_CLASS_ID_EXTMGMT_IF_MON_POLICY = "extmgmtIfMonPolicy"
    CHANGED_MO_CLASS_ID_EXTMGMT_MII_STATUS = "extmgmtMiiStatus"
    CHANGED_MO_CLASS_ID_EXTMGMT_NDISC_TARGETS = "extmgmtNdiscTargets"
    CHANGED_MO_CLASS_ID_EXTPOL_CLIENT = "extpolClient"
    CHANGED_MO_CLASS_ID_EXTPOL_CLIENT_CONT = "extpolClientCont"
    CHANGED_MO_CLASS_ID_EXTPOL_CONNECTOR = "extpolConnector"
    CHANGED_MO_CLASS_ID_EXTPOL_CONNECTOR_CONTAINER = "extpolConnectorContainer"
    CHANGED_MO_CLASS_ID_EXTPOL_CONTROLLER = "extpolController"
    CHANGED_MO_CLASS_ID_EXTPOL_CONTROLLER_CONT = "extpolControllerCont"
    CHANGED_MO_CLASS_ID_EXTPOL_EP = "extpolEp"
    CHANGED_MO_CLASS_ID_EXTPOL_EP_FSM = "extpolEpFsm"
    CHANGED_MO_CLASS_ID_EXTPOL_EP_FSM_STAGE = "extpolEpFsmStage"
    CHANGED_MO_CLASS_ID_EXTPOL_EP_FSM_TASK = "extpolEpFsmTask"
    CHANGED_MO_CLASS_ID_EXTPOL_PROVIDER = "extpolProvider"
    CHANGED_MO_CLASS_ID_EXTPOL_PROVIDER_CONT = "extpolProviderCont"
    CHANGED_MO_CLASS_ID_EXTPOL_PROVIDER_FSM = "extpolProviderFsm"
    CHANGED_MO_CLASS_ID_EXTPOL_PROVIDER_FSM_STAGE = "extpolProviderFsmStage"
    CHANGED_MO_CLASS_ID_EXTPOL_PROVIDER_FSM_TASK = "extpolProviderFsmTask"
    CHANGED_MO_CLASS_ID_EXTPOL_REGISTRY = "extpolRegistry"
    CHANGED_MO_CLASS_ID_EXTPOL_REGISTRY_FSM = "extpolRegistryFsm"
    CHANGED_MO_CLASS_ID_EXTPOL_REGISTRY_FSM_STAGE = "extpolRegistryFsmStage"
    CHANGED_MO_CLASS_ID_EXTPOL_REGISTRY_FSM_TASK = "extpolRegistryFsmTask"
    CHANGED_MO_CLASS_ID_EXTPOL_SVC = "extpolSvc"
    CHANGED_MO_CLASS_ID_EXTPOL_SYSTEM_CONTEXT = "extpolSystemContext"
    CHANGED_MO_CLASS_ID_EXTVMM_EP = "extvmmEp"
    CHANGED_MO_CLASS_ID_EXTVMM_EP_FSM = "extvmmEpFsm"
    CHANGED_MO_CLASS_ID_EXTVMM_EP_FSM_STAGE = "extvmmEpFsmStage"
    CHANGED_MO_CLASS_ID_EXTVMM_EP_FSM_TASK = "extvmmEpFsmTask"
    CHANGED_MO_CLASS_ID_EXTVMM_FNDREFERENCE = "extvmmFNDReference"
    CHANGED_MO_CLASS_ID_EXTVMM_FABRIC_NETWORK = "extvmmFabricNetwork"
    CHANGED_MO_CLASS_ID_EXTVMM_FABRIC_NETWORK_DEFINITION = "extvmmFabricNetworkDefinition"
    CHANGED_MO_CLASS_ID_EXTVMM_KEY_INST = "extvmmKeyInst"
    CHANGED_MO_CLASS_ID_EXTVMM_KEY_RING = "extvmmKeyRing"
    CHANGED_MO_CLASS_ID_EXTVMM_KEY_STORE = "extvmmKeyStore"
    CHANGED_MO_CLASS_ID_EXTVMM_KEY_STORE_FSM = "extvmmKeyStoreFsm"
    CHANGED_MO_CLASS_ID_EXTVMM_KEY_STORE_FSM_STAGE = "extvmmKeyStoreFsmStage"
    CHANGED_MO_CLASS_ID_EXTVMM_KEY_STORE_FSM_TASK = "extvmmKeyStoreFsmTask"
    CHANGED_MO_CLASS_ID_EXTVMM_MASTER_EXT_KEY = "extvmmMasterExtKey"
    CHANGED_MO_CLASS_ID_EXTVMM_MASTER_EXT_KEY_FSM = "extvmmMasterExtKeyFsm"
    CHANGED_MO_CLASS_ID_EXTVMM_MASTER_EXT_KEY_FSM_STAGE = "extvmmMasterExtKeyFsmStage"
    CHANGED_MO_CLASS_ID_EXTVMM_MASTER_EXT_KEY_FSM_TASK = "extvmmMasterExtKeyFsmTask"
    CHANGED_MO_CLASS_ID_EXTVMM_NETWORK_SETS = "extvmmNetworkSets"
    CHANGED_MO_CLASS_ID_EXTVMM_NETWORK_SETS_FSM = "extvmmNetworkSetsFsm"
    CHANGED_MO_CLASS_ID_EXTVMM_NETWORK_SETS_FSM_STAGE = "extvmmNetworkSetsFsmStage"
    CHANGED_MO_CLASS_ID_EXTVMM_NETWORK_SETS_FSM_TASK = "extvmmNetworkSetsFsmTask"
    CHANGED_MO_CLASS_ID_EXTVMM_PROVIDER = "extvmmProvider"
    CHANGED_MO_CLASS_ID_EXTVMM_PROVIDER_FSM = "extvmmProviderFsm"
    CHANGED_MO_CLASS_ID_EXTVMM_PROVIDER_FSM_STAGE = "extvmmProviderFsmStage"
    CHANGED_MO_CLASS_ID_EXTVMM_PROVIDER_FSM_TASK = "extvmmProviderFsmTask"
    CHANGED_MO_CLASS_ID_EXTVMM_SWITCH_DEL_TASK = "extvmmSwitchDelTask"
    CHANGED_MO_CLASS_ID_EXTVMM_SWITCH_DEL_TASK_FSM = "extvmmSwitchDelTaskFsm"
    CHANGED_MO_CLASS_ID_EXTVMM_SWITCH_DEL_TASK_FSM_STAGE = "extvmmSwitchDelTaskFsmStage"
    CHANGED_MO_CLASS_ID_EXTVMM_SWITCH_DEL_TASK_FSM_TASK = "extvmmSwitchDelTaskFsmTask"
    CHANGED_MO_CLASS_ID_EXTVMM_SWITCH_SET = "extvmmSwitchSet"
    CHANGED_MO_CLASS_ID_EXTVMM_UP_LINK_PP = "extvmmUpLinkPP"
    CHANGED_MO_CLASS_ID_EXTVMM_VMNDREF = "extvmmVMNDRef"
    CHANGED_MO_CLASS_ID_EXTVMM_VMNETWORK = "extvmmVMNetwork"
    CHANGED_MO_CLASS_ID_EXTVMM_VMNETWORK_DEFINITION = "extvmmVMNetworkDefinition"
    CHANGED_MO_CLASS_ID_EXTVMM_VMNETWORK_SETS = "extvmmVMNetworkSets"
    CHANGED_MO_CLASS_ID_FABRIC_ADCE_SW_SRV_EP = "fabricADceSwSrvEp"
    CHANGED_MO_CLASS_ID_FABRIC_AETH_ESTC_EP = "fabricAEthEstcEp"
    CHANGED_MO_CLASS_ID_FABRIC_AETH_LAN_EP = "fabricAEthLanEp"
    CHANGED_MO_CLASS_ID_FABRIC_AFC_ESTC_EP = "fabricAFcEstcEp"
    CHANGED_MO_CLASS_ID_FABRIC_AFC_SAN_EP = "fabricAFcSanEp"
    CHANGED_MO_CLASS_ID_FABRIC_AFCOE_ESTC_EP = "fabricAFcoeEstcEp"
    CHANGED_MO_CLASS_ID_FABRIC_AFCOE_SAN_EP = "fabricAFcoeSanEp"
    CHANGED_MO_CLASS_ID_FABRIC_ANET_GROUP = "fabricANetGroup"
    CHANGED_MO_CLASS_ID_FABRIC_ANET_GROUP_REF = "fabricANetGroupRef"
    CHANGED_MO_CLASS_ID_FABRIC_ASAN_GROUP = "fabricASanGroup"
    CHANGED_MO_CLASS_ID_FABRIC_AVLAN = "fabricAVlan"
    CHANGED_MO_CLASS_ID_FABRIC_AVSAN = "fabricAVsan"
    CHANGED_MO_CLASS_ID_FABRIC_BHVLAN = "fabricBHVlan"
    CHANGED_MO_CLASS_ID_FABRIC_BASE_NET_GROUP = "fabricBaseNetGroup"
    CHANGED_MO_CLASS_ID_FABRIC_BREAKOUT = "fabricBreakout"
    CHANGED_MO_CLASS_ID_FABRIC_CIO_EP = "fabricCIoEp"
    CHANGED_MO_CLASS_ID_FABRIC_CABLING = "fabricCabling"
    CHANGED_MO_CLASS_ID_FABRIC_CABLING_SW = "fabricCablingSw"
    CHANGED_MO_CLASS_ID_FABRIC_CARTRIDGE_PH_EP = "fabricCartridgePhEp"
    CHANGED_MO_CLASS_ID_FABRIC_CARTRIDGE_SLOT_EP = "fabricCartridgeSlotEp"
    CHANGED_MO_CLASS_ID_FABRIC_CARTRIDGE_SLOT_EP_FSM = "fabricCartridgeSlotEpFsm"
    CHANGED_MO_CLASS_ID_FABRIC_CARTRIDGE_SLOT_EP_FSM_STAGE = "fabricCartridgeSlotEpFsmStage"
    CHANGED_MO_CLASS_ID_FABRIC_CARTRIDGE_SLOT_EP_FSM_TASK = "fabricCartridgeSlotEpFsmTask"
    CHANGED_MO_CLASS_ID_FABRIC_CDP_LINK_POLICY = "fabricCdpLinkPolicy"
    CHANGED_MO_CLASS_ID_FABRIC_CHANGED_OBJECT_REF = "fabricChangedObjectRef"
    CHANGED_MO_CLASS_ID_FABRIC_CHASSIS_EP = "fabricChassisEp"
    CHANGED_MO_CLASS_ID_FABRIC_CLOUD = "fabricCloud"
    CHANGED_MO_CLASS_ID_FABRIC_COMPUTE_EP = "fabricComputeEp"
    CHANGED_MO_CLASS_ID_FABRIC_COMPUTE_MSLOT_EP = "fabricComputeMSlotEp"
    CHANGED_MO_CLASS_ID_FABRIC_COMPUTE_MSLOT_EP_FSM = "fabricComputeMSlotEpFsm"
    CHANGED_MO_CLASS_ID_FABRIC_COMPUTE_MSLOT_EP_FSM_STAGE = "fabricComputeMSlotEpFsmStage"
    CHANGED_MO_CLASS_ID_FABRIC_COMPUTE_MSLOT_EP_FSM_TASK = "fabricComputeMSlotEpFsmTask"
    CHANGED_MO_CLASS_ID_FABRIC_COMPUTE_PH_EP = "fabricComputePhEp"
    CHANGED_MO_CLASS_ID_FABRIC_COMPUTE_SLOT_EP = "fabricComputeSlotEp"
    CHANGED_MO_CLASS_ID_FABRIC_COMPUTE_SLOT_EP_FSM = "fabricComputeSlotEpFsm"
    CHANGED_MO_CLASS_ID_FABRIC_COMPUTE_SLOT_EP_FSM_STAGE = "fabricComputeSlotEpFsmStage"
    CHANGED_MO_CLASS_ID_FABRIC_COMPUTE_SLOT_EP_FSM_TASK = "fabricComputeSlotEpFsmTask"
    CHANGED_MO_CLASS_ID_FABRIC_DCE_SRV = "fabricDceSrv"
    CHANGED_MO_CLASS_ID_FABRIC_DCE_SW_SRV = "fabricDceSwSrv"
    CHANGED_MO_CLASS_ID_FABRIC_DCE_SW_SRV_EP = "fabricDceSwSrvEp"
    CHANGED_MO_CLASS_ID_FABRIC_DCE_SW_SRV_PC = "fabricDceSwSrvPc"
    CHANGED_MO_CLASS_ID_FABRIC_DCE_SW_SRV_PC_EP = "fabricDceSwSrvPcEp"
    CHANGED_MO_CLASS_ID_FABRIC_DOMAIN = "fabricDomain"
    CHANGED_MO_CLASS_ID_FABRIC_EP = "fabricEp"
    CHANGED_MO_CLASS_ID_FABRIC_EP_MGR = "fabricEpMgr"
    CHANGED_MO_CLASS_ID_FABRIC_EP_MGR_FSM = "fabricEpMgrFsm"
    CHANGED_MO_CLASS_ID_FABRIC_EP_MGR_FSM_STAGE = "fabricEpMgrFsmStage"
    CHANGED_MO_CLASS_ID_FABRIC_EP_MGR_FSM_TASK = "fabricEpMgrFsmTask"
    CHANGED_MO_CLASS_ID_FABRIC_EP_VLAN = "fabricEpVlan"
    CHANGED_MO_CLASS_ID_FABRIC_EP_VSAN = "fabricEpVsan"
    CHANGED_MO_CLASS_ID_FABRIC_EQUIPMENT_EP = "fabricEquipmentEp"
    CHANGED_MO_CLASS_ID_FABRIC_ESTC_EP = "fabricEstcEp"
    CHANGED_MO_CLASS_ID_FABRIC_ESTC_PC = "fabricEstcPc"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_CDP_POLICY = "fabricEthCdpPolicy"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_ESTC = "fabricEthEstc"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_ESTC_CLOUD = "fabricEthEstcCloud"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_ESTC_EP = "fabricEthEstcEp"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_ESTC_PC = "fabricEthEstcPc"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_ESTC_PC_EP = "fabricEthEstcPcEp"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_FLOW_MON_LAN = "fabricEthFlowMonLan"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_FLOW_MON_SRC_REF = "fabricEthFlowMonSrcRef"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_LAN = "fabricEthLan"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_LAN_EP = "fabricEthLanEp"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_LAN_FLOW_MON = "fabricEthLanFlowMon"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_LAN_FLOW_MON_COLLECTOR = "fabricEthLanFlowMonCollector"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_LAN_FLOW_MON_EXPORTER = "fabricEthLanFlowMonExporter"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_LAN_FLOW_MON_SRC_EP = "fabricEthLanFlowMonSrcEp"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_LAN_FLOW_MONITOR = "fabricEthLanFlowMonitor"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_LAN_FLOW_MONITORING = "fabricEthLanFlowMonitoring"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_LAN_PC = "fabricEthLanPc"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_LAN_PC_EP = "fabricEthLanPcEp"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_LINK_POLICY = "fabricEthLinkPolicy"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_LINK_PROFILE = "fabricEthLinkProfile"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_MON = "fabricEthMon"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_MON_DEST_EP = "fabricEthMonDestEp"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_MON_FILT_EP = "fabricEthMonFiltEp"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_MON_FILT_REF = "fabricEthMonFiltRef"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_MON_LAN = "fabricEthMonLan"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_MON_SRC_EP = "fabricEthMonSrcEp"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_MON_SRC_REF = "fabricEthMonSrcRef"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_TARGET_EP = "fabricEthTargetEp"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_UDLD_POLICY = "fabricEthUdldPolicy"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_VLAN_PC = "fabricEthVlanPc"
    CHANGED_MO_CLASS_ID_FABRIC_ETH_VLAN_PORT_EP = "fabricEthVlanPortEp"
    CHANGED_MO_CLASS_ID_FABRIC_EXTERNAL = "fabricExternal"
    CHANGED_MO_CLASS_ID_FABRIC_EXTERNAL_EP = "fabricExternalEp"
    CHANGED_MO_CLASS_ID_FABRIC_EXTERNAL_ESTC = "fabricExternalEstc"
    CHANGED_MO_CLASS_ID_FABRIC_EXTERNAL_PC = "fabricExternalPc"
    CHANGED_MO_CLASS_ID_FABRIC_FC_ENDPOINT = "fabricFcEndpoint"
    CHANGED_MO_CLASS_ID_FABRIC_FC_ESTC = "fabricFcEstc"
    CHANGED_MO_CLASS_ID_FABRIC_FC_ESTC_CLOUD = "fabricFcEstcCloud"
    CHANGED_MO_CLASS_ID_FABRIC_FC_ESTC_EP = "fabricFcEstcEp"
    CHANGED_MO_CLASS_ID_FABRIC_FC_MON = "fabricFcMon"
    CHANGED_MO_CLASS_ID_FABRIC_FC_MON_DEST_EP = "fabricFcMonDestEp"
    CHANGED_MO_CLASS_ID_FABRIC_FC_MON_FILT_EP = "fabricFcMonFiltEp"
    CHANGED_MO_CLASS_ID_FABRIC_FC_MON_FILT_REF = "fabricFcMonFiltRef"
    CHANGED_MO_CLASS_ID_FABRIC_FC_MON_SAN = "fabricFcMonSan"
    CHANGED_MO_CLASS_ID_FABRIC_FC_MON_SRC_EP = "fabricFcMonSrcEp"
    CHANGED_MO_CLASS_ID_FABRIC_FC_MON_SRC_REF = "fabricFcMonSrcRef"
    CHANGED_MO_CLASS_ID_FABRIC_FC_SAN = "fabricFcSan"
    CHANGED_MO_CLASS_ID_FABRIC_FC_SAN_EP = "fabricFcSanEp"
    CHANGED_MO_CLASS_ID_FABRIC_FC_SAN_PC = "fabricFcSanPc"
    CHANGED_MO_CLASS_ID_FABRIC_FC_SAN_PC_EP = "fabricFcSanPcEp"
    CHANGED_MO_CLASS_ID_FABRIC_FC_USER_ZONE = "fabricFcUserZone"
    CHANGED_MO_CLASS_ID_FABRIC_FC_VSAN_PC = "fabricFcVsanPc"
    CHANGED_MO_CLASS_ID_FABRIC_FC_VSAN_PORT_EP = "fabricFcVsanPortEp"
    CHANGED_MO_CLASS_ID_FABRIC_FC_ZONE_PROFILE = "fabricFcZoneProfile"
    CHANGED_MO_CLASS_ID_FABRIC_FCOE_ESTC_EP = "fabricFcoeEstcEp"
    CHANGED_MO_CLASS_ID_FABRIC_FCOE_SAN_EP = "fabricFcoeSanEp"
    CHANGED_MO_CLASS_ID_FABRIC_FCOE_SAN_PC = "fabricFcoeSanPc"
    CHANGED_MO_CLASS_ID_FABRIC_FCOE_SAN_PC_EP = "fabricFcoeSanPcEp"
    CHANGED_MO_CLASS_ID_FABRIC_FCOE_VSAN_PC = "fabricFcoeVsanPc"
    CHANGED_MO_CLASS_ID_FABRIC_FCOE_VSAN_PORT_EP = "fabricFcoeVsanPortEp"
    CHANGED_MO_CLASS_ID_FABRIC_FLOW_MON = "fabricFlowMon"
    CHANGED_MO_CLASS_ID_FABRIC_FLOW_MON_COLLECTOR = "fabricFlowMonCollector"
    CHANGED_MO_CLASS_ID_FABRIC_FLOW_MON_DEFINITION = "fabricFlowMonDefinition"
    CHANGED_MO_CLASS_ID_FABRIC_FLOW_MON_EXPORTER = "fabricFlowMonExporter"
    CHANGED_MO_CLASS_ID_FABRIC_FLOW_MON_EXPORTER_PROFILE = "fabricFlowMonExporterProfile"
    CHANGED_MO_CLASS_ID_FABRIC_FLOW_MON_ITEM = "fabricFlowMonItem"
    CHANGED_MO_CLASS_ID_FABRIC_FLOW_MON_SRC_EP = "fabricFlowMonSrcEp"
    CHANGED_MO_CLASS_ID_FABRIC_FLOW_MON_SRC_REF = "fabricFlowMonSrcRef"
    CHANGED_MO_CLASS_ID_FABRIC_FLOW_MONITOR = "fabricFlowMonitor"
    CHANGED_MO_CLASS_ID_FABRIC_FLOW_MONITORING_CATEGORY = "fabricFlowMonitoringCategory"
    CHANGED_MO_CLASS_ID_FABRIC_IF = "fabricIf"
    CHANGED_MO_CLASS_ID_FABRIC_INTERNAL = "fabricInternal"
    CHANGED_MO_CLASS_ID_FABRIC_INTERNAL_DCE_SRV = "fabricInternalDceSrv"
    CHANGED_MO_CLASS_ID_FABRIC_INTERNAL_EP = "fabricInternalEp"
    CHANGED_MO_CLASS_ID_FABRIC_INTERNAL_PC = "fabricInternalPc"
    CHANGED_MO_CLASS_ID_FABRIC_LACP_POLICY = "fabricLacpPolicy"
    CHANGED_MO_CLASS_ID_FABRIC_LAN = "fabricLan"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_ACCESS_MGR = "fabricLanAccessMgr"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_CLOUD = "fabricLanCloud"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_CLOUD_FSM = "fabricLanCloudFsm"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_CLOUD_FSM_STAGE = "fabricLanCloudFsmStage"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_CLOUD_FSM_TASK = "fabricLanCloudFsmTask"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_CLOUD_POLICY = "fabricLanCloudPolicy"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_EP = "fabricLanEp"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_FLOW_MON = "fabricLanFlowMon"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_FLOW_MON_COLLECTOR = "fabricLanFlowMonCollector"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_FLOW_MON_EXPORTER = "fabricLanFlowMonExporter"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_FLOW_MON_SRC_EP = "fabricLanFlowMonSrcEp"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_FLOW_MONITOR = "fabricLanFlowMonitor"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_MON_CLOUD = "fabricLanMonCloud"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_PC = "fabricLanPc"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_PIN_GROUP = "fabricLanPinGroup"
    CHANGED_MO_CLASS_ID_FABRIC_LAN_PIN_TARGET = "fabricLanPinTarget"
    CHANGED_MO_CLASS_ID_FABRIC_LAST_ACKED_SLOT = "fabricLastAckedSlot"
    CHANGED_MO_CLASS_ID_FABRIC_LINK_POLICY = "fabricLinkPolicy"
    CHANGED_MO_CLASS_ID_FABRIC_LOCALE = "fabricLocale"
    CHANGED_MO_CLASS_ID_FABRIC_MON = "fabricMon"
    CHANGED_MO_CLASS_ID_FABRIC_MON_DEST_EP = "fabricMonDestEp"
    CHANGED_MO_CLASS_ID_FABRIC_MON_FILT_REF = "fabricMonFiltRef"
    CHANGED_MO_CLASS_ID_FABRIC_MON_SRC_EP = "fabricMonSrcEp"
    CHANGED_MO_CLASS_ID_FABRIC_MON_SRC_FILT_EP = "fabricMonSrcFiltEp"
    CHANGED_MO_CLASS_ID_FABRIC_MON_SRC_REF = "fabricMonSrcRef"
    CHANGED_MO_CLASS_ID_FABRIC_MULTICAST_POLICY = "fabricMulticastPolicy"
    CHANGED_MO_CLASS_ID_FABRIC_NET_GROUP = "fabricNetGroup"
    CHANGED_MO_CLASS_ID_FABRIC_NET_GROUP_REF = "fabricNetGroupRef"
    CHANGED_MO_CLASS_ID_FABRIC_NETFLOW_COLLECTOR = "fabricNetflowCollector"
    CHANGED_MO_CLASS_ID_FABRIC_NETFLOW_IPV4_ADDR = "fabricNetflowIPv4Addr"
    CHANGED_MO_CLASS_ID_FABRIC_NETFLOW_MON_EXPORTER = "fabricNetflowMonExporter"
    CHANGED_MO_CLASS_ID_FABRIC_NETFLOW_MON_EXPORTER_REF = "fabricNetflowMonExporterRef"
    CHANGED_MO_CLASS_ID_FABRIC_NETFLOW_MON_SESSION = "fabricNetflowMonSession"
    CHANGED_MO_CLASS_ID_FABRIC_NETFLOW_MON_SRC_EP = "fabricNetflowMonSrcEp"
    CHANGED_MO_CLASS_ID_FABRIC_NETFLOW_MON_SRC_REF = "fabricNetflowMonSrcRef"
    CHANGED_MO_CLASS_ID_FABRIC_NETFLOW_MONITOR = "fabricNetflowMonitor"
    CHANGED_MO_CLASS_ID_FABRIC_NETFLOW_MONITOR_REF = "fabricNetflowMonitorRef"
    CHANGED_MO_CLASS_ID_FABRIC_NETFLOW_TIMEOUT_POLICY = "fabricNetflowTimeoutPolicy"
    CHANGED_MO_CLASS_ID_FABRIC_ORG_VLAN_POLICY = "fabricOrgVlanPolicy"
    CHANGED_MO_CLASS_ID_FABRIC_PIO_EP = "fabricPIoEp"
    CHANGED_MO_CLASS_ID_FABRIC_PATH = "fabricPath"
    CHANGED_MO_CLASS_ID_FABRIC_PATH_CONN = "fabricPathConn"
    CHANGED_MO_CLASS_ID_FABRIC_PATH_EP = "fabricPathEp"
    CHANGED_MO_CLASS_ID_FABRIC_PIN_GROUP = "fabricPinGroup"
    CHANGED_MO_CLASS_ID_FABRIC_PIN_TARGET = "fabricPinTarget"
    CHANGED_MO_CLASS_ID_FABRIC_POOLABLE_VLAN = "fabricPoolableVlan"
    CHANGED_MO_CLASS_ID_FABRIC_POOLED_VLAN = "fabricPooledVlan"
    CHANGED_MO_CLASS_ID_FABRIC_RESERVED_VLAN = "fabricReservedVlan"
    CHANGED_MO_CLASS_ID_FABRIC_RESERVED_VLAN_FSM = "fabricReservedVlanFsm"
    CHANGED_MO_CLASS_ID_FABRIC_RESERVED_VLAN_FSM_STAGE = "fabricReservedVlanFsmStage"
    CHANGED_MO_CLASS_ID_FABRIC_RESERVED_VLAN_FSM_TASK = "fabricReservedVlanFsmTask"
    CHANGED_MO_CLASS_ID_FABRIC_SAN = "fabricSan"
    CHANGED_MO_CLASS_ID_FABRIC_SAN_CLOUD = "fabricSanCloud"
    CHANGED_MO_CLASS_ID_FABRIC_SAN_CLOUD_FSM = "fabricSanCloudFsm"
    CHANGED_MO_CLASS_ID_FABRIC_SAN_CLOUD_FSM_STAGE = "fabricSanCloudFsmStage"
    CHANGED_MO_CLASS_ID_FABRIC_SAN_CLOUD_FSM_TASK = "fabricSanCloudFsmTask"
    CHANGED_MO_CLASS_ID_FABRIC_SAN_EP = "fabricSanEp"
    CHANGED_MO_CLASS_ID_FABRIC_SAN_GROUP = "fabricSanGroup"
    CHANGED_MO_CLASS_ID_FABRIC_SAN_GROUP_REF = "fabricSanGroupRef"
    CHANGED_MO_CLASS_ID_FABRIC_SAN_MON_CLOUD = "fabricSanMonCloud"
    CHANGED_MO_CLASS_ID_FABRIC_SAN_PC = "fabricSanPc"
    CHANGED_MO_CLASS_ID_FABRIC_SAN_PIN_GROUP = "fabricSanPinGroup"
    CHANGED_MO_CLASS_ID_FABRIC_SAN_PIN_TARGET = "fabricSanPinTarget"
    CHANGED_MO_CLASS_ID_FABRIC_SUB_GROUP = "fabricSubGroup"
    CHANGED_MO_CLASS_ID_FABRIC_SW_CH_EP = "fabricSwChEp"
    CHANGED_MO_CLASS_ID_FABRIC_SW_CH_PH_EP = "fabricSwChPhEp"
    CHANGED_MO_CLASS_ID_FABRIC_SW_SRV_EP = "fabricSwSrvEp"
    CHANGED_MO_CLASS_ID_FABRIC_SW_SRV_PC = "fabricSwSrvPc"
    CHANGED_MO_CLASS_ID_FABRIC_SW_SUB_GROUP = "fabricSwSubGroup"
    CHANGED_MO_CLASS_ID_FABRIC_TARGET_EP = "fabricTargetEp"
    CHANGED_MO_CLASS_ID_FABRIC_UDLD_LINK_POLICY = "fabricUdldLinkPolicy"
    CHANGED_MO_CLASS_ID_FABRIC_UDLD_POLICY = "fabricUdldPolicy"
    CHANGED_MO_CLASS_ID_FABRIC_VCON = "fabricVCon"
    CHANGED_MO_CLASS_ID_FABRIC_VCON_PROFILE = "fabricVConProfile"
    CHANGED_MO_CLASS_ID_FABRIC_VLAN = "fabricVlan"
    CHANGED_MO_CLASS_ID_FABRIC_VLAN_EP = "fabricVlanEp"
    CHANGED_MO_CLASS_ID_FABRIC_VLAN_GROUP_PERMIT = "fabricVlanGroupPermit"
    CHANGED_MO_CLASS_ID_FABRIC_VLAN_GROUP_REQ = "fabricVlanGroupReq"
    CHANGED_MO_CLASS_ID_FABRIC_VLAN_PERMIT = "fabricVlanPermit"
    CHANGED_MO_CLASS_ID_FABRIC_VLAN_REQ = "fabricVlanReq"
    CHANGED_MO_CLASS_ID_FABRIC_VNET_EP = "fabricVnetEp"
    CHANGED_MO_CLASS_ID_FABRIC_VNET_EP_SYNC_EP = "fabricVnetEpSyncEp"
    CHANGED_MO_CLASS_ID_FABRIC_VNET_EP_SYNC_EP_FSM = "fabricVnetEpSyncEpFsm"
    CHANGED_MO_CLASS_ID_FABRIC_VNET_EP_SYNC_EP_FSM_STAGE = "fabricVnetEpSyncEpFsmStage"
    CHANGED_MO_CLASS_ID_FABRIC_VNET_EP_SYNC_EP_FSM_TASK = "fabricVnetEpSyncEpFsmTask"
    CHANGED_MO_CLASS_ID_FABRIC_VNET_GROUP_PERMIT = "fabricVnetGroupPermit"
    CHANGED_MO_CLASS_ID_FABRIC_VNET_GROUP_REQ = "fabricVnetGroupReq"
    CHANGED_MO_CLASS_ID_FABRIC_VNET_PERMIT = "fabricVnetPermit"
    CHANGED_MO_CLASS_ID_FABRIC_VNET_REQ = "fabricVnetReq"
    CHANGED_MO_CLASS_ID_FABRIC_VSAN = "fabricVsan"
    CHANGED_MO_CLASS_ID_FABRIC_VSAN_EP = "fabricVsanEp"
    CHANGED_MO_CLASS_ID_FABRIC_VSAN_MEMBERSHIP = "fabricVsanMembership"
    CHANGED_MO_CLASS_ID_FABRIC_ZONE_ID_UNIVERSE = "fabricZoneIdUniverse"
    CHANGED_MO_CLASS_ID_FAULT_AFFECTED_CLASS = "faultAffectedClass"
    CHANGED_MO_CLASS_ID_FAULT_BASE_HOLDER = "faultBaseHolder"
    CHANGED_MO_CLASS_ID_FAULT_BASE_POLICY = "faultBasePolicy"
    CHANGED_MO_CLASS_ID_FAULT_HOLDER = "faultHolder"
    CHANGED_MO_CLASS_ID_FAULT_INST = "faultInst"
    CHANGED_MO_CLASS_ID_FAULT_LOCAL_TYPED_HOLDER = "faultLocalTypedHolder"
    CHANGED_MO_CLASS_ID_FAULT_POLICY = "faultPolicy"
    CHANGED_MO_CLASS_ID_FAULT_SUPPRESS_POLICY = "faultSuppressPolicy"
    CHANGED_MO_CLASS_ID_FAULT_SUPPRESS_POLICY_ITEM = "faultSuppressPolicyItem"
    CHANGED_MO_CLASS_ID_FAULT_SUPPRESS_TASK = "faultSuppressTask"
    CHANGED_MO_CLASS_ID_FC_CONFIG = "fcConfig"
    CHANGED_MO_CLASS_ID_FC_ERR_STATS = "fcErrStats"
    CHANGED_MO_CLASS_ID_FC_ERR_STATS_HIST = "fcErrStatsHist"
    CHANGED_MO_CLASS_ID_FC_IF_CONFIG = "fcIfConfig"
    CHANGED_MO_CLASS_ID_FC_NIC_IF_CONFIG = "fcNicIfConfig"
    CHANGED_MO_CLASS_ID_FC_PIO = "fcPIo"
    CHANGED_MO_CLASS_ID_FC_PIO_FSM = "fcPIoFsm"
    CHANGED_MO_CLASS_ID_FC_PIO_FSM_STAGE = "fcPIoFsmStage"
    CHANGED_MO_CLASS_ID_FC_STATS = "fcStats"
    CHANGED_MO_CLASS_ID_FC_STATS_HIST = "fcStatsHist"
    CHANGED_MO_CLASS_ID_FC_SW_IF_CONFIG = "fcSwIfConfig"
    CHANGED_MO_CLASS_ID_FCPOOL_ADDR = "fcpoolAddr"
    CHANGED_MO_CLASS_ID_FCPOOL_BLOCK = "fcpoolBlock"
    CHANGED_MO_CLASS_ID_FCPOOL_BOOT_TARGET = "fcpoolBootTarget"
    CHANGED_MO_CLASS_ID_FCPOOL_FORMAT = "fcpoolFormat"
    CHANGED_MO_CLASS_ID_FCPOOL_INITIATOR = "fcpoolInitiator"
    CHANGED_MO_CLASS_ID_FCPOOL_INITIATOR_EP = "fcpoolInitiatorEp"
    CHANGED_MO_CLASS_ID_FCPOOL_INITIATORS = "fcpoolInitiators"
    CHANGED_MO_CLASS_ID_FCPOOL_OUI = "fcpoolOui"
    CHANGED_MO_CLASS_ID_FCPOOL_OUIS = "fcpoolOuis"
    CHANGED_MO_CLASS_ID_FCPOOL_OUIS_FSM = "fcpoolOuisFsm"
    CHANGED_MO_CLASS_ID_FCPOOL_OUIS_FSM_STAGE = "fcpoolOuisFsmStage"
    CHANGED_MO_CLASS_ID_FCPOOL_OUIS_FSM_TASK = "fcpoolOuisFsmTask"
    CHANGED_MO_CLASS_ID_FCPOOL_POOLABLE = "fcpoolPoolable"
    CHANGED_MO_CLASS_ID_FCPOOL_UNIVERSE = "fcpoolUniverse"
    CHANGED_MO_CLASS_ID_FEATURE_BASE_REF = "featureBaseRef"
    CHANGED_MO_CLASS_ID_FEATURE_CONTEXT_EP = "featureContextEp"
    CHANGED_MO_CLASS_ID_FEATURE_DEFINITION = "featureDefinition"
    CHANGED_MO_CLASS_ID_FEATURE_DEFINITION_INSTANCE = "featureDefinitionInstance"
    CHANGED_MO_CLASS_ID_FEATURE_DEFINITION_REF = "featureDefinitionRef"
    CHANGED_MO_CLASS_ID_FEATURE_FRU_CAP_PROVIDER_INSTANCE = "featureFruCapProviderInstance"
    CHANGED_MO_CLASS_ID_FEATURE_FRU_CAP_PROVIDER_REF = "featureFruCapProviderRef"
    CHANGED_MO_CLASS_ID_FEATURE_PROVIDER = "featureProvider"
    CHANGED_MO_CLASS_ID_FEATURE_PROVIDER_INSTANCE = "featureProviderInstance"
    CHANGED_MO_CLASS_ID_FIRMWARE_ABUNDLE_TYPE_CAP_PROVIDER = "firmwareABundleTypeCapProvider"
    CHANGED_MO_CLASS_ID_FIRMWARE_ACHASSIS_CONSTRAINT = "firmwareAChassisConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_ACOMPONENT_SPEC = "firmwareAComponentSpec"
    CHANGED_MO_CLASS_ID_FIRMWARE_ACONSTRAINT = "firmwareAConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_AEXCLUDE_COMPONENT = "firmwareAExcludeComponent"
    CHANGED_MO_CLASS_ID_FIRMWARE_ACK = "firmwareAck"
    CHANGED_MO_CLASS_ID_FIRMWARE_ACTIVITY = "firmwareActivity"
    CHANGED_MO_CLASS_ID_FIRMWARE_ACTIVITY_TRIGGER = "firmwareActivityTrigger"
    CHANGED_MO_CLASS_ID_FIRMWARE_AUTO_SYNC_POLICY = "firmwareAutoSyncPolicy"
    CHANGED_MO_CLASS_ID_FIRMWARE_BACKUP_VERSION_HOLDER = "firmwareBackupVersionHolder"
    CHANGED_MO_CLASS_ID_FIRMWARE_BLADE = "firmwareBlade"
    CHANGED_MO_CLASS_ID_FIRMWARE_BOOT_DEFINITION = "firmwareBootDefinition"
    CHANGED_MO_CLASS_ID_FIRMWARE_BOOT_UNIT = "firmwareBootUnit"
    CHANGED_MO_CLASS_ID_FIRMWARE_BUNDLE_INFO = "firmwareBundleInfo"
    CHANGED_MO_CLASS_ID_FIRMWARE_BUNDLE_INFO_DIGEST = "firmwareBundleInfoDigest"
    CHANGED_MO_CLASS_ID_FIRMWARE_BUNDLE_TYPE = "firmwareBundleType"
    CHANGED_MO_CLASS_ID_FIRMWARE_BUNDLE_TYPE_CAP_PROVIDER = "firmwareBundleTypeCapProvider"
    CHANGED_MO_CLASS_ID_FIRMWARE_CAP_PROVIDER = "firmwareCapProvider"
    CHANGED_MO_CLASS_ID_FIRMWARE_CATALOG_PACK = "firmwareCatalogPack"
    CHANGED_MO_CLASS_ID_FIRMWARE_CATALOGUE = "firmwareCatalogue"
    CHANGED_MO_CLASS_ID_FIRMWARE_CHASSIS_COMPONENT_SPEC = "firmwareChassisComponentSpec"
    CHANGED_MO_CLASS_ID_FIRMWARE_CHASSIS_PACK = "firmwareChassisPack"
    CHANGED_MO_CLASS_ID_FIRMWARE_CHASSIS_PACK_MOD_IMPACT = "firmwareChassisPackModImpact"
    CHANGED_MO_CLASS_ID_FIRMWARE_COMP_ITEM = "firmwareCompItem"
    CHANGED_MO_CLASS_ID_FIRMWARE_COMP_SOURCE = "firmwareCompSource"
    CHANGED_MO_CLASS_ID_FIRMWARE_COMP_TARGET = "firmwareCompTarget"
    CHANGED_MO_CLASS_ID_FIRMWARE_COMPONENT_SPEC = "firmwareComponentSpec"
    CHANGED_MO_CLASS_ID_FIRMWARE_COMPUTE_HOST_PACK = "firmwareComputeHostPack"
    CHANGED_MO_CLASS_ID_FIRMWARE_COMPUTE_MGMT_PACK = "firmwareComputeMgmtPack"
    CHANGED_MO_CLASS_ID_FIRMWARE_COMPUTE_PACK = "firmwareComputePack"
    CHANGED_MO_CLASS_ID_FIRMWARE_CONNECTION_MANAGEMENT_CHASSIS_CONSTRAINT = "firmwareConnectionManagementChassisConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_CONSTRAINTS = "firmwareConstraints"
    CHANGED_MO_CLASS_ID_FIRMWARE_DEPENDENCY = "firmwareDependency"
    CHANGED_MO_CLASS_ID_FIRMWARE_DIST_IMAGE = "firmwareDistImage"
    CHANGED_MO_CLASS_ID_FIRMWARE_DISTRIBUTABLE = "firmwareDistributable"
    CHANGED_MO_CLASS_ID_FIRMWARE_DISTRIBUTABLE_FSM = "firmwareDistributableFsm"
    CHANGED_MO_CLASS_ID_FIRMWARE_DISTRIBUTABLE_FSM_STAGE = "firmwareDistributableFsmStage"
    CHANGED_MO_CLASS_ID_FIRMWARE_DISTRIBUTABLE_FSM_TASK = "firmwareDistributableFsmTask"
    CHANGED_MO_CLASS_ID_FIRMWARE_DOWNLOADER = "firmwareDownloader"
    CHANGED_MO_CLASS_ID_FIRMWARE_DOWNLOADER_FSM = "firmwareDownloaderFsm"
    CHANGED_MO_CLASS_ID_FIRMWARE_DOWNLOADER_FSM_STAGE = "firmwareDownloaderFsmStage"
    CHANGED_MO_CLASS_ID_FIRMWARE_DOWNLOADER_FSM_TASK = "firmwareDownloaderFsmTask"
    CHANGED_MO_CLASS_ID_FIRMWARE_DRIVE_SECURITY_CONSTRAINT = "firmwareDriveSecurityConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_DUAL_VIC_CHASSIS_CONSTRAINT = "firmwareDualVicChassisConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_DUAL_VIC_SERVER_CONSTRAINT = "firmwareDualVicServerConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_EXCLUDE_CHASSIS_COMPONENT = "firmwareExcludeChassisComponent"
    CHANGED_MO_CLASS_ID_FIRMWARE_EXCLUDE_SERVER_COMPONENT = "firmwareExcludeServerComponent"
    CHANGED_MO_CLASS_ID_FIRMWARE_FILE_UNIT = "firmwareFileUnit"
    CHANGED_MO_CLASS_ID_FIRMWARE_HOST = "firmwareHost"
    CHANGED_MO_CLASS_ID_FIRMWARE_HOST_PACK_MOD_IMPACT = "firmwareHostPackModImpact"
    CHANGED_MO_CLASS_ID_FIRMWARE_IMAGE = "firmwareImage"
    CHANGED_MO_CLASS_ID_FIRMWARE_IMAGE_FSM = "firmwareImageFsm"
    CHANGED_MO_CLASS_ID_FIRMWARE_IMAGE_FSM_STAGE = "firmwareImageFsmStage"
    CHANGED_MO_CLASS_ID_FIRMWARE_IMAGE_FSM_TASK = "firmwareImageFsmTask"
    CHANGED_MO_CLASS_ID_FIRMWARE_IMAGE_LOCK = "firmwareImageLock"
    CHANGED_MO_CLASS_ID_FIRMWARE_INFRA = "firmwareInfra"
    CHANGED_MO_CLASS_ID_FIRMWARE_INFRA_PACK = "firmwareInfraPack"
    CHANGED_MO_CLASS_ID_FIRMWARE_INSTALL_IMPACT = "firmwareInstallImpact"
    CHANGED_MO_CLASS_ID_FIRMWARE_INSTALLABLE = "firmwareInstallable"
    CHANGED_MO_CLASS_ID_FIRMWARE_MODULE = "firmwareModule"
    CHANGED_MO_CLASS_ID_FIRMWARE_PCHSTORAGE_CONFIG_CONSTRAINT = "firmwarePCHStorageConfigConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_PACK = "firmwarePack"
    CHANGED_MO_CLASS_ID_FIRMWARE_PACK_ITEM = "firmwarePackItem"
    CHANGED_MO_CLASS_ID_FIRMWARE_PLATFORM_BUNDLE_TYPE_CAP_PROVIDER = "firmwarePlatformBundleTypeCapProvider"
    CHANGED_MO_CLASS_ID_FIRMWARE_PROCESSOR_TYPE_CONSTRAINT = "firmwareProcessorTypeConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_RACK = "firmwareRack"
    CHANGED_MO_CLASS_ID_FIRMWARE_RACK_POWER_CAP_CONSTRAINT = "firmwareRackPowerCapConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_RUNNING = "firmwareRunning"
    CHANGED_MO_CLASS_ID_FIRMWARE_SECOND_CONTROLLER_CHASSIS_CONSTRAINT = "firmwareSecondControllerChassisConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_SECOND_CONTROLLER_SERVER_CONSTRAINT = "firmwareSecondControllerServerConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_SECURE_FPGA = "firmwareSecureFPGA"
    CHANGED_MO_CLASS_ID_FIRMWARE_SERVER_CHASSIS_CONSTRAINT = "firmwareServerChassisConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_SERVER_TYPE_CONSTRAINT = "firmwareServerTypeConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_SERVICE_PACK = "firmwareServicePack"
    CHANGED_MO_CLASS_ID_FIRMWARE_SINGLE_PATH_CHASSIS_CONSTRAINT = "firmwareSinglePathChassisConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_SPEC = "firmwareSpec"
    CHANGED_MO_CLASS_ID_FIRMWARE_STATUS = "firmwareStatus"
    CHANGED_MO_CLASS_ID_FIRMWARE_SYSTEM = "firmwareSystem"
    CHANGED_MO_CLASS_ID_FIRMWARE_SYSTEM_COMP_CHECK_RESULT = "firmwareSystemCompCheckResult"
    CHANGED_MO_CLASS_ID_FIRMWARE_SYSTEM_FSM = "firmwareSystemFsm"
    CHANGED_MO_CLASS_ID_FIRMWARE_SYSTEM_FSM_STAGE = "firmwareSystemFsmStage"
    CHANGED_MO_CLASS_ID_FIRMWARE_SYSTEM_FSM_TASK = "firmwareSystemFsmTask"
    CHANGED_MO_CLASS_ID_FIRMWARE_TPMCONSTRAINT = "firmwareTPMConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_TYPE = "firmwareType"
    CHANGED_MO_CLASS_ID_FIRMWARE_UCSC_INFO = "firmwareUcscInfo"
    CHANGED_MO_CLASS_ID_FIRMWARE_UNIT = "firmwareUnit"
    CHANGED_MO_CLASS_ID_FIRMWARE_UPDATABLE = "firmwareUpdatable"
    CHANGED_MO_CLASS_ID_FIRMWARE_UPGRADE_CONSTRAINT = "firmwareUpgradeConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_UPGRADE_DETAIL = "firmwareUpgradeDetail"
    CHANGED_MO_CLASS_ID_FIRMWARE_UPGRADE_INFO = "firmwareUpgradeInfo"
    CHANGED_MO_CLASS_ID_FIRMWARE_VIC_SLOT_CONSTRAINT = "firmwareVicSlotConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_VNIC_CDN_CONSTRAINT = "firmwareVnicCdnConstraint"
    CHANGED_MO_CLASS_ID_FIRMWARE_WATERBAY_SIOC_SERVER_CONSTRAINT = "firmwareWaterbaySiocServerConstraint"
    CHANGED_MO_CLASS_ID_FLOWCTRL_DEFINITION = "flowctrlDefinition"
    CHANGED_MO_CLASS_ID_FLOWCTRL_ITEM = "flowctrlItem"
    CHANGED_MO_CLASS_ID_FSM_FSM = "fsmFsm"
    CHANGED_MO_CLASS_ID_FSM_STAGE = "fsmStage"
    CHANGED_MO_CLASS_ID_FSM_STATUS = "fsmStatus"
    CHANGED_MO_CLASS_ID_FSM_TASK = "fsmTask"
    CHANGED_MO_CLASS_ID_GMETA_CLASS = "gmetaClass"
    CHANGED_MO_CLASS_ID_GMETA_EP = "gmetaEp"
    CHANGED_MO_CLASS_ID_GMETA_HOLDER = "gmetaHolder"
    CHANGED_MO_CLASS_ID_GMETA_HOLDER_FSM = "gmetaHolderFsm"
    CHANGED_MO_CLASS_ID_GMETA_HOLDER_FSM_STAGE = "gmetaHolderFsmStage"
    CHANGED_MO_CLASS_ID_GMETA_HOLDER_FSM_TASK = "gmetaHolderFsmTask"
    CHANGED_MO_CLASS_ID_GMETA_POLICY_MAP_ELEMENT = "gmetaPolicyMapElement"
    CHANGED_MO_CLASS_ID_GMETA_POLICY_MAP_HOLDER = "gmetaPolicyMapHolder"
    CHANGED_MO_CLASS_ID_GMETA_PROP = "gmetaProp"
    CHANGED_MO_CLASS_ID_GRAPHICS_CARD = "graphicsCard"
    CHANGED_MO_CLASS_ID_GRAPHICS_CONTROLLER = "graphicsController"
    CHANGED_MO_CLASS_ID_HOSTIMG_POLICY = "hostimgPolicy"
    CHANGED_MO_CLASS_ID_HOSTIMG_TARGET = "hostimgTarget"
    CHANGED_MO_CLASS_ID_IDENT_IDENT_CTX = "identIdentCtx"
    CHANGED_MO_CLASS_ID_IDENT_IDENT_REQUEST = "identIdentRequest"
    CHANGED_MO_CLASS_ID_IDENT_IDENT_REQUEST_FSM = "identIdentRequestFsm"
    CHANGED_MO_CLASS_ID_IDENT_IDENT_REQUEST_FSM_STAGE = "identIdentRequestFsmStage"
    CHANGED_MO_CLASS_ID_IDENT_IDENT_REQUEST_FSM_TASK = "identIdentRequestFsmTask"
    CHANGED_MO_CLASS_ID_IDENT_META_SYSTEM = "identMetaSystem"
    CHANGED_MO_CLASS_ID_IDENT_META_SYSTEM_FSM = "identMetaSystemFsm"
    CHANGED_MO_CLASS_ID_IDENT_META_SYSTEM_FSM_STAGE = "identMetaSystemFsmStage"
    CHANGED_MO_CLASS_ID_IDENT_META_SYSTEM_FSM_TASK = "identMetaSystemFsmTask"
    CHANGED_MO_CLASS_ID_IDENT_META_VERSE = "identMetaVerse"
    CHANGED_MO_CLASS_ID_IDENT_REQUEST_EP = "identRequestEp"
    CHANGED_MO_CLASS_ID_IDENT_SYS_INFO = "identSysInfo"
    CHANGED_MO_CLASS_ID_IMGPROV_POLICY = "imgprovPolicy"
    CHANGED_MO_CLASS_ID_IMGPROV_TARGET = "imgprovTarget"
    CHANGED_MO_CLASS_ID_IMGSEC_KEY = "imgsecKey"
    CHANGED_MO_CLASS_ID_IMGSEC_POLICY = "imgsecPolicy"
    CHANGED_MO_CLASS_ID_INITIATOR_EP = "initiatorEp"
    CHANGED_MO_CLASS_ID_INITIATOR_FC_INITIATOR_EP = "initiatorFcInitiatorEp"
    CHANGED_MO_CLASS_ID_INITIATOR_GROUP_EP = "initiatorGroupEp"
    CHANGED_MO_CLASS_ID_INITIATOR_ISCSI_INITIATOR_EP = "initiatorIScsiInitiatorEp"
    CHANGED_MO_CLASS_ID_INITIATOR_INITIATOR_EP = "initiatorInitiatorEp"
    CHANGED_MO_CLASS_ID_INITIATOR_LUN_EP = "initiatorLunEp"
    CHANGED_MO_CLASS_ID_INITIATOR_MEMBER_EP = "initiatorMemberEp"
    CHANGED_MO_CLASS_ID_INITIATOR_REQUESTOR_EP = "initiatorRequestorEp"
    CHANGED_MO_CLASS_ID_INITIATOR_REQUESTOR_GRP_EP = "initiatorRequestorGrpEp"
    CHANGED_MO_CLASS_ID_INITIATOR_STORE_EP = "initiatorStoreEp"
    CHANGED_MO_CLASS_ID_INITIATOR_UNIT_EP = "initiatorUnitEp"
    CHANGED_MO_CLASS_ID_IP_DNS_SUFFIX = "ipDnsSuffix"
    CHANGED_MO_CLASS_ID_IP_IPV4_DNS = "ipIPv4Dns"
    CHANGED_MO_CLASS_ID_IP_IPV4_WINS_SERVER = "ipIPv4WinsServer"
    CHANGED_MO_CLASS_ID_IP_IP_V4_ADDR = "ipIpV4Addr"
    CHANGED_MO_CLASS_ID_IP_IP_V4_STATIC_ADDR = "ipIpV4StaticAddr"
    CHANGED_MO_CLASS_ID_IP_IP_V4_STATIC_TARGET_ADDR = "ipIpV4StaticTargetAddr"
    CHANGED_MO_CLASS_ID_IP_SERVICE_IF = "ipServiceIf"
    CHANGED_MO_CLASS_ID_IPPOOL_ADDR = "ippoolAddr"
    CHANGED_MO_CLASS_ID_IPPOOL_BLOCK = "ippoolBlock"
    CHANGED_MO_CLASS_ID_IPPOOL_IP_V6_ADDR = "ippoolIpV6Addr"
    CHANGED_MO_CLASS_ID_IPPOOL_IP_V6_BLOCK = "ippoolIpV6Block"
    CHANGED_MO_CLASS_ID_IPPOOL_IP_V6_POOLED = "ippoolIpV6Pooled"
    CHANGED_MO_CLASS_ID_IPPOOL_POOL = "ippoolPool"
    CHANGED_MO_CLASS_ID_IPPOOL_POOLABLE = "ippoolPoolable"
    CHANGED_MO_CLASS_ID_IPPOOL_POOLED = "ippoolPooled"
    CHANGED_MO_CLASS_ID_IPPOOL_UNIVERSE = "ippoolUniverse"
    CHANGED_MO_CLASS_ID_IQNPOOL_ABS_BLOCK = "iqnpoolAbsBlock"
    CHANGED_MO_CLASS_ID_IQNPOOL_ADDR = "iqnpoolAddr"
    CHANGED_MO_CLASS_ID_IQNPOOL_BLOCK = "iqnpoolBlock"
    CHANGED_MO_CLASS_ID_IQNPOOL_FORMAT = "iqnpoolFormat"
    CHANGED_MO_CLASS_ID_IQNPOOL_POOL = "iqnpoolPool"
    CHANGED_MO_CLASS_ID_IQNPOOL_POOLABLE = "iqnpoolPoolable"
    CHANGED_MO_CLASS_ID_IQNPOOL_POOLED = "iqnpoolPooled"
    CHANGED_MO_CLASS_ID_IQNPOOL_TRANSPORT_BLOCK = "iqnpoolTransportBlock"
    CHANGED_MO_CLASS_ID_IQNPOOL_UNIVERSE = "iqnpoolUniverse"
    CHANGED_MO_CLASS_ID_ISCSI_AUTH_PROFILE = "iscsiAuthProfile"
    CHANGED_MO_CLASS_ID_LICENSE_CAP_PROVIDER = "licenseCapProvider"
    CHANGED_MO_CLASS_ID_LICENSE_CONTENTS = "licenseContents"
    CHANGED_MO_CLASS_ID_LICENSE_DOWNLOADER = "licenseDownloader"
    CHANGED_MO_CLASS_ID_LICENSE_DOWNLOADER_FSM = "licenseDownloaderFsm"
    CHANGED_MO_CLASS_ID_LICENSE_DOWNLOADER_FSM_STAGE = "licenseDownloaderFsmStage"
    CHANGED_MO_CLASS_ID_LICENSE_DOWNLOADER_FSM_TASK = "licenseDownloaderFsmTask"
    CHANGED_MO_CLASS_ID_LICENSE_EP = "licenseEp"
    CHANGED_MO_CLASS_ID_LICENSE_FEATURE = "licenseFeature"
    CHANGED_MO_CLASS_ID_LICENSE_FEATURE_CAP_PROVIDER = "licenseFeatureCapProvider"
    CHANGED_MO_CLASS_ID_LICENSE_FEATURE_LINE = "licenseFeatureLine"
    CHANGED_MO_CLASS_ID_LICENSE_FILE = "licenseFile"
    CHANGED_MO_CLASS_ID_LICENSE_FILE_FSM = "licenseFileFsm"
    CHANGED_MO_CLASS_ID_LICENSE_FILE_FSM_STAGE = "licenseFileFsmStage"
    CHANGED_MO_CLASS_ID_LICENSE_FILE_FSM_TASK = "licenseFileFsmTask"
    CHANGED_MO_CLASS_ID_LICENSE_INSTANCE = "licenseInstance"
    CHANGED_MO_CLASS_ID_LICENSE_INSTANCE_FSM = "licenseInstanceFsm"
    CHANGED_MO_CLASS_ID_LICENSE_INSTANCE_FSM_STAGE = "licenseInstanceFsmStage"
    CHANGED_MO_CLASS_ID_LICENSE_INSTANCE_FSM_TASK = "licenseInstanceFsmTask"
    CHANGED_MO_CLASS_ID_LICENSE_PROP = "licenseProp"
    CHANGED_MO_CLASS_ID_LICENSE_SERVER_HOST_ID = "licenseServerHostId"
    CHANGED_MO_CLASS_ID_LICENSE_SOURCE = "licenseSource"
    CHANGED_MO_CLASS_ID_LICENSE_SOURCE_FILE = "licenseSourceFile"
    CHANGED_MO_CLASS_ID_LICENSE_TARGET = "licenseTarget"
    CHANGED_MO_CLASS_ID_LLDP_ACQUIRED = "lldpAcquired"
    CHANGED_MO_CLASS_ID_LS_AGENT_POLICY = "lsAgentPolicy"
    CHANGED_MO_CLASS_ID_LS_BINDING = "lsBinding"
    CHANGED_MO_CLASS_ID_LS_COMPUTE_BINDING = "lsComputeBinding"
    CHANGED_MO_CLASS_ID_LS_FC_LOCALE = "lsFcLocale"
    CHANGED_MO_CLASS_ID_LS_FC_ZONE = "lsFcZone"
    CHANGED_MO_CLASS_ID_LS_FC_ZONE_GROUP = "lsFcZoneGroup"
    CHANGED_MO_CLASS_ID_LS_FC_ZONE_MEMBER = "lsFcZoneMember"
    CHANGED_MO_CLASS_ID_LS_IDENTITY_INFO = "lsIdentityInfo"
    CHANGED_MO_CLASS_ID_LS_ISSUES = "lsIssues"
    CHANGED_MO_CLASS_ID_LS_POWER = "lsPower"
    CHANGED_MO_CLASS_ID_LS_REQUIREMENT = "lsRequirement"
    CHANGED_MO_CLASS_ID_LS_SERVER = "lsServer"
    CHANGED_MO_CLASS_ID_LS_SERVER_ASSOC_CTX = "lsServerAssocCtx"
    CHANGED_MO_CLASS_ID_LS_SERVER_EXTENSION = "lsServerExtension"
    CHANGED_MO_CLASS_ID_LS_SERVER_FSM = "lsServerFsm"
    CHANGED_MO_CLASS_ID_LS_SERVER_FSM_STAGE = "lsServerFsmStage"
    CHANGED_MO_CLASS_ID_LS_SERVER_FSM_TASK = "lsServerFsmTask"
    CHANGED_MO_CLASS_ID_LS_TIER = "lsTier"
    CHANGED_MO_CLASS_ID_LS_UUID_HISTORY = "lsUuidHistory"
    CHANGED_MO_CLASS_ID_LS_VCON_ASSIGN = "lsVConAssign"
    CHANGED_MO_CLASS_ID_LS_VERSION_BEH = "lsVersionBeh"
    CHANGED_MO_CLASS_ID_LS_ZONE_INITIATOR_MEMBER = "lsZoneInitiatorMember"
    CHANGED_MO_CLASS_ID_LS_ZONE_TARGET_MEMBER = "lsZoneTargetMember"
    CHANGED_MO_CLASS_ID_LSBOOT_ADEF = "lsbootADef"
    CHANGED_MO_CLASS_ID_LSBOOT_BOOT_SECURITY = "lsbootBootSecurity"
    CHANGED_MO_CLASS_ID_LSBOOT_CATEGORY = "lsbootCategory"
    CHANGED_MO_CLASS_ID_LSBOOT_DEF = "lsbootDef"
    CHANGED_MO_CLASS_ID_LSBOOT_DEFAULT_LOCAL_IMAGE = "lsbootDefaultLocalImage"
    CHANGED_MO_CLASS_ID_LSBOOT_EFISHELL = "lsbootEFIShell"
    CHANGED_MO_CLASS_ID_LSBOOT_EMBEDDED_LOCAL_DISK_IMAGE = "lsbootEmbeddedLocalDiskImage"
    CHANGED_MO_CLASS_ID_LSBOOT_EMBEDDED_LOCAL_DISK_IMAGE_PATH = "lsbootEmbeddedLocalDiskImagePath"
    CHANGED_MO_CLASS_ID_LSBOOT_EMBEDDED_LOCAL_LUN_IMAGE = "lsbootEmbeddedLocalLunImage"
    CHANGED_MO_CLASS_ID_LSBOOT_ISCSI = "lsbootIScsi"
    CHANGED_MO_CLASS_ID_LSBOOT_ISCSI_IMAGE_PATH = "lsbootIScsiImagePath"
    CHANGED_MO_CLASS_ID_LSBOOT_IMAGE = "lsbootImage"
    CHANGED_MO_CLASS_ID_LSBOOT_IMAGE_PATH = "lsbootImagePath"
    CHANGED_MO_CLASS_ID_LSBOOT_ITEM = "lsbootItem"
    CHANGED_MO_CLASS_ID_LSBOOT_LAN = "lsbootLan"
    CHANGED_MO_CLASS_ID_LSBOOT_LAN_IMAGE_PATH = "lsbootLanImagePath"
    CHANGED_MO_CLASS_ID_LSBOOT_LOCAL_DISK_IMAGE = "lsbootLocalDiskImage"
    CHANGED_MO_CLASS_ID_LSBOOT_LOCAL_DISK_IMAGE_PATH = "lsbootLocalDiskImagePath"
    CHANGED_MO_CLASS_ID_LSBOOT_LOCAL_HDD_IMAGE = "lsbootLocalHddImage"
    CHANGED_MO_CLASS_ID_LSBOOT_LOCAL_IMAGE = "lsbootLocalImage"
    CHANGED_MO_CLASS_ID_LSBOOT_LOCAL_LUN_IMAGE_PATH = "lsbootLocalLunImagePath"
    CHANGED_MO_CLASS_ID_LSBOOT_LOCAL_MEDIA_ITEM = "lsbootLocalMediaItem"
    CHANGED_MO_CLASS_ID_LSBOOT_LOCAL_STORAGE = "lsbootLocalStorage"
    CHANGED_MO_CLASS_ID_LSBOOT_NVME = "lsbootNvme"
    CHANGED_MO_CLASS_ID_LSBOOT_NVME_DEVICE = "lsbootNvmeDevice"
    CHANGED_MO_CLASS_ID_LSBOOT_NVME_DISK_SSD = "lsbootNvmeDiskSsd"
    CHANGED_MO_CLASS_ID_LSBOOT_NVME_PCI_SSD = "lsbootNvmePciSsd"
    CHANGED_MO_CLASS_ID_LSBOOT_POLICY = "lsbootPolicy"
    CHANGED_MO_CLASS_ID_LSBOOT_REMOTE_IMAGE = "lsbootRemoteImage"
    CHANGED_MO_CLASS_ID_LSBOOT_SAN = "lsbootSan"
    CHANGED_MO_CLASS_ID_LSBOOT_SAN_CAT_SAN_IMAGE = "lsbootSanCatSanImage"
    CHANGED_MO_CLASS_ID_LSBOOT_SAN_CAT_SAN_IMAGE_PATH = "lsbootSanCatSanImagePath"
    CHANGED_MO_CLASS_ID_LSBOOT_SAN_IMAGE = "lsbootSanImage"
    CHANGED_MO_CLASS_ID_LSBOOT_SAN_IMAGE_PATH = "lsbootSanImagePath"
    CHANGED_MO_CLASS_ID_LSBOOT_STORAGE = "lsbootStorage"
    CHANGED_MO_CLASS_ID_LSBOOT_UEFIBOOT_PARAM = "lsbootUEFIBootParam"
    CHANGED_MO_CLASS_ID_LSBOOT_USB_EXTERNAL_IMAGE = "lsbootUsbExternalImage"
    CHANGED_MO_CLASS_ID_LSBOOT_USB_FLASH_STORAGE_IMAGE = "lsbootUsbFlashStorageImage"
    CHANGED_MO_CLASS_ID_LSBOOT_USB_INTERNAL_IMAGE = "lsbootUsbInternalImage"
    CHANGED_MO_CLASS_ID_LSBOOT_VIRTUAL_MEDIA = "lsbootVirtualMedia"
    CHANGED_MO_CLASS_ID_LSMAINT_ACK = "lsmaintAck"
    CHANGED_MO_CLASS_ID_LSMAINT_MAINT_POLICY = "lsmaintMaintPolicy"
    CHANGED_MO_CLASS_ID_LSTORAGE_ASLOT = "lstorageASlot"
    CHANGED_MO_CLASS_ID_LSTORAGE_CONTROLLER_DEF = "lstorageControllerDef"
    CHANGED_MO_CLASS_ID_LSTORAGE_CONTROLLER_MODE_CONFIG = "lstorageControllerModeConfig"
    CHANGED_MO_CLASS_ID_LSTORAGE_CONTROLLER_QUALIFIER = "lstorageControllerQualifier"
    CHANGED_MO_CLASS_ID_LSTORAGE_CONTROLLER_REF = "lstorageControllerRef"
    CHANGED_MO_CLASS_ID_LSTORAGE_DAS_SCSI_LUN = "lstorageDasScsiLun"
    CHANGED_MO_CLASS_ID_LSTORAGE_DISK_GROUP_CONFIG = "lstorageDiskGroupConfig"
    CHANGED_MO_CLASS_ID_LSTORAGE_DISK_GROUP_CONFIG_DEF = "lstorageDiskGroupConfigDef"
    CHANGED_MO_CLASS_ID_LSTORAGE_DISK_GROUP_CONFIG_POLICY = "lstorageDiskGroupConfigPolicy"
    CHANGED_MO_CLASS_ID_LSTORAGE_DISK_GROUP_QUALIFIER = "lstorageDiskGroupQualifier"
    CHANGED_MO_CLASS_ID_LSTORAGE_DISK_SLOT = "lstorageDiskSlot"
    CHANGED_MO_CLASS_ID_LSTORAGE_DISK_ZONING_CONFIG = "lstorageDiskZoningConfig"
    CHANGED_MO_CLASS_ID_LSTORAGE_DISK_ZONING_CONFIG_DEF = "lstorageDiskZoningConfigDef"
    CHANGED_MO_CLASS_ID_LSTORAGE_DISK_ZONING_POLICY = "lstorageDiskZoningPolicy"
    CHANGED_MO_CLASS_ID_LSTORAGE_DRIVE_SECURITY = "lstorageDriveSecurity"
    CHANGED_MO_CLASS_ID_LSTORAGE_ITEM = "lstorageItem"
    CHANGED_MO_CLASS_ID_LSTORAGE_LOCAL = "lstorageLocal"
    CHANGED_MO_CLASS_ID_LSTORAGE_LOCAL_CONFIG = "lstorageLocalConfig"
    CHANGED_MO_CLASS_ID_LSTORAGE_LOCAL_DEF = "lstorageLocalDef"
    CHANGED_MO_CLASS_ID_LSTORAGE_LOCAL_DISK_CONFIG_REF = "lstorageLocalDiskConfigRef"
    CHANGED_MO_CLASS_ID_LSTORAGE_LOCAL_DISK_REF = "lstorageLocalDiskRef"
    CHANGED_MO_CLASS_ID_LSTORAGE_LOGIN = "lstorageLogin"
    CHANGED_MO_CLASS_ID_LSTORAGE_LUN_SET_CONFIG = "lstorageLunSetConfig"
    CHANGED_MO_CLASS_ID_LSTORAGE_LUN_SET_DISK_SLOT = "lstorageLunSetDiskSlot"
    CHANGED_MO_CLASS_ID_LSTORAGE_PROFILE = "lstorageProfile"
    CHANGED_MO_CLASS_ID_LSTORAGE_PROFILE_BASE = "lstorageProfileBase"
    CHANGED_MO_CLASS_ID_LSTORAGE_PROFILE_BINDING = "lstorageProfileBinding"
    CHANGED_MO_CLASS_ID_LSTORAGE_PROFILE_BINDING_BASE = "lstorageProfileBindingBase"
    CHANGED_MO_CLASS_ID_LSTORAGE_PROFILE_DEF = "lstorageProfileDef"
    CHANGED_MO_CLASS_ID_LSTORAGE_REMOTE = "lstorageRemote"
    CHANGED_MO_CLASS_ID_LSTORAGE_REMOTE_CONFIG = "lstorageRemoteConfig"
    CHANGED_MO_CLASS_ID_LSTORAGE_REMOTE_DEF = "lstorageRemoteDef"
    CHANGED_MO_CLASS_ID_LSTORAGE_SAS_EXPANDER_CONFIG_POLICY = "lstorageSasExpanderConfigPolicy"
    CHANGED_MO_CLASS_ID_LSTORAGE_SCSI_LUN = "lstorageScsiLun"
    CHANGED_MO_CLASS_ID_LSTORAGE_SECURITY = "lstorageSecurity"
    CHANGED_MO_CLASS_ID_LSTORAGE_VIRTUAL_DRIVE_DEF = "lstorageVirtualDriveDef"
    CHANGED_MO_CLASS_ID_MACPOOL_ADDR = "macpoolAddr"
    CHANGED_MO_CLASS_ID_MACPOOL_BLOCK = "macpoolBlock"
    CHANGED_MO_CLASS_ID_MACPOOL_FORMAT = "macpoolFormat"
    CHANGED_MO_CLASS_ID_MACPOOL_POOL = "macpoolPool"
    CHANGED_MO_CLASS_ID_MACPOOL_POOLABLE = "macpoolPoolable"
    CHANGED_MO_CLASS_ID_MACPOOL_POOLED = "macpoolPooled"
    CHANGED_MO_CLASS_ID_MACPOOL_UNIVERSE = "macpoolUniverse"
    CHANGED_MO_CLASS_ID_MEMORY_AUNIT = "memoryAUnit"
    CHANGED_MO_CLASS_ID_MEMORY_ARRAY = "memoryArray"
    CHANGED_MO_CLASS_ID_MEMORY_ARRAY_ENV_STATS = "memoryArrayEnvStats"
    CHANGED_MO_CLASS_ID_MEMORY_ARRAY_ENV_STATS_HIST = "memoryArrayEnvStatsHist"
    CHANGED_MO_CLASS_ID_MEMORY_BUFFER_UNIT = "memoryBufferUnit"
    CHANGED_MO_CLASS_ID_MEMORY_BUFFER_UNIT_ENV_STATS = "memoryBufferUnitEnvStats"
    CHANGED_MO_CLASS_ID_MEMORY_BUFFER_UNIT_ENV_STATS_HIST = "memoryBufferUnitEnvStatsHist"
    CHANGED_MO_CLASS_ID_MEMORY_ERROR_STATS = "memoryErrorStats"
    CHANGED_MO_CLASS_ID_MEMORY_PERSISTENT_MEMORY_ANAMESPACE = "memoryPersistentMemoryANamespace"
    CHANGED_MO_CLASS_ID_MEMORY_PERSISTENT_MEMORY_CONFIG_RESULT = "memoryPersistentMemoryConfigResult"
    CHANGED_MO_CLASS_ID_MEMORY_PERSISTENT_MEMORY_CONFIGURATION = "memoryPersistentMemoryConfiguration"
    CHANGED_MO_CLASS_ID_MEMORY_PERSISTENT_MEMORY_GOAL = "memoryPersistentMemoryGoal"
    CHANGED_MO_CLASS_ID_MEMORY_PERSISTENT_MEMORY_LOCAL_SECURITY = "memoryPersistentMemoryLocalSecurity"
    CHANGED_MO_CLASS_ID_MEMORY_PERSISTENT_MEMORY_LOGICAL_NAMESPACE = "memoryPersistentMemoryLogicalNamespace"
    CHANGED_MO_CLASS_ID_MEMORY_PERSISTENT_MEMORY_NAMESPACE = "memoryPersistentMemoryNamespace"
    CHANGED_MO_CLASS_ID_MEMORY_PERSISTENT_MEMORY_NAMESPACE_CONFIG_RESULT = "memoryPersistentMemoryNamespaceConfigResult"
    CHANGED_MO_CLASS_ID_MEMORY_PERSISTENT_MEMORY_POLICY = "memoryPersistentMemoryPolicy"
    CHANGED_MO_CLASS_ID_MEMORY_PERSISTENT_MEMORY_REGION = "memoryPersistentMemoryRegion"
    CHANGED_MO_CLASS_ID_MEMORY_PERSISTENT_MEMORY_SECURITY = "memoryPersistentMemorySecurity"
    CHANGED_MO_CLASS_ID_MEMORY_PERSISTENT_MEMORY_UNIT = "memoryPersistentMemoryUnit"
    CHANGED_MO_CLASS_ID_MEMORY_QUAL = "memoryQual"
    CHANGED_MO_CLASS_ID_MEMORY_RUNTIME = "memoryRuntime"
    CHANGED_MO_CLASS_ID_MEMORY_RUNTIME_HIST = "memoryRuntimeHist"
    CHANGED_MO_CLASS_ID_MEMORY_UNIT = "memoryUnit"
    CHANGED_MO_CLASS_ID_MEMORY_UNIT_ENV_STATS = "memoryUnitEnvStats"
    CHANGED_MO_CLASS_ID_MEMORY_UNIT_ENV_STATS_HIST = "memoryUnitEnvStatsHist"
    CHANGED_MO_CLASS_ID_MGMT_ASECURE_BOOT = "mgmtASecureBoot"
    CHANGED_MO_CLASS_ID_MGMT_ABSTRACT_IF = "mgmtAbstractIf"
    CHANGED_MO_CLASS_ID_MGMT_ACCESS_POLICY = "mgmtAccessPolicy"
    CHANGED_MO_CLASS_ID_MGMT_ACCESS_POLICY_ITEM = "mgmtAccessPolicyItem"
    CHANGED_MO_CLASS_ID_MGMT_ACCESS_PORT = "mgmtAccessPort"
    CHANGED_MO_CLASS_ID_MGMT_BACKUP = "mgmtBackup"
    CHANGED_MO_CLASS_ID_MGMT_BACKUP_EXPORT_EXT_POLICY = "mgmtBackupExportExtPolicy"
    CHANGED_MO_CLASS_ID_MGMT_BACKUP_FSM = "mgmtBackupFsm"
    CHANGED_MO_CLASS_ID_MGMT_BACKUP_FSM_STAGE = "mgmtBackupFsmStage"
    CHANGED_MO_CLASS_ID_MGMT_BACKUP_FSM_TASK = "mgmtBackupFsmTask"
    CHANGED_MO_CLASS_ID_MGMT_BACKUP_POLICY = "mgmtBackupPolicy"
    CHANGED_MO_CLASS_ID_MGMT_BACKUP_POLICY_CONFIG = "mgmtBackupPolicyConfig"
    CHANGED_MO_CLASS_ID_MGMT_BACKUP_POLICY_FSM = "mgmtBackupPolicyFsm"
    CHANGED_MO_CLASS_ID_MGMT_BACKUP_POLICY_FSM_STAGE = "mgmtBackupPolicyFsmStage"
    CHANGED_MO_CLASS_ID_MGMT_CFG_EXPORT_POLICY = "mgmtCfgExportPolicy"
    CHANGED_MO_CLASS_ID_MGMT_CFG_EXPORT_POLICY_FSM = "mgmtCfgExportPolicyFsm"
    CHANGED_MO_CLASS_ID_MGMT_CFG_EXPORT_POLICY_FSM_STAGE = "mgmtCfgExportPolicyFsmStage"
    CHANGED_MO_CLASS_ID_MGMT_CIMC_INTERFACE = "mgmtCimcInterface"
    CHANGED_MO_CLASS_ID_MGMT_CIMC_SECURE_BOOT = "mgmtCimcSecureBoot"
    CHANGED_MO_CLASS_ID_MGMT_CMC_SECURE_BOOT = "mgmtCmcSecureBoot"
    CHANGED_MO_CLASS_ID_MGMT_CONNECTION = "mgmtConnection"
    CHANGED_MO_CLASS_ID_MGMT_CONTROLLER = "mgmtController"
    CHANGED_MO_CLASS_ID_MGMT_CONTROLLER_FSM = "mgmtControllerFsm"
    CHANGED_MO_CLASS_ID_MGMT_CONTROLLER_FSM_STAGE = "mgmtControllerFsmStage"
    CHANGED_MO_CLASS_ID_MGMT_CONTROLLER_FSM_TASK = "mgmtControllerFsmTask"
    CHANGED_MO_CLASS_ID_MGMT_DB_STATE = "mgmtDbState"
    CHANGED_MO_CLASS_ID_MGMT_ENTITY = "mgmtEntity"
    CHANGED_MO_CLASS_ID_MGMT_EXPORT_POLICY = "mgmtExportPolicy"
    CHANGED_MO_CLASS_ID_MGMT_EXPORT_POLICY_FSM = "mgmtExportPolicyFsm"
    CHANGED_MO_CLASS_ID_MGMT_EXPORT_POLICY_FSM_STAGE = "mgmtExportPolicyFsmStage"
    CHANGED_MO_CLASS_ID_MGMT_EXPORT_POLICY_FSM_TASK = "mgmtExportPolicyFsmTask"
    CHANGED_MO_CLASS_ID_MGMT_HEALTH_ATTR = "mgmtHealthAttr"
    CHANGED_MO_CLASS_ID_MGMT_HEALTH_STATUS = "mgmtHealthStatus"
    CHANGED_MO_CLASS_ID_MGMT_IPV6_ADDR = "mgmtIPv6Addr"
    CHANGED_MO_CLASS_ID_MGMT_IPV6_IF_ADDR = "mgmtIPv6IfAddr"
    CHANGED_MO_CLASS_ID_MGMT_IPV6_IF_ADDR_FSM = "mgmtIPv6IfAddrFsm"
    CHANGED_MO_CLASS_ID_MGMT_IPV6_IF_ADDR_FSM_STAGE = "mgmtIPv6IfAddrFsmStage"
    CHANGED_MO_CLASS_ID_MGMT_IPV6_IF_ADDR_FSM_TASK = "mgmtIPv6IfAddrFsmTask"
    CHANGED_MO_CLASS_ID_MGMT_IPV6_IF_CONFIG = "mgmtIPv6IfConfig"
    CHANGED_MO_CLASS_ID_MGMT_IF = "mgmtIf"
    CHANGED_MO_CLASS_ID_MGMT_IF_FSM = "mgmtIfFsm"
    CHANGED_MO_CLASS_ID_MGMT_IF_FSM_STAGE = "mgmtIfFsmStage"
    CHANGED_MO_CLASS_ID_MGMT_IF_FSM_TASK = "mgmtIfFsmTask"
    CHANGED_MO_CLASS_ID_MGMT_IMPORTER = "mgmtImporter"
    CHANGED_MO_CLASS_ID_MGMT_IMPORTER_FSM = "mgmtImporterFsm"
    CHANGED_MO_CLASS_ID_MGMT_IMPORTER_FSM_STAGE = "mgmtImporterFsmStage"
    CHANGED_MO_CLASS_ID_MGMT_IMPORTER_FSM_TASK = "mgmtImporterFsmTask"
    CHANGED_MO_CLASS_ID_MGMT_INBAND_PROFILE = "mgmtInbandProfile"
    CHANGED_MO_CLASS_ID_MGMT_INT_AUTH_POLICY = "mgmtIntAuthPolicy"
    CHANGED_MO_CLASS_ID_MGMT_INTERFACE = "mgmtInterface"
    CHANGED_MO_CLASS_ID_MGMT_KMIP = "mgmtKmip"
    CHANGED_MO_CLASS_ID_MGMT_KMIP_CERT_POLICY = "mgmtKmipCertPolicy"
    CHANGED_MO_CLASS_ID_MGMT_KVM_CERTIFICATE = "mgmtKvmCertificate"
    CHANGED_MO_CLASS_ID_MGMT_LEADER_ENTITY = "mgmtLeaderEntity"
    CHANGED_MO_CLASS_ID_MGMT_PMON_ENTRY = "mgmtPmonEntry"
    CHANGED_MO_CLASS_ID_MGMT_PROF_DERIVED_INTERFACE = "mgmtProfDerivedInterface"
    CHANGED_MO_CLASS_ID_MGMT_SECURITY = "mgmtSecurity"
    CHANGED_MO_CLASS_ID_MGMT_SPDM_CERTIFICATE = "mgmtSpdmCertificate"
    CHANGED_MO_CLASS_ID_MGMT_SPDM_CERTIFICATE_DATA = "mgmtSpdmCertificateData"
    CHANGED_MO_CLASS_ID_MGMT_SPDM_CERTIFICATE_INVENTORY = "mgmtSpdmCertificateInventory"
    CHANGED_MO_CLASS_ID_MGMT_SPDM_CERTIFICATE_POLICY = "mgmtSpdmCertificatePolicy"
    CHANGED_MO_CLASS_ID_MGMT_SW_PERSONALITIES = "mgmtSwPersonalities"
    CHANGED_MO_CLASS_ID_MGMT_SW_PERSONALITIES_INVENTORY = "mgmtSwPersonalitiesInventory"
    CHANGED_MO_CLASS_ID_MGMT_SW_PERSONALITY = "mgmtSwPersonality"
    CHANGED_MO_CLASS_ID_MGMT_USB_NIC_MGMT_IF = "mgmtUsbNicMgmtIf"
    CHANGED_MO_CLASS_ID_MGMT_VNET = "mgmtVnet"
    CHANGED_MO_CLASS_ID_MO_ABSTRACT_CFG_KV = "moAbstractCfgKv"
    CHANGED_MO_CLASS_ID_MO_ABSTRACT_INV_KV = "moAbstractInvKv"
    CHANGED_MO_CLASS_ID_MO_ABSTRACT_KV = "moAbstractKv"
    CHANGED_MO_CLASS_ID_MO_INV_KV = "moInvKv"
    CHANGED_MO_CLASS_ID_MO_IP_ADDR_KV = "moIpAddrKv"
    CHANGED_MO_CLASS_ID_MO_IP_V4_ADDR_KV = "moIpV4AddrKv"
    CHANGED_MO_CLASS_ID_MO_IP_V6_ADDR_KV = "moIpV6AddrKv"
    CHANGED_MO_CLASS_ID_MO_KV = "moKv"
    CHANGED_MO_CLASS_ID_MO_KV_CFG_HOLDER = "moKvCfgHolder"
    CHANGED_MO_CLASS_ID_MO_KV_INV_HOLDER = "moKvInvHolder"
    CHANGED_MO_CLASS_ID_MO_TOP_PROPS = "moTopProps"
    CHANGED_MO_CLASS_ID_MO_VNIC_KV = "moVnicKv"
    CHANGED_MO_CLASS_ID_MOREF_FRU_REF = "morefFruRef"
    CHANGED_MO_CLASS_ID_MOREF_IMPORT_ROOT = "morefImportRoot"
    CHANGED_MO_CLASS_ID_MOREF_IMPORT_ROOT_FSM = "morefImportRootFsm"
    CHANGED_MO_CLASS_ID_MOREF_IMPORT_ROOT_FSM_STAGE = "morefImportRootFsmStage"
    CHANGED_MO_CLASS_ID_MOREF_IMPORT_ROOT_FSM_TASK = "morefImportRootFsmTask"
    CHANGED_MO_CLASS_ID_MOREF_PROP = "morefProp"
    CHANGED_MO_CLASS_ID_MOREF_REF = "morefRef"
    CHANGED_MO_CLASS_ID_NAMING_NAMED_IDENTIFIED_OBJECT = "namingNamedIdentifiedObject"
    CHANGED_MO_CLASS_ID_NAMING_NAMED_OBJECT = "namingNamedObject"
    CHANGED_MO_CLASS_ID_NETWORK_ALAN_NEIGHBOR_ENTRY = "networkALanNeighborEntry"
    CHANGED_MO_CLASS_ID_NETWORK_ANEIGHBOR_ENTRY = "networkANeighborEntry"
    CHANGED_MO_CLASS_ID_NETWORK_CIO_EP = "networkCIoEp"
    CHANGED_MO_CLASS_ID_NETWORK_CONN = "networkConn"
    CHANGED_MO_CLASS_ID_NETWORK_DOMAIN_EP = "networkDomainEp"
    CHANGED_MO_CLASS_ID_NETWORK_ELEMENT = "networkElement"
    CHANGED_MO_CLASS_ID_NETWORK_EP = "networkEp"
    CHANGED_MO_CLASS_ID_NETWORK_IF_EP = "networkIfEp"
    CHANGED_MO_CLASS_ID_NETWORK_IF_STATS = "networkIfStats"
    CHANGED_MO_CLASS_ID_NETWORK_LAN_NEIGHBOR_ENTRY = "networkLanNeighborEntry"
    CHANGED_MO_CLASS_ID_NETWORK_LAN_NEIGHBORS = "networkLanNeighbors"
    CHANGED_MO_CLASS_ID_NETWORK_LIMIT = "networkLimit"
    CHANGED_MO_CLASS_ID_NETWORK_LLDP_NEIGHBOR_ENTRY = "networkLldpNeighborEntry"
    CHANGED_MO_CLASS_ID_NETWORK_LLDP_NEIGHBORS = "networkLldpNeighbors"
    CHANGED_MO_CLASS_ID_NETWORK_OPER_LEVEL = "networkOperLevel"
    CHANGED_MO_CLASS_ID_NETWORK_PIO_EP = "networkPIoEp"
    CHANGED_MO_CLASS_ID_NETWORK_PHYS_EP = "networkPhysEp"
    CHANGED_MO_CLASS_ID_NETWORK_SAN_NEIGHBOR_ENTRY = "networkSanNeighborEntry"
    CHANGED_MO_CLASS_ID_NETWORK_SAN_NEIGHBORS = "networkSanNeighbors"
    CHANGED_MO_CLASS_ID_NETWORK_VNET_EP = "networkVnetEp"
    CHANGED_MO_CLASS_ID_NETWORKRULE_DEFINITION = "networkruleDefinition"
    CHANGED_MO_CLASS_ID_NETWORKRULE_ITEM = "networkruleItem"
    CHANGED_MO_CLASS_ID_NETWORKRULE_REQUIREMENT = "networkruleRequirement"
    CHANGED_MO_CLASS_ID_NFS_EP = "nfsEp"
    CHANGED_MO_CLASS_ID_NFS_MOUNT_DEF = "nfsMountDef"
    CHANGED_MO_CLASS_ID_NFS_MOUNT_DEF_FSM = "nfsMountDefFsm"
    CHANGED_MO_CLASS_ID_NFS_MOUNT_DEF_FSM_STAGE = "nfsMountDefFsmStage"
    CHANGED_MO_CLASS_ID_NFS_MOUNT_DEF_FSM_TASK = "nfsMountDefFsmTask"
    CHANGED_MO_CLASS_ID_NFS_MOUNT_INST = "nfsMountInst"
    CHANGED_MO_CLASS_ID_NFS_MOUNT_INST_FSM = "nfsMountInstFsm"
    CHANGED_MO_CLASS_ID_NFS_MOUNT_INST_FSM_STAGE = "nfsMountInstFsmStage"
    CHANGED_MO_CLASS_ID_NFS_MOUNT_INST_FSM_TASK = "nfsMountInstFsmTask"
    CHANGED_MO_CLASS_ID_NWCTRL_DEFINITION = "nwctrlDefinition"
    CHANGED_MO_CLASS_ID_OBSERVE_FILTER = "observeFilter"
    CHANGED_MO_CLASS_ID_OBSERVE_OBSERVED = "observeObserved"
    CHANGED_MO_CLASS_ID_OBSERVE_OBSERVED_CONT = "observeObservedCont"
    CHANGED_MO_CLASS_ID_OBSERVE_OBSERVED_FSM = "observeObservedFsm"
    CHANGED_MO_CLASS_ID_OBSERVE_OBSERVED_FSM_STAGE = "observeObservedFsmStage"
    CHANGED_MO_CLASS_ID_OBSERVE_OBSERVED_FSM_TASK = "observeObservedFsmTask"
    CHANGED_MO_CLASS_ID_ORG_ORG = "orgOrg"
    CHANGED_MO_CLASS_ID_ORG_SOURCE_MASK = "orgSourceMask"
    CHANGED_MO_CLASS_ID_OS_ARPLINK_MONITORING_POLICY = "osARPLinkMonitoringPolicy"
    CHANGED_MO_CLASS_ID_OS_ARPTARGET = "osARPTarget"
    CHANGED_MO_CLASS_ID_OS_AGENT = "osAgent"
    CHANGED_MO_CLASS_ID_OS_ETH_BOND_INTF = "osEthBondIntf"
    CHANGED_MO_CLASS_ID_OS_ETH_BOND_MODE = "osEthBondMode"
    CHANGED_MO_CLASS_ID_OS_ETH_BOND_MODE_ACTIVE_BACKUP = "osEthBondModeActiveBackup"
    CHANGED_MO_CLASS_ID_OS_ETH_BOND_MODE_BALANCED_ALB = "osEthBondModeBalancedALB"
    CHANGED_MO_CLASS_ID_OS_ETH_BOND_MODE_BALANCED_RR = "osEthBondModeBalancedRR"
    CHANGED_MO_CLASS_ID_OS_ETH_BOND_MODE_BALANCED_TLB = "osEthBondModeBalancedTLB"
    CHANGED_MO_CLASS_ID_OS_ETH_BOND_MODE_BALANCED_XOR = "osEthBondModeBalancedXOR"
    CHANGED_MO_CLASS_ID_OS_ETH_BOND_MODE_BROADCAST = "osEthBondModeBroadcast"
    CHANGED_MO_CLASS_ID_OS_ETH_BOND_MODE_LB = "osEthBondModeLB"
    CHANGED_MO_CLASS_ID_OS_ETH_INTF = "osEthIntf"
    CHANGED_MO_CLASS_ID_OS_INSTANCE = "osInstance"
    CHANGED_MO_CLASS_ID_OS_INTF = "osIntf"
    CHANGED_MO_CLASS_ID_OS_LINK_MONITORING_POLICY = "osLinkMonitoringPolicy"
    CHANGED_MO_CLASS_ID_OS_MII_LINK_MONITORING_POLICY = "osMiiLinkMonitoringPolicy"
    CHANGED_MO_CLASS_ID_OS_PRIMARY_SLAVE = "osPrimarySlave"
    CHANGED_MO_CLASS_ID_PCI_CARD = "pciCard"
    CHANGED_MO_CLASS_ID_PCI_EQUIP_SLOT = "pciEquipSlot"
    CHANGED_MO_CLASS_ID_PCI_LINK = "pciLink"
    CHANGED_MO_CLASS_ID_PCI_SWITCH = "pciSwitch"
    CHANGED_MO_CLASS_ID_PCI_UNIT = "pciUnit"
    CHANGED_MO_CLASS_ID_PFC_WATCH_DOG = "pfcWatchDog"
    CHANGED_MO_CLASS_ID_PFC_WATCH_DOG_FSM = "pfcWatchDogFsm"
    CHANGED_MO_CLASS_ID_PFC_WATCH_DOG_FSM_STAGE = "pfcWatchDogFsmStage"
    CHANGED_MO_CLASS_ID_PFC_WATCH_DOG_FSM_TASK = "pfcWatchDogFsmTask"
    CHANGED_MO_CLASS_ID_PKI_CERT_REQ = "pkiCertReq"
    CHANGED_MO_CLASS_ID_PKI_DEFINITION = "pkiDefinition"
    CHANGED_MO_CLASS_ID_PKI_EP = "pkiEp"
    CHANGED_MO_CLASS_ID_PKI_EP_FSM = "pkiEpFsm"
    CHANGED_MO_CLASS_ID_PKI_EP_FSM_STAGE = "pkiEpFsmStage"
    CHANGED_MO_CLASS_ID_PKI_EP_FSM_TASK = "pkiEpFsmTask"
    CHANGED_MO_CLASS_ID_PKI_ITEM = "pkiItem"
    CHANGED_MO_CLASS_ID_PKI_KEY_RING = "pkiKeyRing"
    CHANGED_MO_CLASS_ID_PKI_TP = "pkiTP"
    CHANGED_MO_CLASS_ID_POLICY_ADEST_EP = "policyADestEp"
    CHANGED_MO_CLASS_ID_POLICY_BINDING = "policyBinding"
    CHANGED_MO_CLASS_ID_POLICY_CENTRALE_SYNC = "policyCentraleSync"
    CHANGED_MO_CLASS_ID_POLICY_CHILD_CLASS = "policyChildClass"
    CHANGED_MO_CLASS_ID_POLICY_COMMUNICATION = "policyCommunication"
    CHANGED_MO_CLASS_ID_POLICY_CONFIG_BACKUP = "policyConfigBackup"
    CHANGED_MO_CLASS_ID_POLICY_CONFIG_ERROR = "policyConfigError"
    CHANGED_MO_CLASS_ID_POLICY_CONTEXT = "policyContext"
    CHANGED_MO_CLASS_ID_POLICY_CONTROL = "policyControl"
    CHANGED_MO_CLASS_ID_POLICY_CONTROL_EP = "policyControlEp"
    CHANGED_MO_CLASS_ID_POLICY_CONTROL_EP_FSM = "policyControlEpFsm"
    CHANGED_MO_CLASS_ID_POLICY_CONTROL_EP_FSM_STAGE = "policyControlEpFsmStage"
    CHANGED_MO_CLASS_ID_POLICY_CONTROL_EP_FSM_TASK = "policyControlEpFsmTask"
    CHANGED_MO_CLASS_ID_POLICY_CONTROLLED = "policyControlled"
    CHANGED_MO_CLASS_ID_POLICY_CONTROLLED_INSTANCE = "policyControlledInstance"
    CHANGED_MO_CLASS_ID_POLICY_CONTROLLED_TYPE = "policyControlledType"
    CHANGED_MO_CLASS_ID_POLICY_CONTROLLED_TYPE_FSM = "policyControlledTypeFsm"
    CHANGED_MO_CLASS_ID_POLICY_CONTROLLED_TYPE_FSM_STAGE = "policyControlledTypeFsmStage"
    CHANGED_MO_CLASS_ID_POLICY_CONTROLLED_TYPE_FSM_TASK = "policyControlledTypeFsmTask"
    CHANGED_MO_CLASS_ID_POLICY_DATE_TIME = "policyDateTime"
    CHANGED_MO_CLASS_ID_POLICY_DEFINITION = "policyDefinition"
    CHANGED_MO_CLASS_ID_POLICY_DEST_CLASS = "policyDestClass"
    CHANGED_MO_CLASS_ID_POLICY_DEST_EP = "policyDestEp"
    CHANGED_MO_CLASS_ID_POLICY_DIGEST = "policyDigest"
    CHANGED_MO_CLASS_ID_POLICY_DISCOVERY = "policyDiscovery"
    CHANGED_MO_CLASS_ID_POLICY_DNS = "policyDns"
    CHANGED_MO_CLASS_ID_POLICY_ELEMENT = "policyElement"
    CHANGED_MO_CLASS_ID_POLICY_EQUIPMENT = "policyEquipment"
    CHANGED_MO_CLASS_ID_POLICY_FAULT = "policyFault"
    CHANGED_MO_CLASS_ID_POLICY_HOLDER = "policyHolder"
    CHANGED_MO_CLASS_ID_POLICY_ID_RESOLVE_POLICY = "policyIdResolvePolicy"
    CHANGED_MO_CLASS_ID_POLICY_INFRA_FIRMWARE = "policyInfraFirmware"
    CHANGED_MO_CLASS_ID_POLICY_ITEM = "policyItem"
    CHANGED_MO_CLASS_ID_POLICY_LOCAL_MAP = "policyLocalMap"
    CHANGED_MO_CLASS_ID_POLICY_MEP = "policyMEp"
    CHANGED_MO_CLASS_ID_POLICY_MONITORING = "policyMonitoring"
    CHANGED_MO_CLASS_ID_POLICY_OBJECT = "policyObject"
    CHANGED_MO_CLASS_ID_POLICY_POLICY_DEST_CLASS = "policyPolicyDestClass"
    CHANGED_MO_CLASS_ID_POLICY_POLICY_EP = "policyPolicyEp"
    CHANGED_MO_CLASS_ID_POLICY_POLICY_REQUESTOR = "policyPolicyRequestor"
    CHANGED_MO_CLASS_ID_POLICY_POLICY_SCOPE = "policyPolicyScope"
    CHANGED_MO_CLASS_ID_POLICY_POLICY_SCOPE_CONT = "policyPolicyScopeCont"
    CHANGED_MO_CLASS_ID_POLICY_POLICY_SCOPE_CONT_FSM = "policyPolicyScopeContFsm"
    CHANGED_MO_CLASS_ID_POLICY_POLICY_SCOPE_CONT_FSM_STAGE = "policyPolicyScopeContFsmStage"
    CHANGED_MO_CLASS_ID_POLICY_POLICY_SCOPE_CONT_FSM_TASK = "policyPolicyScopeContFsmTask"
    CHANGED_MO_CLASS_ID_POLICY_POLICY_SCOPE_CONTEXT = "policyPolicyScopeContext"
    CHANGED_MO_CLASS_ID_POLICY_POLICY_SCOPE_FSM = "policyPolicyScopeFsm"
    CHANGED_MO_CLASS_ID_POLICY_POLICY_SCOPE_FSM_STAGE = "policyPolicyScopeFsmStage"
    CHANGED_MO_CLASS_ID_POLICY_POLICY_SCOPE_FSM_TASK = "policyPolicyScopeFsmTask"
    CHANGED_MO_CLASS_ID_POLICY_PORT_CONFIG = "policyPortConfig"
    CHANGED_MO_CLASS_ID_POLICY_POWER_MGMT = "policyPowerMgmt"
    CHANGED_MO_CLASS_ID_POLICY_PSU = "policyPsu"
    CHANGED_MO_CLASS_ID_POLICY_REF_REQ = "policyRefReq"
    CHANGED_MO_CLASS_ID_POLICY_REQUESTOR = "policyRequestor"
    CHANGED_MO_CLASS_ID_POLICY_REQUESTOR_FSM = "policyRequestorFsm"
    CHANGED_MO_CLASS_ID_POLICY_REQUESTOR_FSM_STAGE = "policyRequestorFsmStage"
    CHANGED_MO_CLASS_ID_POLICY_REQUESTOR_FSM_TASK = "policyRequestorFsmTask"
    CHANGED_MO_CLASS_ID_POLICY_SCOPE = "policyScope"
    CHANGED_MO_CLASS_ID_POLICY_SECURITY = "policySecurity"
    CHANGED_MO_CLASS_ID_POLICY_SOURCE_APP = "policySourceApp"
    CHANGED_MO_CLASS_ID_POLICY_STORAGE_AUTO_CONFIG = "policyStorageAutoConfig"
    CHANGED_MO_CLASS_ID_POLICY_SYSTEM_EP = "policySystemEp"
    CHANGED_MO_CLASS_ID_POOL_ELEMENT = "poolElement"
    CHANGED_MO_CLASS_ID_POOL_POOL = "poolPool"
    CHANGED_MO_CLASS_ID_POOL_POOL_MEMBER = "poolPoolMember"
    CHANGED_MO_CLASS_ID_POOL_POOLABLE = "poolPoolable"
    CHANGED_MO_CLASS_ID_POOL_UNIVERSE = "poolUniverse"
    CHANGED_MO_CLASS_ID_PORT_DOMAIN_EP = "portDomainEp"
    CHANGED_MO_CLASS_ID_PORT_GROUP = "portGroup"
    CHANGED_MO_CLASS_ID_PORT_INT_FIO = "portIntFIo"
    CHANGED_MO_CLASS_ID_PORT_PIO = "portPIo"
    CHANGED_MO_CLASS_ID_PORT_PIO_FSM = "portPIoFsm"
    CHANGED_MO_CLASS_ID_PORT_PIO_FSM_STAGE = "portPIoFsmStage"
    CHANGED_MO_CLASS_ID_PORT_PIO_FSM_TASK = "portPIoFsmTask"
    CHANGED_MO_CLASS_ID_PORT_PHYS_SWITCH_IO = "portPhysSwitchIo"
    CHANGED_MO_CLASS_ID_PORT_SERVER_INT_FIO = "portServerIntFIo"
    CHANGED_MO_CLASS_ID_PORT_SUB_GROUP = "portSubGroup"
    CHANGED_MO_CLASS_ID_PORT_SWITCH_INT_FIO = "portSwitchIntFIo"
    CHANGED_MO_CLASS_ID_PORT_TRUST_MODE = "portTrustMode"
    CHANGED_MO_CLASS_ID_POWER_ABUDGET = "powerABudget"
    CHANGED_MO_CLASS_ID_POWER_AGROUP = "powerAGroup"
    CHANGED_MO_CLASS_ID_POWER_BUDGET = "powerBudget"
    CHANGED_MO_CLASS_ID_POWER_CHASSIS_MEMBER = "powerChassisMember"
    CHANGED_MO_CLASS_ID_POWER_EP = "powerEp"
    CHANGED_MO_CLASS_ID_POWER_FIMEMBER = "powerFIMember"
    CHANGED_MO_CLASS_ID_POWER_FEX_MEMBER = "powerFexMember"
    CHANGED_MO_CLASS_ID_POWER_GROUP = "powerGroup"
    CHANGED_MO_CLASS_ID_POWER_GROUP_ADDITION_POLICY = "powerGroupAdditionPolicy"
    CHANGED_MO_CLASS_ID_POWER_GROUP_MEMBER = "powerGroupMember"
    CHANGED_MO_CLASS_ID_POWER_GROUP_QUAL = "powerGroupQual"
    CHANGED_MO_CLASS_ID_POWER_GROUP_STATS = "powerGroupStats"
    CHANGED_MO_CLASS_ID_POWER_GROUP_STATS_HIST = "powerGroupStatsHist"
    CHANGED_MO_CLASS_ID_POWER_MGMT_POLICY = "powerMgmtPolicy"
    CHANGED_MO_CLASS_ID_POWER_PLACEMENT = "powerPlacement"
    CHANGED_MO_CLASS_ID_POWER_POLICY = "powerPolicy"
    CHANGED_MO_CLASS_ID_POWER_PRIO_WGHT = "powerPrioWght"
    CHANGED_MO_CLASS_ID_POWER_PROFILED_POWER = "powerProfiledPower"
    CHANGED_MO_CLASS_ID_POWER_RACK_UNIT_MEMBER = "powerRackUnitMember"
    CHANGED_MO_CLASS_ID_PROC_DOER = "procDoer"
    CHANGED_MO_CLASS_ID_PROC_MANAGER = "procManager"
    CHANGED_MO_CLASS_ID_PROC_PROC_COUNTS = "procProcCounts"
    CHANGED_MO_CLASS_ID_PROC_PROCS = "procProcs"
    CHANGED_MO_CLASS_ID_PROC_PRT = "procPrt"
    CHANGED_MO_CLASS_ID_PROC_PRT_COUNTS = "procPrtCounts"
    CHANGED_MO_CLASS_ID_PROC_STIMULUS_COUNTS = "procStimulusCounts"
    CHANGED_MO_CLASS_ID_PROC_SVC = "procSvc"
    CHANGED_MO_CLASS_ID_PROC_TX_COUNTS = "procTxCounts"
    CHANGED_MO_CLASS_ID_PROCESSOR_CACHE_MEM_STATS = "processorCacheMemStats"
    CHANGED_MO_CLASS_ID_PROCESSOR_COMPONENT = "processorComponent"
    CHANGED_MO_CLASS_ID_PROCESSOR_CORE = "processorCore"
    CHANGED_MO_CLASS_ID_PROCESSOR_ENV_STATS = "processorEnvStats"
    CHANGED_MO_CLASS_ID_PROCESSOR_ENV_STATS_HIST = "processorEnvStatsHist"
    CHANGED_MO_CLASS_ID_PROCESSOR_ERROR_STATS = "processorErrorStats"
    CHANGED_MO_CLASS_ID_PROCESSOR_EXEC_STATS = "processorExecStats"
    CHANGED_MO_CLASS_ID_PROCESSOR_IOSTATS = "processorIOStats"
    CHANGED_MO_CLASS_ID_PROCESSOR_MISC_STATS = "processorMiscStats"
    CHANGED_MO_CLASS_ID_PROCESSOR_PCIBUS_STATS = "processorPCIBusStats"
    CHANGED_MO_CLASS_ID_PROCESSOR_PMUSTATS = "processorPMUStats"
    CHANGED_MO_CLASS_ID_PROCESSOR_QUAL = "processorQual"
    CHANGED_MO_CLASS_ID_PROCESSOR_RUNTIME = "processorRuntime"
    CHANGED_MO_CLASS_ID_PROCESSOR_RUNTIME_HIST = "processorRuntimeHist"
    CHANGED_MO_CLASS_ID_PROCESSOR_SECURITY_STATS = "processorSecurityStats"
    CHANGED_MO_CLASS_ID_PROCESSOR_THREAD = "processorThread"
    CHANGED_MO_CLASS_ID_PROCESSOR_UNIT = "processorUnit"
    CHANGED_MO_CLASS_ID_PROCESSOR_UNIT_ASSOC_CTX = "processorUnitAssocCtx"
    CHANGED_MO_CLASS_ID_QOS_DEFINITION = "qosDefinition"
    CHANGED_MO_CLASS_ID_QOS_ITEM = "qosItem"
    CHANGED_MO_CLASS_ID_QOSCLASS_DEFINITION = "qosclassDefinition"
    CHANGED_MO_CLASS_ID_QOSCLASS_DEFINITION_FSM = "qosclassDefinitionFsm"
    CHANGED_MO_CLASS_ID_QOSCLASS_DEFINITION_FSM_STAGE = "qosclassDefinitionFsmStage"
    CHANGED_MO_CLASS_ID_QOSCLASS_DEFINITION_FSM_TASK = "qosclassDefinitionFsmTask"
    CHANGED_MO_CLASS_ID_QOSCLASS_ETH = "qosclassEth"
    CHANGED_MO_CLASS_ID_QOSCLASS_ETH_BE = "qosclassEthBE"
    CHANGED_MO_CLASS_ID_QOSCLASS_ETH_CLASSIFIED = "qosclassEthClassified"
    CHANGED_MO_CLASS_ID_QOSCLASS_FC = "qosclassFc"
    CHANGED_MO_CLASS_ID_QOSCLASS_ITEM = "qosclassItem"
    CHANGED_MO_CLASS_ID_QOSCLASS_SLOW_DRAIN = "qosclassSlowDrain"
    CHANGED_MO_CLASS_ID_QOSCLASS_SLOW_DRAIN_FSM = "qosclassSlowDrainFsm"
    CHANGED_MO_CLASS_ID_QOSCLASS_SLOW_DRAIN_FSM_STAGE = "qosclassSlowDrainFsmStage"
    CHANGED_MO_CLASS_ID_QOSCLASS_SLOW_DRAIN_FSM_TASK = "qosclassSlowDrainFsmTask"
    CHANGED_MO_CLASS_ID_QUERYRESULT_DEPENDENCY = "queryresultDependency"
    CHANGED_MO_CLASS_ID_QUERYRESULT_ITEM = "queryresultItem"
    CHANGED_MO_CLASS_ID_QUERYRESULT_USAGE = "queryresultUsage"
    CHANGED_MO_CLASS_ID_RULE_DEFINITION = "ruleDefinition"
    CHANGED_MO_CLASS_ID_RULE_ITEM = "ruleItem"
    CHANGED_MO_CLASS_ID_RULE_REQUIREMENT = "ruleRequirement"
    CHANGED_MO_CLASS_ID_RULE_SIZE_REQUIREMENT = "ruleSizeRequirement"
    CHANGED_MO_CLASS_ID_SECURITY_UNIT = "securityUnit"
    CHANGED_MO_CLASS_ID_SES_DISK_SLOT_EP = "sesDiskSlotEp"
    CHANGED_MO_CLASS_ID_SES_ENCLOSURE = "sesEnclosure"
    CHANGED_MO_CLASS_ID_SOL_CONFIG = "solConfig"
    CHANGED_MO_CLASS_ID_SOL_DEF = "solDef"
    CHANGED_MO_CLASS_ID_SOL_IF = "solIf"
    CHANGED_MO_CLASS_ID_SOL_POLICY = "solPolicy"
    CHANGED_MO_CLASS_ID_STATS_COLLECTION_POLICY = "statsCollectionPolicy"
    CHANGED_MO_CLASS_ID_STATS_COLLECTION_POLICY_FSM = "statsCollectionPolicyFsm"
    CHANGED_MO_CLASS_ID_STATS_COLLECTION_POLICY_FSM_STAGE = "statsCollectionPolicyFsmStage"
    CHANGED_MO_CLASS_ID_STATS_COLLECTION_POLICY_FSM_TASK = "statsCollectionPolicyFsmTask"
    CHANGED_MO_CLASS_ID_STATS_CURR = "statsCurr"
    CHANGED_MO_CLASS_ID_STATS_HIST = "statsHist"
    CHANGED_MO_CLASS_ID_STATS_HOLDER = "statsHolder"
    CHANGED_MO_CLASS_ID_STATS_ITEM = "statsItem"
    CHANGED_MO_CLASS_ID_STATS_THR32_DEFINITION = "statsThr32Definition"
    CHANGED_MO_CLASS_ID_STATS_THR32_VALUE = "statsThr32Value"
    CHANGED_MO_CLASS_ID_STATS_THR64_DEFINITION = "statsThr64Definition"
    CHANGED_MO_CLASS_ID_STATS_THR64_VALUE = "statsThr64Value"
    CHANGED_MO_CLASS_ID_STATS_THR_FLOAT_DEFINITION = "statsThrFloatDefinition"
    CHANGED_MO_CLASS_ID_STATS_THR_FLOAT_VALUE = "statsThrFloatValue"
    CHANGED_MO_CLASS_ID_STATS_THRESHOLD_CLASS = "statsThresholdClass"
    CHANGED_MO_CLASS_ID_STATS_THRESHOLD_DEFINITION = "statsThresholdDefinition"
    CHANGED_MO_CLASS_ID_STATS_THRESHOLD_POLICY = "statsThresholdPolicy"
    CHANGED_MO_CLASS_ID_STATS_THRESHOLD_VALUE = "statsThresholdValue"
    CHANGED_MO_CLASS_ID_STORAGE_ADEF = "storageADef"
    CHANGED_MO_CLASS_ID_STORAGE_ADISK_EP = "storageADiskEp"
    CHANGED_MO_CLASS_ID_STORAGE_ADISK_SLOT_EP = "storageADiskSlotEp"
    CHANGED_MO_CLASS_ID_STORAGE_ALUN = "storageALun"
    CHANGED_MO_CLASS_ID_STORAGE_ALUN_REF_BASE = "storageALunRefBase"
    CHANGED_MO_CLASS_ID_STORAGE_ASLOT = "storageASlot"
    CHANGED_MO_CLASS_ID_STORAGE_AUTH_KEY = "storageAuthKey"
    CHANGED_MO_CLASS_ID_STORAGE_CONNECTION_DEF = "storageConnectionDef"
    CHANGED_MO_CLASS_ID_STORAGE_CONNECTION_POLICY = "storageConnectionPolicy"
    CHANGED_MO_CLASS_ID_STORAGE_CONTROLLER = "storageController"
    CHANGED_MO_CLASS_ID_STORAGE_CONTROLLER_BASE = "storageControllerBase"
    CHANGED_MO_CLASS_ID_STORAGE_CONTROLLER_EP = "storageControllerEp"
    CHANGED_MO_CLASS_ID_STORAGE_CONTROLLER_REF = "storageControllerRef"
    CHANGED_MO_CLASS_ID_STORAGE_CONTROLLER_REFERENCE = "storageControllerReference"
    CHANGED_MO_CLASS_ID_STORAGE_DEVICE = "storageDevice"
    CHANGED_MO_CLASS_ID_STORAGE_DISK_ENV_STATS = "storageDiskEnvStats"
    CHANGED_MO_CLASS_ID_STORAGE_DISK_ENV_STATS_HIST = "storageDiskEnvStatsHist"
    CHANGED_MO_CLASS_ID_STORAGE_DOMAIN_EP = "storageDomainEp"
    CHANGED_MO_CLASS_ID_STORAGE_DRIVE = "storageDrive"
    CHANGED_MO_CLASS_ID_STORAGE_EMBEDDED_STORAGE = "storageEmbeddedStorage"
    CHANGED_MO_CLASS_ID_STORAGE_ENCLOSURE = "storageEnclosure"
    CHANGED_MO_CLASS_ID_STORAGE_ENCLOSURE_CAP = "storageEnclosureCap"
    CHANGED_MO_CLASS_ID_STORAGE_ENCLOSURE_DISK_SLOT_EP = "storageEnclosureDiskSlotEp"
    CHANGED_MO_CLASS_ID_STORAGE_ENCLOSURE_FSM = "storageEnclosureFsm"
    CHANGED_MO_CLASS_ID_STORAGE_ENCLOSURE_FSM_STAGE = "storageEnclosureFsmStage"
    CHANGED_MO_CLASS_ID_STORAGE_ENCLOSURE_FSM_TASK = "storageEnclosureFsmTask"
    CHANGED_MO_CLASS_ID_STORAGE_ENCLOSURE_LOCAL_DISK_CONFIG = "storageEnclosureLocalDiskConfig"
    CHANGED_MO_CLASS_ID_STORAGE_EP = "storageEp"
    CHANGED_MO_CLASS_ID_STORAGE_EP_USER = "storageEpUser"
    CHANGED_MO_CLASS_ID_STORAGE_ETHER_IF = "storageEtherIf"
    CHANGED_MO_CLASS_ID_STORAGE_FC_IF = "storageFcIf"
    CHANGED_MO_CLASS_ID_STORAGE_FC_TARGET_EP = "storageFcTargetEp"
    CHANGED_MO_CLASS_ID_STORAGE_FC_TARGET_IF = "storageFcTargetIf"
    CHANGED_MO_CLASS_ID_STORAGE_FLEX_FLASH_CARD = "storageFlexFlashCard"
    CHANGED_MO_CLASS_ID_STORAGE_FLEX_FLASH_CONTROLLER = "storageFlexFlashController"
    CHANGED_MO_CLASS_ID_STORAGE_FLEX_FLASH_CONTROLLER_FSM = "storageFlexFlashControllerFsm"
    CHANGED_MO_CLASS_ID_STORAGE_FLEX_FLASH_CONTROLLER_FSM_STAGE = "storageFlexFlashControllerFsmStage"
    CHANGED_MO_CLASS_ID_STORAGE_FLEX_FLASH_CONTROLLER_FSM_TASK = "storageFlexFlashControllerFsmTask"
    CHANGED_MO_CLASS_ID_STORAGE_FLEX_FLASH_DRIVE = "storageFlexFlashDrive"
    CHANGED_MO_CLASS_ID_STORAGE_FLEX_FLASH_VIRTUAL_DRIVE = "storageFlexFlashVirtualDrive"
    CHANGED_MO_CLASS_ID_STORAGE_HDD_MOTHER_BOARD_TEMP_STATS = "storageHddMotherBoardTempStats"
    CHANGED_MO_CLASS_ID_STORAGE_HDD_MOTHER_BOARD_TEMP_STATS_HIST = "storageHddMotherBoardTempStatsHist"
    CHANGED_MO_CLASS_ID_STORAGE_ISCSI_TARGET_IF = "storageIScsiTargetIf"
    CHANGED_MO_CLASS_ID_STORAGE_INI_GROUP = "storageIniGroup"
    CHANGED_MO_CLASS_ID_STORAGE_INITIATOR = "storageInitiator"
    CHANGED_MO_CLASS_ID_STORAGE_ITEM = "storageItem"
    CHANGED_MO_CLASS_ID_STORAGE_L2_IF = "storageL2If"
    CHANGED_MO_CLASS_ID_STORAGE_LOCAL_DISK = "storageLocalDisk"
    CHANGED_MO_CLASS_ID_STORAGE_LOCAL_DISK_BASE = "storageLocalDiskBase"
    CHANGED_MO_CLASS_ID_STORAGE_LOCAL_DISK_CONFIG = "storageLocalDiskConfig"
    CHANGED_MO_CLASS_ID_STORAGE_LOCAL_DISK_CONFIG_DEF = "storageLocalDiskConfigDef"
    CHANGED_MO_CLASS_ID_STORAGE_LOCAL_DISK_CONFIG_POLICY = "storageLocalDiskConfigPolicy"
    CHANGED_MO_CLASS_ID_STORAGE_LOCAL_DISK_EP = "storageLocalDiskEp"
    CHANGED_MO_CLASS_ID_STORAGE_LOCAL_DISK_FSM = "storageLocalDiskFsm"
    CHANGED_MO_CLASS_ID_STORAGE_LOCAL_DISK_FSM_STAGE = "storageLocalDiskFsmStage"
    CHANGED_MO_CLASS_ID_STORAGE_LOCAL_DISK_FSM_TASK = "storageLocalDiskFsmTask"
    CHANGED_MO_CLASS_ID_STORAGE_LOCAL_DISK_PARTITION = "storageLocalDiskPartition"
    CHANGED_MO_CLASS_ID_STORAGE_LOCAL_DISK_SLOT_EP = "storageLocalDiskSlotEp"
    CHANGED_MO_CLASS_ID_STORAGE_LOCAL_LUN = "storageLocalLun"
    CHANGED_MO_CLASS_ID_STORAGE_LOGICAL = "storageLogical"
    CHANGED_MO_CLASS_ID_STORAGE_LUN_DISK = "storageLunDisk"
    CHANGED_MO_CLASS_ID_STORAGE_LUN_RESOURCE_SELECTION_LOG = "storageLunResourceSelectionLog"
    CHANGED_MO_CLASS_ID_STORAGE_MEZZ_FLASH_LIFE = "storageMezzFlashLife"
    CHANGED_MO_CLASS_ID_STORAGE_MINI_STORAGE = "storageMiniStorage"
    CHANGED_MO_CLASS_ID_STORAGE_NODE_EP = "storageNodeEp"
    CHANGED_MO_CLASS_ID_STORAGE_NVME_STATS = "storageNvmeStats"
    CHANGED_MO_CLASS_ID_STORAGE_NVME_STATS_HIST = "storageNvmeStatsHist"
    CHANGED_MO_CLASS_ID_STORAGE_NVME_STORAGE = "storageNvmeStorage"
    CHANGED_MO_CLASS_ID_STORAGE_NVME_SWITCH = "storageNvmeSwitch"
    CHANGED_MO_CLASS_ID_STORAGE_ONBOARD_DEVICE = "storageOnboardDevice"
    CHANGED_MO_CLASS_ID_STORAGE_OPERATION = "storageOperation"
    CHANGED_MO_CLASS_ID_STORAGE_PHYSICAL = "storagePhysical"
    CHANGED_MO_CLASS_ID_STORAGE_QUAL = "storageQual"
    CHANGED_MO_CLASS_ID_STORAGE_RAID_BATTERY = "storageRaidBattery"
    CHANGED_MO_CLASS_ID_STORAGE_SAS_EXPANDER = "storageSasExpander"
    CHANGED_MO_CLASS_ID_STORAGE_SAS_LINK_DESCRIPTOR = "storageSasLinkDescriptor"
    CHANGED_MO_CLASS_ID_STORAGE_SAS_PHY_LINK = "storageSasPhyLink"
    CHANGED_MO_CLASS_ID_STORAGE_SAS_PORT = "storageSasPort"
    CHANGED_MO_CLASS_ID_STORAGE_SAS_PORT_DESCRIPTOR = "storageSasPortDescriptor"
    CHANGED_MO_CLASS_ID_STORAGE_SAS_UP_LINK = "storageSasUpLink"
    CHANGED_MO_CLASS_ID_STORAGE_SCSI_LUN_REF = "storageScsiLunRef"
    CHANGED_MO_CLASS_ID_STORAGE_SSD_HEALTH_STATS = "storageSsdHealthStats"
    CHANGED_MO_CLASS_ID_STORAGE_SSD_HEALTH_STATS_HIST = "storageSsdHealthStatsHist"
    CHANGED_MO_CLASS_ID_STORAGE_SYSTEM = "storageSystem"
    CHANGED_MO_CLASS_ID_STORAGE_SYSTEM_FSM = "storageSystemFsm"
    CHANGED_MO_CLASS_ID_STORAGE_SYSTEM_FSM_STAGE = "storageSystemFsmStage"
    CHANGED_MO_CLASS_ID_STORAGE_SYSTEM_FSM_TASK = "storageSystemFsmTask"
    CHANGED_MO_CLASS_ID_STORAGE_TARGET = "storageTarget"
    CHANGED_MO_CLASS_ID_STORAGE_TARGET_IF = "storageTargetIf"
    CHANGED_MO_CLASS_ID_STORAGE_TRANSPORT_IF = "storageTransportIf"
    CHANGED_MO_CLASS_ID_STORAGE_TRANSPORTABLE_FLASH_MODULE = "storageTransportableFlashModule"
    CHANGED_MO_CLASS_ID_STORAGE_UNIT = "storageUnit"
    CHANGED_MO_CLASS_ID_STORAGE_VDMEMBER_EP = "storageVDMemberEp"
    CHANGED_MO_CLASS_ID_STORAGE_VIRTUAL_DRIVE = "storageVirtualDrive"
    CHANGED_MO_CLASS_ID_STORAGE_VIRTUAL_DRIVE_CONTAINER = "storageVirtualDriveContainer"
    CHANGED_MO_CLASS_ID_STORAGE_VIRTUAL_DRIVE_EP = "storageVirtualDriveEp"
    CHANGED_MO_CLASS_ID_STORAGE_VIRTUAL_DRIVE_REF = "storageVirtualDriveRef"
    CHANGED_MO_CLASS_ID_STORAGE_VSAN_REF = "storageVsanRef"
    CHANGED_MO_CLASS_ID_SW_ACCESS_DOMAIN = "swAccessDomain"
    CHANGED_MO_CLASS_ID_SW_ACCESS_DOMAIN_FSM = "swAccessDomainFsm"
    CHANGED_MO_CLASS_ID_SW_ACCESS_DOMAIN_FSM_STAGE = "swAccessDomainFsmStage"
    CHANGED_MO_CLASS_ID_SW_ACCESS_DOMAIN_FSM_TASK = "swAccessDomainFsmTask"
    CHANGED_MO_CLASS_ID_SW_ACCESS_EP = "swAccessEp"
    CHANGED_MO_CLASS_ID_SW_BORDER_DOMAIN = "swBorderDomain"
    CHANGED_MO_CLASS_ID_SW_BORDER_EP = "swBorderEp"
    CHANGED_MO_CLASS_ID_SW_BORDER_PC = "swBorderPc"
    CHANGED_MO_CLASS_ID_SW_CIO_EP = "swCIoEp"
    CHANGED_MO_CLASS_ID_SW_CARD_ENV_STATS = "swCardEnvStats"
    CHANGED_MO_CLASS_ID_SW_CARD_ENV_STATS_HIST = "swCardEnvStatsHist"
    CHANGED_MO_CLASS_ID_SW_CMCLAN = "swCmclan"
    CHANGED_MO_CLASS_ID_SW_DOMAIN = "swDomain"
    CHANGED_MO_CLASS_ID_SW_ENV_STATS = "swEnvStats"
    CHANGED_MO_CLASS_ID_SW_ENV_STATS_HIST = "swEnvStatsHist"
    CHANGED_MO_CLASS_ID_SW_ESTC_EP = "swEstcEp"
    CHANGED_MO_CLASS_ID_SW_ETH_ESTC_EP = "swEthEstcEp"
    CHANGED_MO_CLASS_ID_SW_ETH_ESTC_PC = "swEthEstcPc"
    CHANGED_MO_CLASS_ID_SW_ETH_FLOW_MON_SESSION = "swEthFlowMonSession"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_BORDER = "swEthLanBorder"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_BORDER_FSM = "swEthLanBorderFsm"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_BORDER_FSM_STAGE = "swEthLanBorderFsmStage"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_BORDER_FSM_TASK = "swEthLanBorderFsmTask"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_EP = "swEthLanEp"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_FLOW_MON = "swEthLanFlowMon"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_FLOW_MON_EXPORTER = "swEthLanFlowMonExporter"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_FLOW_MON_FSM = "swEthLanFlowMonFsm"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_FLOW_MON_FSM_STAGE = "swEthLanFlowMonFsmStage"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_FLOW_MON_FSM_TASK = "swEthLanFlowMonFsmTask"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_FLOW_MONITOR = "swEthLanFlowMonitor"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_FLOW_RECORD_DEF = "swEthLanFlowRecordDef"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_MON = "swEthLanMon"
    CHANGED_MO_CLASS_ID_SW_ETH_LAN_PC = "swEthLanPc"
    CHANGED_MO_CLASS_ID_SW_ETH_MON = "swEthMon"
    CHANGED_MO_CLASS_ID_SW_ETH_MON_DEST_EP = "swEthMonDestEp"
    CHANGED_MO_CLASS_ID_SW_ETH_MON_FSM = "swEthMonFsm"
    CHANGED_MO_CLASS_ID_SW_ETH_MON_FSM_STAGE = "swEthMonFsmStage"
    CHANGED_MO_CLASS_ID_SW_ETH_MON_FSM_TASK = "swEthMonFsmTask"
    CHANGED_MO_CLASS_ID_SW_ETH_MON_SRC_EP = "swEthMonSrcEp"
    CHANGED_MO_CLASS_ID_SW_ETH_TARGET_EP = "swEthTargetEp"
    CHANGED_MO_CLASS_ID_SW_ETHER_PORT = "swEtherPort"
    CHANGED_MO_CLASS_ID_SW_EXT_UTILITY = "swExtUtility"
    CHANGED_MO_CLASS_ID_SW_EXT_UTILITY_FSM = "swExtUtilityFsm"
    CHANGED_MO_CLASS_ID_SW_EXT_UTILITY_FSM_STAGE = "swExtUtilityFsmStage"
    CHANGED_MO_CLASS_ID_SW_EXT_UTILITY_FSM_TASK = "swExtUtilityFsmTask"
    CHANGED_MO_CLASS_ID_SW_FABRIC_ZONE_NS = "swFabricZoneNs"
    CHANGED_MO_CLASS_ID_SW_FABRIC_ZONE_NS_OVERRIDE = "swFabricZoneNsOverride"
    CHANGED_MO_CLASS_ID_SW_FC_ENDPOINT = "swFcEndpoint"
    CHANGED_MO_CLASS_ID_SW_FC_ESTC_EP = "swFcEstcEp"
    CHANGED_MO_CLASS_ID_SW_FC_MON = "swFcMon"
    CHANGED_MO_CLASS_ID_SW_FC_MON_DEST_EP = "swFcMonDestEp"
    CHANGED_MO_CLASS_ID_SW_FC_MON_FSM = "swFcMonFsm"
    CHANGED_MO_CLASS_ID_SW_FC_MON_FSM_STAGE = "swFcMonFsmStage"
    CHANGED_MO_CLASS_ID_SW_FC_MON_FSM_TASK = "swFcMonFsmTask"
    CHANGED_MO_CLASS_ID_SW_FC_MON_SRC_EP = "swFcMonSrcEp"
    CHANGED_MO_CLASS_ID_SW_FC_SAN_BORDER = "swFcSanBorder"
    CHANGED_MO_CLASS_ID_SW_FC_SAN_BORDER_FSM = "swFcSanBorderFsm"
    CHANGED_MO_CLASS_ID_SW_FC_SAN_BORDER_FSM_STAGE = "swFcSanBorderFsmStage"
    CHANGED_MO_CLASS_ID_SW_FC_SAN_BORDER_FSM_TASK = "swFcSanBorderFsmTask"
    CHANGED_MO_CLASS_ID_SW_FC_SAN_EP = "swFcSanEp"
    CHANGED_MO_CLASS_ID_SW_FC_SAN_MON = "swFcSanMon"
    CHANGED_MO_CLASS_ID_SW_FC_SAN_PC = "swFcSanPc"
    CHANGED_MO_CLASS_ID_SW_FC_SERVER_ZONE_GROUP = "swFcServerZoneGroup"
    CHANGED_MO_CLASS_ID_SW_FC_USER_ZONE = "swFcUserZone"
    CHANGED_MO_CLASS_ID_SW_FC_USER_ZONE_GROUP = "swFcUserZoneGroup"
    CHANGED_MO_CLASS_ID_SW_FC_ZONE = "swFcZone"
    CHANGED_MO_CLASS_ID_SW_FC_ZONE_MEMBER = "swFcZoneMember"
    CHANGED_MO_CLASS_ID_SW_FC_ZONE_SET = "swFcZoneSet"
    CHANGED_MO_CLASS_ID_SW_FCOE_ESTC_EP = "swFcoeEstcEp"
    CHANGED_MO_CLASS_ID_SW_FCOE_SAN_EP = "swFcoeSanEp"
    CHANGED_MO_CLASS_ID_SW_FCOE_SAN_PC = "swFcoeSanPc"
    CHANGED_MO_CLASS_ID_SW_FLOW_MON_EXPORTER = "swFlowMonExporter"
    CHANGED_MO_CLASS_ID_SW_FLOW_MONITOR = "swFlowMonitor"
    CHANGED_MO_CLASS_ID_SW_FLOW_RECORD_DEF = "swFlowRecordDef"
    CHANGED_MO_CLASS_ID_SW_IP_ROUTE = "swIpRoute"
    CHANGED_MO_CLASS_ID_SW_LAN_BORDER = "swLanBorder"
    CHANGED_MO_CLASS_ID_SW_LAN_EP = "swLanEp"
    CHANGED_MO_CLASS_ID_SW_LAN_MON = "swLanMon"
    CHANGED_MO_CLASS_ID_SW_LAN_PC = "swLanPc"
    CHANGED_MO_CLASS_ID_SW_MON = "swMon"
    CHANGED_MO_CLASS_ID_SW_MON_DEST_EP = "swMonDestEp"
    CHANGED_MO_CLASS_ID_SW_MON_DOMAIN = "swMonDomain"
    CHANGED_MO_CLASS_ID_SW_MON_SRC_EP = "swMonSrcEp"
    CHANGED_MO_CLASS_ID_SW_NFEXPORTER_REF = "swNFExporterRef"
    CHANGED_MO_CLASS_ID_SW_NETFLOW_EXPORTER = "swNetflowExporter"
    CHANGED_MO_CLASS_ID_SW_NETFLOW_MON_SESSION = "swNetflowMonSession"
    CHANGED_MO_CLASS_ID_SW_NETFLOW_MONITOR = "swNetflowMonitor"
    CHANGED_MO_CLASS_ID_SW_NETFLOW_MONITOR_REF = "swNetflowMonitorRef"
    CHANGED_MO_CLASS_ID_SW_NETFLOW_RECORD_DEF = "swNetflowRecordDef"
    CHANGED_MO_CLASS_ID_SW_PIO_EP = "swPIoEp"
    CHANGED_MO_CLASS_ID_SW_PHYS = "swPhys"
    CHANGED_MO_CLASS_ID_SW_PHYS_ETHER_EP = "swPhysEtherEp"
    CHANGED_MO_CLASS_ID_SW_PHYS_FC_EP = "swPhysFcEp"
    CHANGED_MO_CLASS_ID_SW_PHYS_FSM = "swPhysFsm"
    CHANGED_MO_CLASS_ID_SW_PHYS_FSM_STAGE = "swPhysFsmStage"
    CHANGED_MO_CLASS_ID_SW_PHYS_FSM_TASK = "swPhysFsmTask"
    CHANGED_MO_CLASS_ID_SW_PORT_BREAKOUT = "swPortBreakout"
    CHANGED_MO_CLASS_ID_SW_PORT_DISCOVER = "swPortDiscover"
    CHANGED_MO_CLASS_ID_SW_PORT_DISCOVER_FSM = "swPortDiscoverFsm"
    CHANGED_MO_CLASS_ID_SW_PORT_DISCOVER_FSM_STAGE = "swPortDiscoverFsmStage"
    CHANGED_MO_CLASS_ID_SW_PORT_DISCOVER_FSM_TASK = "swPortDiscoverFsmTask"
    CHANGED_MO_CLASS_ID_SW_SAN_BORDER = "swSanBorder"
    CHANGED_MO_CLASS_ID_SW_SAN_EP = "swSanEp"
    CHANGED_MO_CLASS_ID_SW_SAN_MON = "swSanMon"
    CHANGED_MO_CLASS_ID_SW_SAN_PC = "swSanPc"
    CHANGED_MO_CLASS_ID_SW_SUB_GROUP = "swSubGroup"
    CHANGED_MO_CLASS_ID_SW_SYSTEM_STATS = "swSystemStats"
    CHANGED_MO_CLASS_ID_SW_SYSTEM_STATS_HIST = "swSystemStatsHist"
    CHANGED_MO_CLASS_ID_SW_TARGET_EP = "swTargetEp"
    CHANGED_MO_CLASS_ID_SW_ULAN = "swUlan"
    CHANGED_MO_CLASS_ID_SW_UTILITY_DOMAIN = "swUtilityDomain"
    CHANGED_MO_CLASS_ID_SW_UTILITY_DOMAIN_FSM = "swUtilityDomainFsm"
    CHANGED_MO_CLASS_ID_SW_UTILITY_DOMAIN_FSM_STAGE = "swUtilityDomainFsmStage"
    CHANGED_MO_CLASS_ID_SW_UTILITY_DOMAIN_FSM_TASK = "swUtilityDomainFsmTask"
    CHANGED_MO_CLASS_ID_SW_VIFREF = "swVIFRef"
    CHANGED_MO_CLASS_ID_SW_VIRT_L3_INTF = "swVirtL3Intf"
    CHANGED_MO_CLASS_ID_SW_VLAN = "swVlan"
    CHANGED_MO_CLASS_ID_SW_VLAN_GROUP = "swVlanGroup"
    CHANGED_MO_CLASS_ID_SW_VLAN_PORT_NS = "swVlanPortNs"
    CHANGED_MO_CLASS_ID_SW_VLAN_PORT_NS_OVERRIDE = "swVlanPortNsOverride"
    CHANGED_MO_CLASS_ID_SW_VLAN_REF = "swVlanRef"
    CHANGED_MO_CLASS_ID_SW_VSAN = "swVsan"
    CHANGED_MO_CLASS_ID_SW_ZONE_INITIATOR_MEMBER = "swZoneInitiatorMember"
    CHANGED_MO_CLASS_ID_SW_ZONE_TARGET_MEMBER = "swZoneTargetMember"
    CHANGED_MO_CLASS_ID_SWAT_ACTION = "swatAction"
    CHANGED_MO_CLASS_ID_SWAT_CONDITION = "swatCondition"
    CHANGED_MO_CLASS_ID_SWAT_INJECTION = "swatInjection"
    CHANGED_MO_CLASS_ID_SWAT_RESULTSTATS = "swatResultstats"
    CHANGED_MO_CLASS_ID_SWAT_TARGET = "swatTarget"
    CHANGED_MO_CLASS_ID_SWAT_TRIGGER = "swatTrigger"
    CHANGED_MO_CLASS_ID_SYNTHETIC_DIRECTORY = "syntheticDirectory"
    CHANGED_MO_CLASS_ID_SYNTHETIC_FILE = "syntheticFile"
    CHANGED_MO_CLASS_ID_SYNTHETIC_FILE_SYSTEM = "syntheticFileSystem"
    CHANGED_MO_CLASS_ID_SYNTHETIC_FS_OBJ = "syntheticFsObj"
    CHANGED_MO_CLASS_ID_SYNTHETIC_FS_OBJ_FSM = "syntheticFsObjFsm"
    CHANGED_MO_CLASS_ID_SYNTHETIC_FS_OBJ_FSM_STAGE = "syntheticFsObjFsmStage"
    CHANGED_MO_CLASS_ID_SYNTHETIC_FS_OBJ_FSM_TASK = "syntheticFsObjFsmTask"
    CHANGED_MO_CLASS_ID_SYNTHETIC_TIME = "syntheticTime"
    CHANGED_MO_CLASS_ID_SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET = "sysdebugAutoCoreFileExportTarget"
    CHANGED_MO_CLASS_ID_SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET_FSM = "sysdebugAutoCoreFileExportTargetFsm"
    CHANGED_MO_CLASS_ID_SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET_FSM_STAGE = "sysdebugAutoCoreFileExportTargetFsmStage"
    CHANGED_MO_CLASS_ID_SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET_FSM_TASK = "sysdebugAutoCoreFileExportTargetFsmTask"
    CHANGED_MO_CLASS_ID_SYSDEBUG_BACKUP_BEHAVIOR = "sysdebugBackupBehavior"
    CHANGED_MO_CLASS_ID_SYSDEBUG_CORE = "sysdebugCore"
    CHANGED_MO_CLASS_ID_SYSDEBUG_CORE_FILE_EXPORT_TARGET = "sysdebugCoreFileExportTarget"
    CHANGED_MO_CLASS_ID_SYSDEBUG_CORE_FILE_REPOSITORY = "sysdebugCoreFileRepository"
    CHANGED_MO_CLASS_ID_SYSDEBUG_CORE_FSM = "sysdebugCoreFsm"
    CHANGED_MO_CLASS_ID_SYSDEBUG_CORE_FSM_STAGE = "sysdebugCoreFsmStage"
    CHANGED_MO_CLASS_ID_SYSDEBUG_CORE_FSM_TASK = "sysdebugCoreFsmTask"
    CHANGED_MO_CLASS_ID_SYSDEBUG_DIAGNOSTIC_LOG = "sysdebugDiagnosticLog"
    CHANGED_MO_CLASS_ID_SYSDEBUG_DIAGNOSTIC_LOG_REPOSITORY = "sysdebugDiagnosticLogRepository"
    CHANGED_MO_CLASS_ID_SYSDEBUG_EP = "sysdebugEp"
    CHANGED_MO_CLASS_ID_SYSDEBUG_EXPORTER = "sysdebugExporter"
    CHANGED_MO_CLASS_ID_SYSDEBUG_FILE = "sysdebugFile"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_BEHAVIOR = "sysdebugLogBehavior"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_CONTROL_DESTINATION_FILE = "sysdebugLogControlDestinationFile"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_CONTROL_DESTINATION_SYSLOG = "sysdebugLogControlDestinationSyslog"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_CONTROL_DOMAIN = "sysdebugLogControlDomain"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_CONTROL_EP = "sysdebugLogControlEp"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_CONTROL_EP_FSM = "sysdebugLogControlEpFsm"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_CONTROL_EP_FSM_STAGE = "sysdebugLogControlEpFsmStage"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_CONTROL_EP_FSM_TASK = "sysdebugLogControlEpFsmTask"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_CONTROL_MODULE = "sysdebugLogControlModule"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_EXPORT_POLICY = "sysdebugLogExportPolicy"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_EXPORT_POLICY_FSM = "sysdebugLogExportPolicyFsm"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_EXPORT_POLICY_FSM_STAGE = "sysdebugLogExportPolicyFsmStage"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_EXPORT_POLICY_FSM_TASK = "sysdebugLogExportPolicyFsmTask"
    CHANGED_MO_CLASS_ID_SYSDEBUG_LOG_EXPORT_STATUS = "sysdebugLogExportStatus"
    CHANGED_MO_CLASS_ID_SYSDEBUG_MEP_LOG = "sysdebugMEpLog"
    CHANGED_MO_CLASS_ID_SYSDEBUG_MEP_LOG_DEF = "sysdebugMEpLogDef"
    CHANGED_MO_CLASS_ID_SYSDEBUG_MEP_LOG_POLICY = "sysdebugMEpLogPolicy"
    CHANGED_MO_CLASS_ID_SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET = "sysdebugManualCoreFileExportTarget"
    CHANGED_MO_CLASS_ID_SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET_FSM = "sysdebugManualCoreFileExportTargetFsm"
    CHANGED_MO_CLASS_ID_SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET_FSM_STAGE = "sysdebugManualCoreFileExportTargetFsmStage"
    CHANGED_MO_CLASS_ID_SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET_FSM_TASK = "sysdebugManualCoreFileExportTargetFsmTask"
    CHANGED_MO_CLASS_ID_SYSDEBUG_REPOSITORY = "sysdebugRepository"
    CHANGED_MO_CLASS_ID_SYSDEBUG_TECH_SUP_FILE_REPOSITORY = "sysdebugTechSupFileRepository"
    CHANGED_MO_CLASS_ID_SYSDEBUG_TECH_SUPPORT = "sysdebugTechSupport"
    CHANGED_MO_CLASS_ID_SYSDEBUG_TECH_SUPPORT_CMD_OPT = "sysdebugTechSupportCmdOpt"
    CHANGED_MO_CLASS_ID_SYSDEBUG_TECH_SUPPORT_FSM = "sysdebugTechSupportFsm"
    CHANGED_MO_CLASS_ID_SYSDEBUG_TECH_SUPPORT_FSM_STAGE = "sysdebugTechSupportFsmStage"
    CHANGED_MO_CLASS_ID_SYSDEBUG_TECH_SUPPORT_FSM_TASK = "sysdebugTechSupportFsmTask"
    CHANGED_MO_CLASS_ID_SYSFILE_DIGEST = "sysfileDigest"
    CHANGED_MO_CLASS_ID_SYSFILE_EP = "sysfileEp"
    CHANGED_MO_CLASS_ID_SYSFILE_EXPORTER = "sysfileExporter"
    CHANGED_MO_CLASS_ID_SYSFILE_IMPORTER = "sysfileImporter"
    CHANGED_MO_CLASS_ID_SYSFILE_INSTANCE = "sysfileInstance"
    CHANGED_MO_CLASS_ID_SYSFILE_MUTATION = "sysfileMutation"
    CHANGED_MO_CLASS_ID_SYSFILE_MUTATION_FSM = "sysfileMutationFsm"
    CHANGED_MO_CLASS_ID_SYSFILE_MUTATION_FSM_STAGE = "sysfileMutationFsmStage"
    CHANGED_MO_CLASS_ID_SYSFILE_MUTATION_FSM_TASK = "sysfileMutationFsmTask"
    CHANGED_MO_CLASS_ID_SYSFILE_REPOSITORY = "sysfileRepository"
    CHANGED_MO_CLASS_ID_TOP_INFO_POLICY = "topInfoPolicy"
    CHANGED_MO_CLASS_ID_TOP_INFO_SYNC_POLICY = "topInfoSyncPolicy"
    CHANGED_MO_CLASS_ID_TOP_META_INF = "topMetaInf"
    CHANGED_MO_CLASS_ID_TOP_ROOT = "topRoot"
    CHANGED_MO_CLASS_ID_TOP_SYS_DEFAULTS = "topSysDefaults"
    CHANGED_MO_CLASS_ID_TOP_SYSTEM = "topSystem"
    CHANGED_MO_CLASS_ID_TRIG_ABS_WINDOW = "trigAbsWindow"
    CHANGED_MO_CLASS_ID_TRIG_ACK = "trigAck"
    CHANGED_MO_CLASS_ID_TRIG_BASE_ABS_WINDOW = "trigBaseAbsWindow"
    CHANGED_MO_CLASS_ID_TRIG_BASE_RECURR_WINDOW = "trigBaseRecurrWindow"
    CHANGED_MO_CLASS_ID_TRIG_BASE_SCHED = "trigBaseSched"
    CHANGED_MO_CLASS_ID_TRIG_CLIENT_TOKEN = "trigClientToken"
    CHANGED_MO_CLASS_ID_TRIG_CONF_ACK = "trigConfAck"
    CHANGED_MO_CLASS_ID_TRIG_INST = "trigInst"
    CHANGED_MO_CLASS_ID_TRIG_LOCAL_ABS_WINDOW = "trigLocalAbsWindow"
    CHANGED_MO_CLASS_ID_TRIG_LOCAL_SCHED = "trigLocalSched"
    CHANGED_MO_CLASS_ID_TRIG_META = "trigMeta"
    CHANGED_MO_CLASS_ID_TRIG_RECURR_WINDOW = "trigRecurrWindow"
    CHANGED_MO_CLASS_ID_TRIG_RES_ACK = "trigResAck"
    CHANGED_MO_CLASS_ID_TRIG_SCHED = "trigSched"
    CHANGED_MO_CLASS_ID_TRIG_SCHED_WINDOW = "trigSchedWindow"
    CHANGED_MO_CLASS_ID_TRIG_TEST = "trigTest"
    CHANGED_MO_CLASS_ID_TRIG_TOKEN = "trigToken"
    CHANGED_MO_CLASS_ID_TRIG_TRIGGERABLE = "trigTriggerable"
    CHANGED_MO_CLASS_ID_TRIG_TRIGGERED = "trigTriggered"
    CHANGED_MO_CLASS_ID_TRIG_WINDOW = "trigWindow"
    CHANGED_MO_CLASS_ID_UNSPECIFIED = "unspecified"
    CHANGED_MO_CLASS_ID_UUIDPOOL_ADDR = "uuidpoolAddr"
    CHANGED_MO_CLASS_ID_UUIDPOOL_BLOCK = "uuidpoolBlock"
    CHANGED_MO_CLASS_ID_UUIDPOOL_FORMAT = "uuidpoolFormat"
    CHANGED_MO_CLASS_ID_UUIDPOOL_POOL = "uuidpoolPool"
    CHANGED_MO_CLASS_ID_UUIDPOOL_POOLABLE = "uuidpoolPoolable"
    CHANGED_MO_CLASS_ID_UUIDPOOL_POOLED = "uuidpoolPooled"
    CHANGED_MO_CLASS_ID_UUIDPOOL_UNIVERSE = "uuidpoolUniverse"
    CHANGED_MO_CLASS_ID_VERSION_APPLICATION = "versionApplication"
    CHANGED_MO_CLASS_ID_VERSION_EP = "versionEp"
    CHANGED_MO_CLASS_ID_VERSION_VERSION = "versionVersion"
    CHANGED_MO_CLASS_ID_VM_ADAPTOR = "vmAdaptor"
    CHANGED_MO_CLASS_ID_VM_CLIENT_CONTAINER = "vmClientContainer"
    CHANGED_MO_CLASS_ID_VM_COMPUTE_EP = "vmComputeEp"
    CHANGED_MO_CLASS_ID_VM_CONT = "vmCont"
    CHANGED_MO_CLASS_ID_VM_DC = "vmDC"
    CHANGED_MO_CLASS_ID_VM_DCORG = "vmDCOrg"
    CHANGED_MO_CLASS_ID_VM_DIR_CONT = "vmDirCont"
    CHANGED_MO_CLASS_ID_VM_EP = "vmEp"
    CHANGED_MO_CLASS_ID_VM_HBA = "vmHba"
    CHANGED_MO_CLASS_ID_VM_HV = "vmHv"
    CHANGED_MO_CLASS_ID_VM_INSTANCE = "vmInstance"
    CHANGED_MO_CLASS_ID_VM_LIFE_CYCLE_POLICY = "vmLifeCyclePolicy"
    CHANGED_MO_CLASS_ID_VM_LIFE_CYCLE_POLICY_FSM = "vmLifeCyclePolicyFsm"
    CHANGED_MO_CLASS_ID_VM_LIFE_CYCLE_POLICY_FSM_STAGE = "vmLifeCyclePolicyFsmStage"
    CHANGED_MO_CLASS_ID_VM_LIFE_CYCLE_POLICY_FSM_TASK = "vmLifeCyclePolicyFsmTask"
    CHANGED_MO_CLASS_ID_VM_NIC = "vmNic"
    CHANGED_MO_CLASS_ID_VM_ORG = "vmOrg"
    CHANGED_MO_CLASS_ID_VM_SWITCH = "vmSwitch"
    CHANGED_MO_CLASS_ID_VM_VIF = "vmVif"
    CHANGED_MO_CLASS_ID_VM_VIRTUAL = "vmVirtual"
    CHANGED_MO_CLASS_ID_VM_VLAN = "vmVlan"
    CHANGED_MO_CLASS_ID_VM_VNIC_PROF_CL = "vmVnicProfCl"
    CHANGED_MO_CLASS_ID_VM_VNIC_PROF_INST = "vmVnicProfInst"
    CHANGED_MO_CLASS_ID_VM_VSAN = "vmVsan"
    CHANGED_MO_CLASS_ID_VNIC_ABEH = "vnicABeh"
    CHANGED_MO_CLASS_ID_VNIC_AETHER_IF = "vnicAEtherIf"
    CHANGED_MO_CLASS_ID_VNIC_AFC_IF = "vnicAFcIf"
    CHANGED_MO_CLASS_ID_VNIC_AGROUP = "vnicAGroup"
    CHANGED_MO_CLASS_ID_VNIC_AIPC_IF = "vnicAIpcIf"
    CHANGED_MO_CLASS_ID_VNIC_ASCSI_IF = "vnicAScsiIf"
    CHANGED_MO_CLASS_ID_VNIC_BOOT_IP_POLICY = "vnicBootIpPolicy"
    CHANGED_MO_CLASS_ID_VNIC_BOOT_TARGET = "vnicBootTarget"
    CHANGED_MO_CLASS_ID_VNIC_CON_POLICY_REF = "vnicConPolicyRef"
    CHANGED_MO_CLASS_ID_VNIC_CON_REQ = "vnicConReq"
    CHANGED_MO_CLASS_ID_VNIC_CONN_DEF = "vnicConnDef"
    CHANGED_MO_CLASS_ID_VNIC_CONNECTION = "vnicConnection"
    CHANGED_MO_CLASS_ID_VNIC_DEF_BEH = "vnicDefBeh"
    CHANGED_MO_CLASS_ID_VNIC_DYNAMIC_CON = "vnicDynamicCon"
    CHANGED_MO_CLASS_ID_VNIC_DYNAMIC_CON_POLICY = "vnicDynamicConPolicy"
    CHANGED_MO_CLASS_ID_VNIC_DYNAMIC_CON_POLICY_REF = "vnicDynamicConPolicyRef"
    CHANGED_MO_CLASS_ID_VNIC_DYNAMIC_CON_REQ = "vnicDynamicConReq"
    CHANGED_MO_CLASS_ID_VNIC_DYNAMIC_ID_UNIVERSE = "vnicDynamicIdUniverse"
    CHANGED_MO_CLASS_ID_VNIC_DYNAMIC_PROVIDER = "vnicDynamicProvider"
    CHANGED_MO_CLASS_ID_VNIC_DYNAMIC_PROVIDER_EP = "vnicDynamicProviderEp"
    CHANGED_MO_CLASS_ID_VNIC_ETH_CONFIG = "vnicEthConfig"
    CHANGED_MO_CLASS_ID_VNIC_ETH_LIF = "vnicEthLif"
    CHANGED_MO_CLASS_ID_VNIC_ETHER = "vnicEther"
    CHANGED_MO_CLASS_ID_VNIC_ETHER_BASE = "vnicEtherBase"
    CHANGED_MO_CLASS_ID_VNIC_ETHER_BASE_IF = "vnicEtherBaseIf"
    CHANGED_MO_CLASS_ID_VNIC_ETHER_IF = "vnicEtherIf"
    CHANGED_MO_CLASS_ID_VNIC_FC = "vnicFc"
    CHANGED_MO_CLASS_ID_VNIC_FC_BASE = "vnicFcBase"
    CHANGED_MO_CLASS_ID_VNIC_FC_GROUP_DEF = "vnicFcGroupDef"
    CHANGED_MO_CLASS_ID_VNIC_FC_GROUP_TEMPL = "vnicFcGroupTempl"
    CHANGED_MO_CLASS_ID_VNIC_FC_IF = "vnicFcIf"
    CHANGED_MO_CLASS_ID_VNIC_FC_LIF = "vnicFcLif"
    CHANGED_MO_CLASS_ID_VNIC_FC_NODE = "vnicFcNode"
    CHANGED_MO_CLASS_ID_VNIC_FC_OEIF = "vnicFcOEIf"
    CHANGED_MO_CLASS_ID_VNIC_IPIF = "vnicIPIf"
    CHANGED_MO_CLASS_ID_VNIC_IPV4_DHCP = "vnicIPv4Dhcp"
    CHANGED_MO_CLASS_ID_VNIC_IPV4_DNS = "vnicIPv4Dns"
    CHANGED_MO_CLASS_ID_VNIC_IPV4_IF = "vnicIPv4If"
    CHANGED_MO_CLASS_ID_VNIC_IPV4_ISCSI_ADDR = "vnicIPv4IscsiAddr"
    CHANGED_MO_CLASS_ID_VNIC_IPV4_POOLED_ISCSI_ADDR = "vnicIPv4PooledIscsiAddr"
    CHANGED_MO_CLASS_ID_VNIC_IPV4_STATIC_ROUTE = "vnicIPv4StaticRoute"
    CHANGED_MO_CLASS_ID_VNIC_IPV6_IF = "vnicIPv6If"
    CHANGED_MO_CLASS_ID_VNIC_ISCSI = "vnicIScsi"
    CHANGED_MO_CLASS_ID_VNIC_ISCSI_AUTO_TARGET_IF = "vnicIScsiAutoTargetIf"
    CHANGED_MO_CLASS_ID_VNIC_ISCSI_BASE = "vnicIScsiBase"
    CHANGED_MO_CLASS_ID_VNIC_ISCSI_BOOT_PARAMS = "vnicIScsiBootParams"
    CHANGED_MO_CLASS_ID_VNIC_ISCSI_BOOT_VNIC = "vnicIScsiBootVnic"
    CHANGED_MO_CLASS_ID_VNIC_ISCSI_CONFIG = "vnicIScsiConfig"
    CHANGED_MO_CLASS_ID_VNIC_ISCSI_INIT_AUTO_CONFIG_POLICY = "vnicIScsiInitAutoConfigPolicy"
    CHANGED_MO_CLASS_ID_VNIC_ISCSI_LCP = "vnicIScsiLCP"
    CHANGED_MO_CLASS_ID_VNIC_ISCSI_NODE = "vnicIScsiNode"
    CHANGED_MO_CLASS_ID_VNIC_ISCSI_STATIC_TARGET_IF = "vnicIScsiStaticTargetIf"
    CHANGED_MO_CLASS_ID_VNIC_ISCSI_TARGET_IF = "vnicIScsiTargetIf"
    CHANGED_MO_CLASS_ID_VNIC_IF = "vnicIf"
    CHANGED_MO_CLASS_ID_VNIC_IF_ROLE = "vnicIfRole"
    CHANGED_MO_CLASS_ID_VNIC_INITIATOR_AUTO_CONFIG_POLICY = "vnicInitiatorAutoConfigPolicy"
    CHANGED_MO_CLASS_ID_VNIC_INTERNAL_PROFILE = "vnicInternalProfile"
    CHANGED_MO_CLASS_ID_VNIC_IP_ADDR = "vnicIpAddr"
    CHANGED_MO_CLASS_ID_VNIC_IP_V4_ADDR = "vnicIpV4Addr"
    CHANGED_MO_CLASS_ID_VNIC_IP_V4_ADDR_CONF = "vnicIpV4AddrConf"
    CHANGED_MO_CLASS_ID_VNIC_IP_V4_ADDR_EXPL_CONF = "vnicIpV4AddrExplConf"
    CHANGED_MO_CLASS_ID_VNIC_IP_V4_HISTORY = "vnicIpV4History"
    CHANGED_MO_CLASS_ID_VNIC_IP_V4_MGMT_POOLED_ADDR = "vnicIpV4MgmtPooledAddr"
    CHANGED_MO_CLASS_ID_VNIC_IP_V4_POOLED_ADDR = "vnicIpV4PooledAddr"
    CHANGED_MO_CLASS_ID_VNIC_IP_V4_PROF_DERIVED_ADDR = "vnicIpV4ProfDerivedAddr"
    CHANGED_MO_CLASS_ID_VNIC_IP_V4_STATIC_ADDR = "vnicIpV4StaticAddr"
    CHANGED_MO_CLASS_ID_VNIC_IP_V6_ADDR = "vnicIpV6Addr"
    CHANGED_MO_CLASS_ID_VNIC_IP_V6_ADDR_CONF = "vnicIpV6AddrConf"
    CHANGED_MO_CLASS_ID_VNIC_IP_V6_ADDR_EXPL_CONF = "vnicIpV6AddrExplConf"
    CHANGED_MO_CLASS_ID_VNIC_IP_V6_HISTORY = "vnicIpV6History"
    CHANGED_MO_CLASS_ID_VNIC_IP_V6_MGMT_POOLED_ADDR = "vnicIpV6MgmtPooledAddr"
    CHANGED_MO_CLASS_ID_VNIC_IP_V6_STATIC_ADDR = "vnicIpV6StaticAddr"
    CHANGED_MO_CLASS_ID_VNIC_IPC = "vnicIpc"
    CHANGED_MO_CLASS_ID_VNIC_IPC_IF = "vnicIpcIf"
    CHANGED_MO_CLASS_ID_VNIC_IQN_HISTORY = "vnicIqnHistory"
    CHANGED_MO_CLASS_ID_VNIC_L2_IF = "vnicL2If"
    CHANGED_MO_CLASS_ID_VNIC_L2_LIF = "vnicL2Lif"
    CHANGED_MO_CLASS_ID_VNIC_L3_IF = "vnicL3If"
    CHANGED_MO_CLASS_ID_VNIC_LAN_CONN_POLICY = "vnicLanConnPolicy"
    CHANGED_MO_CLASS_ID_VNIC_LAN_CONN_TEMPL = "vnicLanConnTempl"
    CHANGED_MO_CLASS_ID_VNIC_LIF_VLAN = "vnicLifVlan"
    CHANGED_MO_CLASS_ID_VNIC_LIF_VSAN = "vnicLifVsan"
    CHANGED_MO_CLASS_ID_VNIC_LUN = "vnicLun"
    CHANGED_MO_CLASS_ID_VNIC_MAC_HISTORY = "vnicMacHistory"
    CHANGED_MO_CLASS_ID_VNIC_NIC_CONN = "vnicNicConn"
    CHANGED_MO_CLASS_ID_VNIC_OPROFILE_ALIAS = "vnicOProfileAlias"
    CHANGED_MO_CLASS_ID_VNIC_PROFILE = "vnicProfile"
    CHANGED_MO_CLASS_ID_VNIC_PROFILE_ALIAS = "vnicProfileAlias"
    CHANGED_MO_CLASS_ID_VNIC_PROFILE_REF = "vnicProfileRef"
    CHANGED_MO_CLASS_ID_VNIC_PROFILE_SET = "vnicProfileSet"
    CHANGED_MO_CLASS_ID_VNIC_PROFILE_SET_FSM = "vnicProfileSetFsm"
    CHANGED_MO_CLASS_ID_VNIC_PROFILE_SET_FSM_STAGE = "vnicProfileSetFsmStage"
    CHANGED_MO_CLASS_ID_VNIC_PROFILE_SET_FSM_TASK = "vnicProfileSetFsmTask"
    CHANGED_MO_CLASS_ID_VNIC_RACK_SERVER_DISCOVERY_PROFILE = "vnicRackServerDiscoveryProfile"
    CHANGED_MO_CLASS_ID_VNIC_SAN_CONN_POLICY = "vnicSanConnPolicy"
    CHANGED_MO_CLASS_ID_VNIC_SAN_CONN_TEMPL = "vnicSanConnTempl"
    CHANGED_MO_CLASS_ID_VNIC_SCSI = "vnicScsi"
    CHANGED_MO_CLASS_ID_VNIC_SCSI_IF = "vnicScsiIf"
    CHANGED_MO_CLASS_ID_VNIC_TEMPL = "vnicTempl"
    CHANGED_MO_CLASS_ID_VNIC_USNIC_CON_POLICY = "vnicUsnicConPolicy"
    CHANGED_MO_CLASS_ID_VNIC_USNIC_CON_POLICY_REF = "vnicUsnicConPolicyRef"
    CHANGED_MO_CLASS_ID_VNIC_USNIC_CON_REQ = "vnicUsnicConReq"
    CHANGED_MO_CLASS_ID_VNIC_VPROFILE_ALIAS = "vnicVProfileAlias"
    CHANGED_MO_CLASS_ID_VNIC_VHBA_BEH_POLICY = "vnicVhbaBehPolicy"
    CHANGED_MO_CLASS_ID_VNIC_VLAN = "vnicVlan"
    CHANGED_MO_CLASS_ID_VNIC_VMQ_CON_POLICY = "vnicVmqConPolicy"
    CHANGED_MO_CLASS_ID_VNIC_VMQ_CON_POLICY_REF = "vnicVmqConPolicyRef"
    CHANGED_MO_CLASS_ID_VNIC_VMQ_CON_REQ = "vnicVmqConReq"
    CHANGED_MO_CLASS_ID_VNIC_VNIC = "vnicVnic"
    CHANGED_MO_CLASS_ID_VNIC_VNIC_BEH_POLICY = "vnicVnicBehPolicy"
    CHANGED_MO_CLASS_ID_VNIC_WWNN_HISTORY = "vnicWwnnHistory"
    CHANGED_MO_CLASS_ID_VNIC_WWPN_HISTORY = "vnicWwpnHistory"
    REF_OBJ_STATUS_CREATED = "created"
    REF_OBJ_STATUS_DELETED = "deleted"
    REF_OBJ_STATUS_INTENT_DELETION = "intent-deletion"
    REF_OBJ_STATUS_MODIFIED = "modified"


class ChangeChangedObjectRef(ManagedObject):
    """This is ChangeChangedObjectRef class."""

    consts = ChangeChangedObjectRefConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("ChangeChangedObjectRef", "changeChangedObjectRef", "ChangedObjectRef[id]", VersionMeta.Version212a, "InputOutput", 0x7f, [], ["read-only"], [], [], [None])

    prop_meta = {
        "centrale_mo_dn": MoPropertyMeta("centrale_mo_dn", "centraleMoDn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "changed_mo_class_id": MoPropertyMeta("changed_mo_class_id", "changedMoClassId", "string", VersionMeta.Version212a, MoPropertyMeta.CREATE_ONLY, 0x2, None, None, None, ["aaaAuthMethod", "aaaAuthRealm", "aaaAuthRealmFsm", "aaaAuthRealmFsmStage", "aaaBanner", "aaaCimcSession", "aaaConfig", "aaaConsoleAuth", "aaaDefaultAuth", "aaaDefinition", "aaaDomain", "aaaDomainAuth", "aaaEp", "aaaEpAuthProfile", "aaaEpFsm", "aaaEpFsmStage", "aaaEpFsmTask", "aaaEpLogin", "aaaEpUser", "aaaExtMgmtCutThruTkn", "aaaItem", "aaaLdapEp", "aaaLdapEpFsm", "aaaLdapEpFsmStage", "aaaLdapGroup", "aaaLdapGroupRule", "aaaLdapProvider", "aaaLocalMgmtCmdLog", "aaaLocale", "aaaLog", "aaaLoginProfile", "aaaModLR", "aaaOrg", "aaaPreLoginBanner", "aaaProvider", "aaaProviderGroup", "aaaProviderRef", "aaaPwdProfile", "aaaRadiusEp", "aaaRadiusEpFsm", "aaaRadiusEpFsmStage", "aaaRadiusProvider", "aaaRealm", "aaaRealmFsm", "aaaRealmFsmStage", "aaaRealmFsmTask", "aaaRemoteUser", "aaaRole", "aaaSession", "aaaSessionInfo", "aaaSessionInfoTable", "aaaSessionLR", "aaaShellLogin", "aaaSshAuth", "aaaSystemUser", "aaaTacacsPlusEp", "aaaTacacsPlusEpFsm", "aaaTacacsPlusEpFsmStage", "aaaTacacsPlusProvider", "aaaUser", "aaaUserAction", "aaaUserData", "aaaUserEp", "aaaUserEpFsm", "aaaUserEpFsmStage", "aaaUserEpFsmTask", "aaaUserGroup", "aaaUserLocale", "aaaUserLogin", "aaaUserRole", "aaaWebLogin", "adaptorAzureQosProfile", "adaptorBehCap", "adaptorCIoEp", "adaptorCapDef", "adaptorCapQual", "adaptorCapSpec", "adaptorDiagCap", "adaptorDynamicConfigCap", "adaptorEthAdvFilterProfile", "adaptorEthArfsProfile", "adaptorEthCompQueueProfile", "adaptorEthFailoverProfile", "adaptorEthGENEVEProfile", "adaptorEthInterruptProfile", "adaptorEthInterruptScalingProfile", "adaptorEthNVGREProfile", "adaptorEthOffloadProfile", "adaptorEthPortBySizeLargeStats", "adaptorEthPortBySizeLargeStatsHist", "adaptorEthPortBySizeSmallStats", "adaptorEthPortBySizeSmallStatsHist", "adaptorEthPortErrStats", "adaptorEthPortErrStatsHist", "adaptorEthPortMcastStats", "adaptorEthPortMcastStatsHist", "adaptorEthPortOutsizedStats", "adaptorEthPortOutsizedStatsHist", "adaptorEthPortStats", "adaptorEthPortStatsHist", "adaptorEthQueueProfile", "adaptorEthRecvQueueProfile", "adaptorEthRoCEProfile", "adaptorEthVxLANProfile", "adaptorEthWorkQueueProfile", "adaptorEtherIfStats", "adaptorEtherIfStatsHist", "adaptorExtEthIf", "adaptorExtEthIfFsm", "adaptorExtEthIfFsmStage", "adaptorExtEthIfFsmTask", "adaptorExtEthIfPc", "adaptorExtEthIfPcEp", "adaptorExtIf", "adaptorExtIfEp", "adaptorExtIfPc", "adaptorExtIpV6RssHashProfile", "adaptorExternalEp", "adaptorExternalPc", "adaptorFamilyTypeDef", "adaptorFcCdbWorkQueueProfile", "adaptorFcErrorRecoveryProfile", "adaptorFcFnicProfile", "adaptorFcIfEventStats", "adaptorFcIfEventStatsHist", "adaptorFcIfFC4Stats", "adaptorFcIfFC4StatsHist", "adaptorFcIfFrameStats", "adaptorFcIfFrameStatsHist", "adaptorFcInterruptProfile", "adaptorFcLogiProfile", "adaptorFcOEIf", "adaptorFcPortFLogiProfile", "adaptorFcPortPLogiProfile", "adaptorFcPortProfile", "adaptorFcPortStats", "adaptorFcPortStatsHist", "adaptorFcQueueProfile", "adaptorFcRecvQueueProfile", "adaptorFcVhbaTypeProfile", "adaptorFcWorkQueueProfile", "adaptorFruCapProvider", "adaptorFruCapRef", "adaptorFwCapProvider", "adaptorHostEthIf", "adaptorHostEthIfFsm", "adaptorHostEthIfFsmStage", "adaptorHostEthIfFsmTask", "adaptorHostEthIfProfile", "adaptorHostFcIf", "adaptorHostFcIfFsm", "adaptorHostFcIfFsmStage", "adaptorHostFcIfFsmTask", "adaptorHostFcIfProfile", "adaptorHostIf", "adaptorHostIfConfig", "adaptorHostIfConnDef", "adaptorHostIfProfile", "adaptorHostIscsiIf", "adaptorHostIscsiIfProfile", "adaptorHostMgmtCap", "adaptorHostPort", "adaptorHostPortCap", "adaptorHostScsiIf", "adaptorHostScsiLunRef", "adaptorHostServiceEthIf", "adaptorHostVnicHwAddrCap", "adaptorHostethHwAddrCap", "adaptorHostfcHwAddrCap", "adaptorHwAddrCap", "adaptorIScsiCap", "adaptorIpV4RssHashProfile", "adaptorIpV6RssHashProfile", "adaptorIscsiAuth", "adaptorIscsiProt", "adaptorIscsiTargetIf", "adaptorLanCap", "adaptorLldpCap", "adaptorMenloBaseErrorStats", "adaptorMenloBaseErrorStatsHist", "adaptorMenloDcePortStats", "adaptorMenloDcePortStatsHist", "adaptorMenloEthErrorStats", "adaptorMenloEthErrorStatsHist", "adaptorMenloEthStats", "adaptorMenloEthStatsHist", "adaptorMenloFcErrorStats", "adaptorMenloFcErrorStatsHist", "adaptorMenloFcStats", "adaptorMenloFcStatsHist", "adaptorMenloHostPortStats", "adaptorMenloHostPortStatsHist", "adaptorMenloMcpuErrorStats", "adaptorMenloMcpuErrorStatsHist", "adaptorMenloMcpuStats", "adaptorMenloMcpuStatsHist", "adaptorMenloNetEgStats", "adaptorMenloNetEgStatsHist", "adaptorMenloNetInStats", "adaptorMenloNetInStatsHist", "adaptorMenloQErrorStats", "adaptorMenloQErrorStatsHist", "adaptorMenloQStats", "adaptorMenloQStatsHist", "adaptorMgmtCap", "adaptorMgmtVnicEthConfig", "adaptorNwMgmtCap", "adaptorNwStatsMgmtCap", "adaptorPIoEp", "adaptorProfileItem", "adaptorProtocolProfile", "adaptorQual", "adaptorQueueProfile", "adaptorRnicCapSpec", "adaptorRssHashProfile", "adaptorRssProfile", "adaptorSanCap", "adaptorTcpIpRssHashProfile", "adaptorUnit", "adaptorUnitAssocCtx", "adaptorUnitExtn", "adaptorUplinkHwAddrCap", "adaptorUplinkPortStats", "adaptorUsnicConnDef", "adaptorVlan", "adaptorVmmqConnDef", "adaptorVnicStats", "adaptorVnicStatsHist", "adaptorVsan", "apeAdapter", "apeAdapterVnic", "apeAttribute", "apeBootMethod", "apeControllerChassis", "apeControllerEeprom", "apeControllerManager", "apeDcosAgManager", "apeFru", "apeHostAgent", "apeLANBoot", "apeLocalDiskBoot", "apeManager", "apeMc", "apeMcStats", "apeMcTable", "apeMenlo", "apeMenloVnic", "apeMenloVnicStats", "apeNicAgManager", "apePalo", "apePaloVnic", "apePaloVnicStats", "apeParam", "apeReading", "apeSANBoot", "apeSdr", "apeSwitchFirmwareInv", "apeVirtualMediaBoot", "apeVnicStats", "biosARef", "biosBOT", "biosBootDev", "biosBootDevGrp", "biosFeatureRef", "biosParameterRef", "biosRef", "biosSettingRef", "biosSettings", "biosTokenFeatureGroup", "biosTokenParam", "biosTokenSettings", "biosUnit", "biosVFeat", "biosVIdentityParams", "biosVProfile", "biosVfACPI10Support", "biosVfASPMSupport", "biosVfAllUSBDevices", "biosVfAltitude", "biosVfAssertNMIOnPERR", "biosVfAssertNMIOnSERR", "biosVfBMEDMAMitigation", "biosVfBootOptionRetry", "biosVfCPUHardwarePowerManagement", "biosVfCPUPerformance", "biosVfConsistentDeviceNameControl", "biosVfConsoleRedirection", "biosVfCoreMultiProcessing", "biosVfDDR3VoltageSelection", "biosVfDRAMClockThrottling", "biosVfDirectCacheAccess", "biosVfDramRefreshRate", "biosVfEnergyPerformanceTuning", "biosVfEnhancedIntelSpeedStepTech", "biosVfEnhancedPowerCappingSupport", "biosVfExecuteDisableBit", "biosVfFRB2Timer", "biosVfFrequencyFloorOverride", "biosVfFrontPanelLockout", "biosVfIOEMezz1OptionROM", "biosVfIOENVMe1OptionROM", "biosVfIOENVMe2OptionROM", "biosVfIOESlot1OptionROM", "biosVfIOESlot2OptionROM", "biosVfIntegratedGraphics", "biosVfIntegratedGraphicsApertureSize", "biosVfIntelEntrySASRAIDModule", "biosVfIntelHyperThreadingTech", "biosVfIntelTrustedExecutionTechnology", "biosVfIntelTurboBoostTech", "biosVfIntelVTForDirectedIO", "biosVfIntelVirtualizationTechnology", "biosVfInterleaveConfiguration", "biosVfLocalX2Apic", "biosVfLvDIMMSupport", "biosVfMaxVariableMTRRSetting", "biosVfMaximumMemoryBelow4GB", "biosVfMemoryMappedIOAbove4GB", "biosVfMirroringMode", "biosVfNUMAOptimized", "biosVfOSBootWatchdogTimer", "biosVfOSBootWatchdogTimerPolicy", "biosVfOSBootWatchdogTimerTimeout", "biosVfOnboardGraphics", "biosVfOnboardSATAController", "biosVfOnboardStorage", "biosVfOptionROMEnable", "biosVfOptionROMLoad", "biosVfOutOfBandManagement", "biosVfPCHSATAMode", "biosVfPCILOMPortsConfiguration", "biosVfPCIROMCLP", "biosVfPCISlotLinkSpeed", "biosVfPCISlotOptionROMEnable", "biosVfPOSTErrorPause", "biosVfPSTATECoordination", "biosVfPackageCStateLimit", "biosVfPanicAndHighWatermark", "biosVfProcessorC1E", "biosVfProcessorC3Report", "biosVfProcessorC6Report", "biosVfProcessorC7Report", "biosVfProcessorCMCI", "biosVfProcessorCState", "biosVfProcessorEnergyConfiguration", "biosVfProcessorPrefetchConfig", "biosVfQPILinkFrequencySelect", "biosVfQPISnoopMode", "biosVfQuietBoot", "biosVfRedirectionAfterBIOSPOST", "biosVfResumeOnACPowerLoss", "biosVfSBMezz1OptionROM", "biosVfSBNVMe1OptionROM", "biosVfSIOC1OptionROM", "biosVfSIOC2OptionROM", "biosVfScrubPolicies", "biosVfSelectMemoryRASConfiguration", "biosVfSerialPortAEnable", "biosVfSparingMode", "biosVfSriovConfig", "biosVfTPMPendingOperation", "biosVfTPMSupport", "biosVfTrustedPlatformModule", "biosVfUCSMBootModeControl", "biosVfUCSMBootOrderRuleControl", "biosVfUEFIOSUseLegacyVideo", "biosVfUSBBootConfig", "biosVfUSBConfiguration", "biosVfUSBFrontPanelAccessLock", "biosVfUSBPortConfiguration", "biosVfUSBSystemIdlePowerOptimizingSetting", "biosVfVGAPriority", "biosVfWorkloadConfiguration", "bmcSELCounter", "callhomeAnonymousReporting", "callhomeDest", "callhomeEp", "callhomeEpFsm", "callhomeEpFsmStage", "callhomeEpFsmTask", "callhomeItem", "callhomePeriodicSystemInventory", "callhomePolicy", "callhomeProfile", "callhomeSmtp", "callhomeSource", "callhomeTestAlert", "capabilityAEndPointConfig", "capabilityASolutionStack", "capabilityCatalogue", "capabilityCatalogueFsm", "capabilityCatalogueFsmStage", "capabilityCatalogueFsmTask", "capabilityDef", "capabilityEp", "capabilityFeatureLimits", "capabilityItem", "capabilityMgmtExtension", "capabilityMgmtExtensionFsm", "capabilityMgmtExtensionFsmStage", "capabilityMgmtExtensionFsmTask", "capabilityNetworkLimits", "capabilityProvider", "capabilityStorageLimits", "capabilitySystemLimits", "capabilityUpdate", "capabilityUpdater", "capabilityUpdaterFsm", "capabilityUpdaterFsmStage", "capabilityUpdaterFsmTask", "changeChangedObjectRef", "cimcvmediaActualMountEntry", "cimcvmediaActualMountList", "cimcvmediaConfigMountEntry", "cimcvmediaExtMgmtRuleEntry", "cimcvmediaItem", "cimcvmediaMountConfig", "cimcvmediaMountConfigDef", "cimcvmediaMountConfigPolicy", "cimcvmediaMountInfo", "clitestTypeTest", "clitestTypeTest2", "clitestTypeTestChild", "clitestTypeTestParent", "cloudDeviceConnectorEp", "cloudMgmtSvc", "commCimcWebService", "commCimxml", "commClient", "commClientItem", "commDateTime", "commDefinition", "commDns", "commDnsProvider", "commEvtChannel", "commHttp", "commHttps", "commItem", "commLocale", "commNtpProvider", "commShell", "commShellSvcLimits", "commSmashCLP", "commSnmp", "commSnmpTrap", "commSnmpUser", "commSsh", "commSvc", "commSvcChannel", "commSvcEp", "commSvcEpFsm", "commSvcEpFsmStage", "commSvcEpFsmTask", "commSvcLimits", "commSvcPolicy", "commSyslog", "commSyslogClient", "commSyslogConsole", "commSyslogFile", "commSyslogMonitor", "commSyslogSource", "commTelnet", "commWeb", "commWebChannel", "commWebSvcLimits", "commWsman", "commXmlClConnPolicy", "computeABoard", "computeAChassisDiscPolicy", "computeAdminAck", "computeAutoconfigPolicy", "computeBehCap", "computeBlade", "computeBladeDiscPolicy", "computeBladeEp", "computeBladeFsm", "computeBladeFsmStage", "computeBladeFsmTask", "computeBladeInheritPolicy", "computeBladePosQual", "computeBoard", "computeBoardConnector", "computeBoardController", "computeCartridge", "computeChassisConnPolicy", "computeChassisDiscPolicy", "computeChassisQual", "computeComputeDiscPolicy", "computeConfigPolicy", "computeConstraintDef", "computeContainer", "computeDefaults", "computeDiscPolicy", "computeExtBoard", "computeFactoryResetOperation", "computeFanPolicy", "computeFwSyncAck", "computeGraphicsCardPolicy", "computeHealthLedSensorAlarm", "computeHostUtilityOs", "computeHwChangeDiscPolicy", "computeIOHub", "computeIOHubEnvStats", "computeIOHubEnvStatsHist", "computeInitConfigPolicy", "computeInstanceIdQual", "computeItem", "computeKvmMgmtPolicy", "computeLogical", "computeMbPowerStats", "computeMbPowerStatsHist", "computeMbTempStats", "computeMbTempStatsHist", "computeMemoryConfigPolicy", "computeMemoryConfiguration", "computeMemoryUnitConstraintDef", "computePCIeFatalCompletionStats", "computePCIeFatalProtocolStats", "computePCIeFatalReceiveStats", "computePCIeFatalStats", "computePartition", "computePciCap", "computePciSlotScanDef", "computePersonality", "computePhysical", "computePhysicalAssocCtx", "computePhysicalExtension", "computePhysicalFsm", "computePhysicalFsmStage", "computePhysicalFsmTask", "computePhysicalQual", "computePlatform", "computePnuOSImage", "computePool", "computePoolPolicyRef", "computePoolable", "computePooled", "computePooledEnclosureComputeSlot", "computePooledPhysical", "computePooledRackUnit", "computePooledSlot", "computePoolingPolicy", "computePortDiscPolicy", "computePowerSavePolicy", "computePowerSyncDef", "computePowerSyncPolicy", "computePsuControl", "computePsuDef", "computePsuPolicy", "computeQual", "computeQualBase", "computeQualItem", "computeQualifiedPolicy", "computeRackConnLinkPolicy", "computeRackPosQual", "computeRackQual", "computeRackUnit", "computeRackUnitFsm", "computeRackUnitFsmStage", "computeRackUnitFsmTask", "computeRackUnitMbTempStats", "computeRackUnitMbTempStatsHist", "computeRebootLog", "computeRtcBattery", "computeScrubPolicy", "computeServer", "computeServerDiscPolicy", "computeServerDiscPolicyFsm", "computeServerDiscPolicyFsmStage", "computeServerDiscPolicyFsmTask", "computeServerMgmtPolicy", "computeServerTypeCap", "computeServerUnit", "computeServerUnitFsm", "computeServerUnitFsmStage", "computeServerUnitFsmTask", "computeSlotEntity", "computeSlotQual", "computeVirtual", "computeVirtualContainer", "conditionImmutable", "conditionInfo", "conditionLog", "conditionLoggable", "conditionMultiInstanceImmutable", "conditionMutable", "conditionPolicy", "conditionReportable", "configImpact", "configImpactResponse", "configManagedEpImpactResponse", "configSorter", "controllerHaController", "controllerMgmtDbCheckPol", "controllerOperationalVersionHolder", "controllerPreferedVersionHolder", "coprocessorCard", "cpmaintAck", "cpmaintMaintPolicy", "dcxFcoeVifEp", "dcxNs", "dcxUniverse", "dcxVIf", "dcxVc", "dcxVifEp", "dhcpAcquired", "dhcpInst", "dhcpLease", "diagCtrl", "diagLogEp", "diagMemoryTest", "diagRslt", "diagRunPolicy", "diagSrvCapProvider", "diagSrvCtrl", "diagTest", "domainChassisFeature", "domainChassisFeatureCont", "domainChassisParam", "domainEnvironmentFeature", "domainEnvironmentFeatureCont", "domainEnvironmentParam", "domainFeature", "domainFeatureCont", "domainNetworkFeature", "domainNetworkFeatureCont", "domainNetworkParam", "domainParameter", "domainServerFeature", "domainServerFeatureCont", "domainServerParam", "domainStorageFeature", "domainStorageFeatureCont", "domainStorageParam", "dpsecMac", "dupeScope", "dupeScopeResult", "epqosDefinition", "epqosDefinitionDelTask", "epqosDefinitionDelTaskFsm", "epqosDefinitionDelTaskFsmStage", "epqosDefinitionDelTaskFsmTask", "epqosDefinitionFsm", "epqosDefinitionFsmStage", "epqosDefinitionFsmTask", "epqosEgress", "epqosItem", "equipmentAdaptorConnDef", "equipmentAdaptorDef", "equipmentAdvancedBootOrder", "equipmentAssocCtx", "equipmentAutoConfigMode", "equipmentAutoconfigPolicy", "equipmentBaseBoardCapProvider", "equipmentBeaconCapProvider", "equipmentBeaconLed", "equipmentBeaconLedFsm", "equipmentBeaconLedFsmStage", "equipmentBeaconLedFsmTask", "equipmentBehCap", "equipmentBinding", "equipmentBiosDef", "equipmentBiosTokenOverride", "equipmentBladeAGLibrary", "equipmentBladeAggregationCapRef", "equipmentBladeBiosCapProvider", "equipmentBladeCapProvider", "equipmentBladeCapProviderTypeDef", "equipmentBladeConnDef", "equipmentBladeIOMConnDef", "equipmentBladeSwitchConnDef", "equipmentBoardControllerDef", "equipmentBootDeviceConstraints", "equipmentBreakoutCap", "equipmentCapModSpec", "equipmentCard", "equipmentCartridgeCapProvider", "equipmentCatalogCapProvider", "equipmentChassis", "equipmentChassisAssocCtx", "equipmentChassisCapProvider", "equipmentChassisFsm", "equipmentChassisFsmStage", "equipmentChassisFsmTask", "equipmentChassisInheritPolicy", "equipmentChassisIssues", "equipmentChassisPosQual", "equipmentChassisProfile", "equipmentChassisProfileAssocCtx", "equipmentChassisProfileBinding", "equipmentChassisProfileFsm", "equipmentChassisProfileFsmStage", "equipmentChassisProfileFsmTask", "equipmentChassisQual", "equipmentChassisStats", "equipmentChassisStatsHist", "equipmentCimcVmedia", "equipmentCiscoOsOpenGate", "equipmentComputeConn", "equipmentComputeConnPolicy", "equipmentComputePhysicalCapProvider", "equipmentConfigPolicy", "equipmentCoprocessorUnitCapProvider", "equipmentDbgPluginCapProvider", "equipmentDiagFeatureSupport", "equipmentDimmEntry", "equipmentDimmMapping", "equipmentDiscoveryCap", "equipmentDowngradeConstraint", "equipmentDriveSecCap", "equipmentEmbeddedControllerConfig", "equipmentEmbeddedStorageDef", "equipmentEnvSensor", "equipmentFan", "equipmentFanAggressiveCoolingCap", "equipmentFanModule", "equipmentFanModuleCapProvider", "equipmentFanModuleDef", "equipmentFanModuleStats", "equipmentFanModuleStatsHist", "equipmentFanPresenceDef", "equipmentFanStats", "equipmentFanStatsHist", "equipmentFex", "equipmentFexCapProvider", "equipmentFexEnvStats", "equipmentFexEnvStatsHist", "equipmentFexFsm", "equipmentFexFsmStage", "equipmentFexFsmTask", "equipmentFexPowerSummary", "equipmentFexPowerSummaryHist", "equipmentFexPsuInputStats", "equipmentFexPsuInputStatsHist", "equipmentFexSystemStats", "equipmentFexSystemStatsHist", "equipmentFirmwareConstraint", "equipmentFlashLife", "equipmentFlexFlashNonRemovable", "equipmentFruCapProvider", "equipmentFruVariant", "equipmentGemCapProvider", "equipmentGemPortCap", "equipmentGraphicsCardCapProvider", "equipmentGraphicsCardCapRef", "equipmentHDDFaultMonDef", "equipmentHealthLed", "equipmentHolder", "equipmentHolderCapProvider", "equipmentHostIfCapProvider", "equipmentHostMgmtControllerCap", "equipmentHwCapDerivativeProvider", "equipmentHwCapProvider", "equipmentHwRevisionModifier", "equipmentHxCap", "equipmentIOCard", "equipmentIOCardBase", "equipmentIOCardBaseFsm", "equipmentIOCardBaseFsmStage", "equipmentIOCardBaseFsmTask", "equipmentIOCardCapProvider", "equipmentIOCardFsm", "equipmentIOCardFsmStage", "equipmentIOCardFsmTask", "equipmentIOCardStats", "equipmentIOCardStatsHist", "equipmentIOCardTypeDef", "equipmentIOExpander", "equipmentIOExpanderCapProvider", "equipmentInbandMgmtCap", "equipmentIndicatorLed", "equipmentInitConfigPolicy", "equipmentIntegratedComponentCapProvider", "equipmentInventoryStatus", "equipmentItem", "equipmentKvmMgmtCap", "equipmentLed", "equipmentLocalDiskCapProvider", "equipmentLocalDiskControllerCapProvider", "equipmentLocalDiskControllerCapRef", "equipmentLocalDiskControllerDef", "equipmentLocalDiskControllerTypeDef", "equipmentLocalDiskDef", "equipmentLocatorLed", "equipmentLocatorLedFsm", "equipmentLocatorLedFsmStage", "equipmentLocatorLedFsmTask", "equipmentManufacturingDef", "equipmentMemoryUnitCapProvider", "equipmentMemoryUnitDiscoveryModifierDef", "equipmentMgmtCapProvider", "equipmentMgmtControllerCap", "equipmentMgmtExtCapProvider", "equipmentMiniStorageCapProvider", "equipmentNetworkElementFanStats", "equipmentNetworkElementFanStatsHist", "equipmentNonCopperPassiveCap", "equipmentNvmeDef", "equipmentNvmeSwitchConfig", "equipmentOnboardDeviceDef", "equipmentPOST", "equipmentPOSTCode", "equipmentPOSTCodeContainer", "equipmentPOSTCodeData", "equipmentPOSTCodeReporter", "equipmentPOSTCodeTemplate", "equipmentPciDef", "equipmentPciSlotIdEntry", "equipmentPciSlotIdMapping", "equipmentPciSlotSubOEMIdEntry", "equipmentPciSwitchCapProvider", "equipmentPcieSlotOrientation", "equipmentPersistentMemoryUnitCapProvider", "equipmentPersonality", "equipmentPfcMmuCap", "equipmentPhysDevicesPerBoard", "equipmentPhysicalDef", "equipmentPhysicalQual", "equipmentPicture", "equipmentPnuosBootMode", "equipmentPool", "equipmentPoolPolicyRef", "equipmentPoolable", "equipmentPooled", "equipmentPooledChassis", "equipmentPooledPhysical", "equipmentPoolingPolicy", "equipmentPortCap", "equipmentPortGroupAggregationDef", "equipmentPortGroupDef", "equipmentPortGroupSwComplexDef", "equipmentPortSwComplexRef", "equipmentPowerCapDef", "equipmentProcessorUnitCapProvider", "equipmentProcessorUnitDef", "equipmentPsu", "equipmentPsuCapProvider", "equipmentPsuDef", "equipmentPsuFsm", "equipmentPsuFsmStage", "equipmentPsuFsmTask", "equipmentPsuInputStats", "equipmentPsuInputStatsHist", "equipmentPsuOutputStats", "equipmentPsuOutputStatsHist", "equipmentPsuStats", "equipmentPsuStatsHist", "equipmentQual", "equipmentQualBase", "equipmentQualItem", "equipmentQualifiedPolicy", "equipmentRackEnclosure", "equipmentRackEnclosureCapProvider", "equipmentRackFanModuleDef", "equipmentRackUnitCapProvider", "equipmentRackUnitFanStats", "equipmentRackUnitFanStatsHist", "equipmentRackUnitPsuStats", "equipmentRackUnitPsuStatsHist", "equipmentRaidDef", "equipmentRequirement", "equipmentSecureBoot", "equipmentSecureController", "equipmentSecurityUnitCapProvider", "equipmentServerCorrectUuidBehavior", "equipmentServerFeatureCap", "equipmentServerPortCapProvider", "equipmentServerUnitCapProvider", "equipmentServiceDef", "equipmentSharedIOModule", "equipmentSiocCapProvider", "equipmentSiocTempStats", "equipmentSiocTempStatsHist", "equipmentSlot", "equipmentSlotArray", "equipmentSlotArrayRef", "equipmentSlotEnclosure", "equipmentSlotEp", "equipmentSpdmCertificateCap", "equipmentSpeedCompatibility", "equipmentStateful", "equipmentStatefulBladeComp", "equipmentStatefulChComp", "equipmentStorageControllerConfig", "equipmentStorageControllerSlotDef", "equipmentStorageEncCapProvider", "equipmentStorageLimitCap", "equipmentStorageNvmeSwitchCapProvider", "equipmentStorageNvmeSwitchDef", "equipmentStorageSasExpanderCapProvider", "equipmentStorageSasExpanderCapRef", "equipmentStorageSasExpanderDef", "equipmentSwitchCap", "equipmentSwitchCapProvider", "equipmentSwitchCard", "equipmentSwitchIOCard", "equipmentSwitchIOCardCapProvider", "equipmentSwitchIOCardFsm", "equipmentSwitchIOCardFsmStage", "equipmentSwitchIOCardFsmTask", "equipmentSwitchTypeDef", "equipmentSystemIOController", "equipmentSystemIOControllerFsm", "equipmentSystemIOControllerFsmStage", "equipmentSystemIOControllerFsmTask", "equipmentTier", "equipmentTpm", "equipmentTpmCapProvider", "equipmentUnifiedPortCapProvider", "equipmentUuidFeatureCap", "equipmentVersionConstraint", "equipmentXcvr", "etherCIoEp", "etherConfig", "etherErrStats", "etherErrStatsHist", "etherExternalEp", "etherExternalPc", "etherFcoeInterfaceStats", "etherFcoeInterfaceStatsHist", "etherIfConfig", "etherIntFIoEp", "etherInternalPc", "etherLossStats", "etherLossStatsHist", "etherNiErrStats", "etherNiErrStatsHist", "etherNicIfConfig", "etherPIo", "etherPIoEndPoint", "etherPIoEp", "etherPIoFsm", "etherPIoFsmStage", "etherPauseStats", "etherPauseStatsHist", "etherPc", "etherPortChanIdElem", "etherPortChanIdUniverse", "etherRxStats", "etherRxStatsHist", "etherServerIntFIo", "etherServerIntFIoFsm", "etherServerIntFIoFsmStage", "etherServerIntFIoFsmTask", "etherServerIntFIoPc", "etherServerIntFIoPcEp", "etherSwIfConfig", "etherSwitchIntFIo", "etherSwitchIntFIoPc", "etherSwitchIntFIoPcEp", "etherTxStats", "etherTxStatsHist", "eventEpCtrl", "eventHolder", "eventInst", "eventLog", "eventPolicy", "eventRecord", "extmgmtArpTargets", "extmgmtGatewayPing", "extmgmtIf", "extmgmtIfMonPolicy", "extmgmtMiiStatus", "extmgmtNdiscTargets", "extpolClient", "extpolClientCont", "extpolConnector", "extpolConnectorContainer", "extpolController", "extpolControllerCont", "extpolEp", "extpolEpFsm", "extpolEpFsmStage", "extpolEpFsmTask", "extpolProvider", "extpolProviderCont", "extpolProviderFsm", "extpolProviderFsmStage", "extpolProviderFsmTask", "extpolRegistry", "extpolRegistryFsm", "extpolRegistryFsmStage", "extpolRegistryFsmTask", "extpolSvc", "extpolSystemContext", "extvmmEp", "extvmmEpFsm", "extvmmEpFsmStage", "extvmmEpFsmTask", "extvmmFNDReference", "extvmmFabricNetwork", "extvmmFabricNetworkDefinition", "extvmmKeyInst", "extvmmKeyRing", "extvmmKeyStore", "extvmmKeyStoreFsm", "extvmmKeyStoreFsmStage", "extvmmKeyStoreFsmTask", "extvmmMasterExtKey", "extvmmMasterExtKeyFsm", "extvmmMasterExtKeyFsmStage", "extvmmMasterExtKeyFsmTask", "extvmmNetworkSets", "extvmmNetworkSetsFsm", "extvmmNetworkSetsFsmStage", "extvmmNetworkSetsFsmTask", "extvmmProvider", "extvmmProviderFsm", "extvmmProviderFsmStage", "extvmmProviderFsmTask", "extvmmSwitchDelTask", "extvmmSwitchDelTaskFsm", "extvmmSwitchDelTaskFsmStage", "extvmmSwitchDelTaskFsmTask", "extvmmSwitchSet", "extvmmUpLinkPP", "extvmmVMNDRef", "extvmmVMNetwork", "extvmmVMNetworkDefinition", "extvmmVMNetworkSets", "fabricADceSwSrvEp", "fabricAEthEstcEp", "fabricAEthLanEp", "fabricAFcEstcEp", "fabricAFcSanEp", "fabricAFcoeEstcEp", "fabricAFcoeSanEp", "fabricANetGroup", "fabricANetGroupRef", "fabricASanGroup", "fabricAVlan", "fabricAVsan", "fabricBHVlan", "fabricBaseNetGroup", "fabricBreakout", "fabricCIoEp", "fabricCabling", "fabricCablingSw", "fabricCartridgePhEp", "fabricCartridgeSlotEp", "fabricCartridgeSlotEpFsm", "fabricCartridgeSlotEpFsmStage", "fabricCartridgeSlotEpFsmTask", "fabricCdpLinkPolicy", "fabricChangedObjectRef", "fabricChassisEp", "fabricCloud", "fabricComputeEp", "fabricComputeMSlotEp", "fabricComputeMSlotEpFsm", "fabricComputeMSlotEpFsmStage", "fabricComputeMSlotEpFsmTask", "fabricComputePhEp", "fabricComputeSlotEp", "fabricComputeSlotEpFsm", "fabricComputeSlotEpFsmStage", "fabricComputeSlotEpFsmTask", "fabricDceSrv", "fabricDceSwSrv", "fabricDceSwSrvEp", "fabricDceSwSrvPc", "fabricDceSwSrvPcEp", "fabricDomain", "fabricEp", "fabricEpMgr", "fabricEpMgrFsm", "fabricEpMgrFsmStage", "fabricEpMgrFsmTask", "fabricEpVlan", "fabricEpVsan", "fabricEquipmentEp", "fabricEstcEp", "fabricEstcPc", "fabricEthCdpPolicy", "fabricEthEstc", "fabricEthEstcCloud", "fabricEthEstcEp", "fabricEthEstcPc", "fabricEthEstcPcEp", "fabricEthFlowMonLan", "fabricEthFlowMonSrcRef", "fabricEthLan", "fabricEthLanEp", "fabricEthLanFlowMon", "fabricEthLanFlowMonCollector", "fabricEthLanFlowMonExporter", "fabricEthLanFlowMonSrcEp", "fabricEthLanFlowMonitor", "fabricEthLanFlowMonitoring", "fabricEthLanPc", "fabricEthLanPcEp", "fabricEthLinkPolicy", "fabricEthLinkProfile", "fabricEthMon", "fabricEthMonDestEp", "fabricEthMonFiltEp", "fabricEthMonFiltRef", "fabricEthMonLan", "fabricEthMonSrcEp", "fabricEthMonSrcRef", "fabricEthTargetEp", "fabricEthUdldPolicy", "fabricEthVlanPc", "fabricEthVlanPortEp", "fabricExternal", "fabricExternalEp", "fabricExternalEstc", "fabricExternalPc", "fabricFcEndpoint", "fabricFcEstc", "fabricFcEstcCloud", "fabricFcEstcEp", "fabricFcMon", "fabricFcMonDestEp", "fabricFcMonFiltEp", "fabricFcMonFiltRef", "fabricFcMonSan", "fabricFcMonSrcEp", "fabricFcMonSrcRef", "fabricFcSan", "fabricFcSanEp", "fabricFcSanPc", "fabricFcSanPcEp", "fabricFcUserZone", "fabricFcVsanPc", "fabricFcVsanPortEp", "fabricFcZoneProfile", "fabricFcoeEstcEp", "fabricFcoeSanEp", "fabricFcoeSanPc", "fabricFcoeSanPcEp", "fabricFcoeVsanPc", "fabricFcoeVsanPortEp", "fabricFlowMon", "fabricFlowMonCollector", "fabricFlowMonDefinition", "fabricFlowMonExporter", "fabricFlowMonExporterProfile", "fabricFlowMonItem", "fabricFlowMonSrcEp", "fabricFlowMonSrcRef", "fabricFlowMonitor", "fabricFlowMonitoringCategory", "fabricIf", "fabricInternal", "fabricInternalDceSrv", "fabricInternalEp", "fabricInternalPc", "fabricLacpPolicy", "fabricLan", "fabricLanAccessMgr", "fabricLanCloud", "fabricLanCloudFsm", "fabricLanCloudFsmStage", "fabricLanCloudFsmTask", "fabricLanCloudPolicy", "fabricLanEp", "fabricLanFlowMon", "fabricLanFlowMonCollector", "fabricLanFlowMonExporter", "fabricLanFlowMonSrcEp", "fabricLanFlowMonitor", "fabricLanMonCloud", "fabricLanPc", "fabricLanPinGroup", "fabricLanPinTarget", "fabricLastAckedSlot", "fabricLinkPolicy", "fabricLocale", "fabricMon", "fabricMonDestEp", "fabricMonFiltRef", "fabricMonSrcEp", "fabricMonSrcFiltEp", "fabricMonSrcRef", "fabricMulticastPolicy", "fabricNetGroup", "fabricNetGroupRef", "fabricNetflowCollector", "fabricNetflowIPv4Addr", "fabricNetflowMonExporter", "fabricNetflowMonExporterRef", "fabricNetflowMonSession", "fabricNetflowMonSrcEp", "fabricNetflowMonSrcRef", "fabricNetflowMonitor", "fabricNetflowMonitorRef", "fabricNetflowTimeoutPolicy", "fabricOrgVlanPolicy", "fabricPIoEp", "fabricPath", "fabricPathConn", "fabricPathEp", "fabricPinGroup", "fabricPinTarget", "fabricPoolableVlan", "fabricPooledVlan", "fabricReservedVlan", "fabricReservedVlanFsm", "fabricReservedVlanFsmStage", "fabricReservedVlanFsmTask", "fabricSan", "fabricSanCloud", "fabricSanCloudFsm", "fabricSanCloudFsmStage", "fabricSanCloudFsmTask", "fabricSanEp", "fabricSanGroup", "fabricSanGroupRef", "fabricSanMonCloud", "fabricSanPc", "fabricSanPinGroup", "fabricSanPinTarget", "fabricSubGroup", "fabricSwChEp", "fabricSwChPhEp", "fabricSwSrvEp", "fabricSwSrvPc", "fabricSwSubGroup", "fabricTargetEp", "fabricUdldLinkPolicy", "fabricUdldPolicy", "fabricVCon", "fabricVConProfile", "fabricVlan", "fabricVlanEp", "fabricVlanGroupPermit", "fabricVlanGroupReq", "fabricVlanPermit", "fabricVlanReq", "fabricVnetEp", "fabricVnetEpSyncEp", "fabricVnetEpSyncEpFsm", "fabricVnetEpSyncEpFsmStage", "fabricVnetEpSyncEpFsmTask", "fabricVnetGroupPermit", "fabricVnetGroupReq", "fabricVnetPermit", "fabricVnetReq", "fabricVsan", "fabricVsanEp", "fabricVsanMembership", "fabricZoneIdUniverse", "faultAffectedClass", "faultBaseHolder", "faultBasePolicy", "faultHolder", "faultInst", "faultLocalTypedHolder", "faultPolicy", "faultSuppressPolicy", "faultSuppressPolicyItem", "faultSuppressTask", "fcConfig", "fcErrStats", "fcErrStatsHist", "fcIfConfig", "fcNicIfConfig", "fcPIo", "fcPIoFsm", "fcPIoFsmStage", "fcStats", "fcStatsHist", "fcSwIfConfig", "fcpoolAddr", "fcpoolBlock", "fcpoolBootTarget", "fcpoolFormat", "fcpoolInitiator", "fcpoolInitiatorEp", "fcpoolInitiators", "fcpoolOui", "fcpoolOuis", "fcpoolOuisFsm", "fcpoolOuisFsmStage", "fcpoolOuisFsmTask", "fcpoolPoolable", "fcpoolUniverse", "featureBaseRef", "featureContextEp", "featureDefinition", "featureDefinitionInstance", "featureDefinitionRef", "featureFruCapProviderInstance", "featureFruCapProviderRef", "featureProvider", "featureProviderInstance", "firmwareABundleTypeCapProvider", "firmwareAChassisConstraint", "firmwareAComponentSpec", "firmwareAConstraint", "firmwareAExcludeComponent", "firmwareAck", "firmwareActivity", "firmwareActivityTrigger", "firmwareAutoSyncPolicy", "firmwareBackupVersionHolder", "firmwareBlade", "firmwareBootDefinition", "firmwareBootUnit", "firmwareBundleInfo", "firmwareBundleInfoDigest", "firmwareBundleType", "firmwareBundleTypeCapProvider", "firmwareCapProvider", "firmwareCatalogPack", "firmwareCatalogue", "firmwareChassisComponentSpec", "firmwareChassisPack", "firmwareChassisPackModImpact", "firmwareCompItem", "firmwareCompSource", "firmwareCompTarget", "firmwareComponentSpec", "firmwareComputeHostPack", "firmwareComputeMgmtPack", "firmwareComputePack", "firmwareConnectionManagementChassisConstraint", "firmwareConstraints", "firmwareDependency", "firmwareDistImage", "firmwareDistributable", "firmwareDistributableFsm", "firmwareDistributableFsmStage", "firmwareDistributableFsmTask", "firmwareDownloader", "firmwareDownloaderFsm", "firmwareDownloaderFsmStage", "firmwareDownloaderFsmTask", "firmwareDriveSecurityConstraint", "firmwareDualVicChassisConstraint", "firmwareDualVicServerConstraint", "firmwareExcludeChassisComponent", "firmwareExcludeServerComponent", "firmwareFileUnit", "firmwareHost", "firmwareHostPackModImpact", "firmwareImage", "firmwareImageFsm", "firmwareImageFsmStage", "firmwareImageFsmTask", "firmwareImageLock", "firmwareInfra", "firmwareInfraPack", "firmwareInstallImpact", "firmwareInstallable", "firmwareModule", "firmwarePCHStorageConfigConstraint", "firmwarePack", "firmwarePackItem", "firmwarePlatformBundleTypeCapProvider", "firmwareProcessorTypeConstraint", "firmwareRack", "firmwareRackPowerCapConstraint", "firmwareRunning", "firmwareSecondControllerChassisConstraint", "firmwareSecondControllerServerConstraint", "firmwareSecureFPGA", "firmwareServerChassisConstraint", "firmwareServerTypeConstraint", "firmwareServicePack", "firmwareSinglePathChassisConstraint", "firmwareSpec", "firmwareStatus", "firmwareSystem", "firmwareSystemCompCheckResult", "firmwareSystemFsm", "firmwareSystemFsmStage", "firmwareSystemFsmTask", "firmwareTPMConstraint", "firmwareType", "firmwareUcscInfo", "firmwareUnit", "firmwareUpdatable", "firmwareUpgradeConstraint", "firmwareUpgradeDetail", "firmwareUpgradeInfo", "firmwareVicSlotConstraint", "firmwareVnicCdnConstraint", "firmwareWaterbaySiocServerConstraint", "flowctrlDefinition", "flowctrlItem", "fsmFsm", "fsmStage", "fsmStatus", "fsmTask", "gmetaClass", "gmetaEp", "gmetaHolder", "gmetaHolderFsm", "gmetaHolderFsmStage", "gmetaHolderFsmTask", "gmetaPolicyMapElement", "gmetaPolicyMapHolder", "gmetaProp", "graphicsCard", "graphicsController", "hostimgPolicy", "hostimgTarget", "identIdentCtx", "identIdentRequest", "identIdentRequestFsm", "identIdentRequestFsmStage", "identIdentRequestFsmTask", "identMetaSystem", "identMetaSystemFsm", "identMetaSystemFsmStage", "identMetaSystemFsmTask", "identMetaVerse", "identRequestEp", "identSysInfo", "imgprovPolicy", "imgprovTarget", "imgsecKey", "imgsecPolicy", "initiatorEp", "initiatorFcInitiatorEp", "initiatorGroupEp", "initiatorIScsiInitiatorEp", "initiatorInitiatorEp", "initiatorLunEp", "initiatorMemberEp", "initiatorRequestorEp", "initiatorRequestorGrpEp", "initiatorStoreEp", "initiatorUnitEp", "ipDnsSuffix", "ipIPv4Dns", "ipIPv4WinsServer", "ipIpV4Addr", "ipIpV4StaticAddr", "ipIpV4StaticTargetAddr", "ipServiceIf", "ippoolAddr", "ippoolBlock", "ippoolIpV6Addr", "ippoolIpV6Block", "ippoolIpV6Pooled", "ippoolPool", "ippoolPoolable", "ippoolPooled", "ippoolUniverse", "iqnpoolAbsBlock", "iqnpoolAddr", "iqnpoolBlock", "iqnpoolFormat", "iqnpoolPool", "iqnpoolPoolable", "iqnpoolPooled", "iqnpoolTransportBlock", "iqnpoolUniverse", "iscsiAuthProfile", "licenseCapProvider", "licenseContents", "licenseDownloader", "licenseDownloaderFsm", "licenseDownloaderFsmStage", "licenseDownloaderFsmTask", "licenseEp", "licenseFeature", "licenseFeatureCapProvider", "licenseFeatureLine", "licenseFile", "licenseFileFsm", "licenseFileFsmStage", "licenseFileFsmTask", "licenseInstance", "licenseInstanceFsm", "licenseInstanceFsmStage", "licenseInstanceFsmTask", "licenseProp", "licenseServerHostId", "licenseSource", "licenseSourceFile", "licenseTarget", "lldpAcquired", "lsAgentPolicy", "lsBinding", "lsComputeBinding", "lsFcLocale", "lsFcZone", "lsFcZoneGroup", "lsFcZoneMember", "lsIdentityInfo", "lsIssues", "lsPower", "lsRequirement", "lsServer", "lsServerAssocCtx", "lsServerExtension", "lsServerFsm", "lsServerFsmStage", "lsServerFsmTask", "lsTier", "lsUuidHistory", "lsVConAssign", "lsVersionBeh", "lsZoneInitiatorMember", "lsZoneTargetMember", "lsbootADef", "lsbootBootSecurity", "lsbootCategory", "lsbootDef", "lsbootDefaultLocalImage", "lsbootEFIShell", "lsbootEmbeddedLocalDiskImage", "lsbootEmbeddedLocalDiskImagePath", "lsbootEmbeddedLocalLunImage", "lsbootIScsi", "lsbootIScsiImagePath", "lsbootImage", "lsbootImagePath", "lsbootItem", "lsbootLan", "lsbootLanImagePath", "lsbootLocalDiskImage", "lsbootLocalDiskImagePath", "lsbootLocalHddImage", "lsbootLocalImage", "lsbootLocalLunImagePath", "lsbootLocalMediaItem", "lsbootLocalStorage", "lsbootNvme", "lsbootNvmeDevice", "lsbootNvmeDiskSsd", "lsbootNvmePciSsd", "lsbootPolicy", "lsbootRemoteImage", "lsbootSan", "lsbootSanCatSanImage", "lsbootSanCatSanImagePath", "lsbootSanImage", "lsbootSanImagePath", "lsbootStorage", "lsbootUEFIBootParam", "lsbootUsbExternalImage", "lsbootUsbFlashStorageImage", "lsbootUsbInternalImage", "lsbootVirtualMedia", "lsmaintAck", "lsmaintMaintPolicy", "lstorageASlot", "lstorageControllerDef", "lstorageControllerModeConfig", "lstorageControllerQualifier", "lstorageControllerRef", "lstorageDasScsiLun", "lstorageDiskGroupConfig", "lstorageDiskGroupConfigDef", "lstorageDiskGroupConfigPolicy", "lstorageDiskGroupQualifier", "lstorageDiskSlot", "lstorageDiskZoningConfig", "lstorageDiskZoningConfigDef", "lstorageDiskZoningPolicy", "lstorageDriveSecurity", "lstorageItem", "lstorageLocal", "lstorageLocalConfig", "lstorageLocalDef", "lstorageLocalDiskConfigRef", "lstorageLocalDiskRef", "lstorageLogin", "lstorageLunSetConfig", "lstorageLunSetDiskSlot", "lstorageProfile", "lstorageProfileBase", "lstorageProfileBinding", "lstorageProfileBindingBase", "lstorageProfileDef", "lstorageRemote", "lstorageRemoteConfig", "lstorageRemoteDef", "lstorageSasExpanderConfigPolicy", "lstorageScsiLun", "lstorageSecurity", "lstorageVirtualDriveDef", "macpoolAddr", "macpoolBlock", "macpoolFormat", "macpoolPool", "macpoolPoolable", "macpoolPooled", "macpoolUniverse", "memoryAUnit", "memoryArray", "memoryArrayEnvStats", "memoryArrayEnvStatsHist", "memoryBufferUnit", "memoryBufferUnitEnvStats", "memoryBufferUnitEnvStatsHist", "memoryErrorStats", "memoryPersistentMemoryANamespace", "memoryPersistentMemoryConfigResult", "memoryPersistentMemoryConfiguration", "memoryPersistentMemoryGoal", "memoryPersistentMemoryLocalSecurity", "memoryPersistentMemoryLogicalNamespace", "memoryPersistentMemoryNamespace", "memoryPersistentMemoryNamespaceConfigResult", "memoryPersistentMemoryPolicy", "memoryPersistentMemoryRegion", "memoryPersistentMemorySecurity", "memoryPersistentMemoryUnit", "memoryQual", "memoryRuntime", "memoryRuntimeHist", "memoryUnit", "memoryUnitEnvStats", "memoryUnitEnvStatsHist", "mgmtASecureBoot", "mgmtAbstractIf", "mgmtAccessPolicy", "mgmtAccessPolicyItem", "mgmtAccessPort", "mgmtBackup", "mgmtBackupExportExtPolicy", "mgmtBackupFsm", "mgmtBackupFsmStage", "mgmtBackupFsmTask", "mgmtBackupPolicy", "mgmtBackupPolicyConfig", "mgmtBackupPolicyFsm", "mgmtBackupPolicyFsmStage", "mgmtCfgExportPolicy", "mgmtCfgExportPolicyFsm", "mgmtCfgExportPolicyFsmStage", "mgmtCimcInterface", "mgmtCimcSecureBoot", "mgmtCmcSecureBoot", "mgmtConnection", "mgmtController", "mgmtControllerFsm", "mgmtControllerFsmStage", "mgmtControllerFsmTask", "mgmtDbState", "mgmtEntity", "mgmtExportPolicy", "mgmtExportPolicyFsm", "mgmtExportPolicyFsmStage", "mgmtExportPolicyFsmTask", "mgmtHealthAttr", "mgmtHealthStatus", "mgmtIPv6Addr", "mgmtIPv6IfAddr", "mgmtIPv6IfAddrFsm", "mgmtIPv6IfAddrFsmStage", "mgmtIPv6IfAddrFsmTask", "mgmtIPv6IfConfig", "mgmtIf", "mgmtIfFsm", "mgmtIfFsmStage", "mgmtIfFsmTask", "mgmtImporter", "mgmtImporterFsm", "mgmtImporterFsmStage", "mgmtImporterFsmTask", "mgmtInbandProfile", "mgmtIntAuthPolicy", "mgmtInterface", "mgmtKmip", "mgmtKmipCertPolicy", "mgmtKvmCertificate", "mgmtLeaderEntity", "mgmtPmonEntry", "mgmtProfDerivedInterface", "mgmtSecurity", "mgmtSpdmCertificate", "mgmtSpdmCertificateData", "mgmtSpdmCertificateInventory", "mgmtSpdmCertificatePolicy", "mgmtSwPersonalities", "mgmtSwPersonalitiesInventory", "mgmtSwPersonality", "mgmtUsbNicMgmtIf", "mgmtVnet", "moAbstractCfgKv", "moAbstractInvKv", "moAbstractKv", "moInvKv", "moIpAddrKv", "moIpV4AddrKv", "moIpV6AddrKv", "moKv", "moKvCfgHolder", "moKvInvHolder", "moTopProps", "moVnicKv", "morefFruRef", "morefImportRoot", "morefImportRootFsm", "morefImportRootFsmStage", "morefImportRootFsmTask", "morefProp", "morefRef", "namingNamedIdentifiedObject", "namingNamedObject", "networkALanNeighborEntry", "networkANeighborEntry", "networkCIoEp", "networkConn", "networkDomainEp", "networkElement", "networkEp", "networkIfEp", "networkIfStats", "networkLanNeighborEntry", "networkLanNeighbors", "networkLimit", "networkLldpNeighborEntry", "networkLldpNeighbors", "networkOperLevel", "networkPIoEp", "networkPhysEp", "networkSanNeighborEntry", "networkSanNeighbors", "networkVnetEp", "networkruleDefinition", "networkruleItem", "networkruleRequirement", "nfsEp", "nfsMountDef", "nfsMountDefFsm", "nfsMountDefFsmStage", "nfsMountDefFsmTask", "nfsMountInst", "nfsMountInstFsm", "nfsMountInstFsmStage", "nfsMountInstFsmTask", "nwctrlDefinition", "observeFilter", "observeObserved", "observeObservedCont", "observeObservedFsm", "observeObservedFsmStage", "observeObservedFsmTask", "orgOrg", "orgSourceMask", "osARPLinkMonitoringPolicy", "osARPTarget", "osAgent", "osEthBondIntf", "osEthBondMode", "osEthBondModeActiveBackup", "osEthBondModeBalancedALB", "osEthBondModeBalancedRR", "osEthBondModeBalancedTLB", "osEthBondModeBalancedXOR", "osEthBondModeBroadcast", "osEthBondModeLB", "osEthIntf", "osInstance", "osIntf", "osLinkMonitoringPolicy", "osMiiLinkMonitoringPolicy", "osPrimarySlave", "pciCard", "pciEquipSlot", "pciLink", "pciSwitch", "pciUnit", "pfcWatchDog", "pfcWatchDogFsm", "pfcWatchDogFsmStage", "pfcWatchDogFsmTask", "pkiCertReq", "pkiDefinition", "pkiEp", "pkiEpFsm", "pkiEpFsmStage", "pkiEpFsmTask", "pkiItem", "pkiKeyRing", "pkiTP", "policyADestEp", "policyBinding", "policyCentraleSync", "policyChildClass", "policyCommunication", "policyConfigBackup", "policyConfigError", "policyContext", "policyControl", "policyControlEp", "policyControlEpFsm", "policyControlEpFsmStage", "policyControlEpFsmTask", "policyControlled", "policyControlledInstance", "policyControlledType", "policyControlledTypeFsm", "policyControlledTypeFsmStage", "policyControlledTypeFsmTask", "policyDateTime", "policyDefinition", "policyDestClass", "policyDestEp", "policyDigest", "policyDiscovery", "policyDns", "policyElement", "policyEquipment", "policyFault", "policyHolder", "policyIdResolvePolicy", "policyInfraFirmware", "policyItem", "policyLocalMap", "policyMEp", "policyMonitoring", "policyObject", "policyPolicyDestClass", "policyPolicyEp", "policyPolicyRequestor", "policyPolicyScope", "policyPolicyScopeCont", "policyPolicyScopeContFsm", "policyPolicyScopeContFsmStage", "policyPolicyScopeContFsmTask", "policyPolicyScopeContext", "policyPolicyScopeFsm", "policyPolicyScopeFsmStage", "policyPolicyScopeFsmTask", "policyPortConfig", "policyPowerMgmt", "policyPsu", "policyRefReq", "policyRequestor", "policyRequestorFsm", "policyRequestorFsmStage", "policyRequestorFsmTask", "policyScope", "policySecurity", "policySourceApp", "policyStorageAutoConfig", "policySystemEp", "poolElement", "poolPool", "poolPoolMember", "poolPoolable", "poolUniverse", "portDomainEp", "portGroup", "portIntFIo", "portPIo", "portPIoFsm", "portPIoFsmStage", "portPIoFsmTask", "portPhysSwitchIo", "portServerIntFIo", "portSubGroup", "portSwitchIntFIo", "portTrustMode", "powerABudget", "powerAGroup", "powerBudget", "powerChassisMember", "powerEp", "powerFIMember", "powerFexMember", "powerGroup", "powerGroupAdditionPolicy", "powerGroupMember", "powerGroupQual", "powerGroupStats", "powerGroupStatsHist", "powerMgmtPolicy", "powerPlacement", "powerPolicy", "powerPrioWght", "powerProfiledPower", "powerRackUnitMember", "procDoer", "procManager", "procProcCounts", "procProcs", "procPrt", "procPrtCounts", "procStimulusCounts", "procSvc", "procTxCounts", "processorCacheMemStats", "processorComponent", "processorCore", "processorEnvStats", "processorEnvStatsHist", "processorErrorStats", "processorExecStats", "processorIOStats", "processorMiscStats", "processorPCIBusStats", "processorPMUStats", "processorQual", "processorRuntime", "processorRuntimeHist", "processorSecurityStats", "processorThread", "processorUnit", "processorUnitAssocCtx", "qosDefinition", "qosItem", "qosclassDefinition", "qosclassDefinitionFsm", "qosclassDefinitionFsmStage", "qosclassDefinitionFsmTask", "qosclassEth", "qosclassEthBE", "qosclassEthClassified", "qosclassFc", "qosclassItem", "qosclassSlowDrain", "qosclassSlowDrainFsm", "qosclassSlowDrainFsmStage", "qosclassSlowDrainFsmTask", "queryresultDependency", "queryresultItem", "queryresultUsage", "ruleDefinition", "ruleItem", "ruleRequirement", "ruleSizeRequirement", "securityUnit", "sesDiskSlotEp", "sesEnclosure", "solConfig", "solDef", "solIf", "solPolicy", "statsCollectionPolicy", "statsCollectionPolicyFsm", "statsCollectionPolicyFsmStage", "statsCollectionPolicyFsmTask", "statsCurr", "statsHist", "statsHolder", "statsItem", "statsThr32Definition", "statsThr32Value", "statsThr64Definition", "statsThr64Value", "statsThrFloatDefinition", "statsThrFloatValue", "statsThresholdClass", "statsThresholdDefinition", "statsThresholdPolicy", "statsThresholdValue", "storageADef", "storageADiskEp", "storageADiskSlotEp", "storageALun", "storageALunRefBase", "storageASlot", "storageAuthKey", "storageConnectionDef", "storageConnectionPolicy", "storageController", "storageControllerBase", "storageControllerEp", "storageControllerRef", "storageControllerReference", "storageDevice", "storageDiskEnvStats", "storageDiskEnvStatsHist", "storageDomainEp", "storageDrive", "storageEmbeddedStorage", "storageEnclosure", "storageEnclosureCap", "storageEnclosureDiskSlotEp", "storageEnclosureFsm", "storageEnclosureFsmStage", "storageEnclosureFsmTask", "storageEnclosureLocalDiskConfig", "storageEp", "storageEpUser", "storageEtherIf", "storageFcIf", "storageFcTargetEp", "storageFcTargetIf", "storageFlexFlashCard", "storageFlexFlashController", "storageFlexFlashControllerFsm", "storageFlexFlashControllerFsmStage", "storageFlexFlashControllerFsmTask", "storageFlexFlashDrive", "storageFlexFlashVirtualDrive", "storageHddMotherBoardTempStats", "storageHddMotherBoardTempStatsHist", "storageIScsiTargetIf", "storageIniGroup", "storageInitiator", "storageItem", "storageL2If", "storageLocalDisk", "storageLocalDiskBase", "storageLocalDiskConfig", "storageLocalDiskConfigDef", "storageLocalDiskConfigPolicy", "storageLocalDiskEp", "storageLocalDiskFsm", "storageLocalDiskFsmStage", "storageLocalDiskFsmTask", "storageLocalDiskPartition", "storageLocalDiskSlotEp", "storageLocalLun", "storageLogical", "storageLunDisk", "storageLunResourceSelectionLog", "storageMezzFlashLife", "storageMiniStorage", "storageNodeEp", "storageNvmeStats", "storageNvmeStatsHist", "storageNvmeStorage", "storageNvmeSwitch", "storageOnboardDevice", "storageOperation", "storagePhysical", "storageQual", "storageRaidBattery", "storageSasExpander", "storageSasLinkDescriptor", "storageSasPhyLink", "storageSasPort", "storageSasPortDescriptor", "storageSasUpLink", "storageScsiLunRef", "storageSsdHealthStats", "storageSsdHealthStatsHist", "storageSystem", "storageSystemFsm", "storageSystemFsmStage", "storageSystemFsmTask", "storageTarget", "storageTargetIf", "storageTransportIf", "storageTransportableFlashModule", "storageUnit", "storageVDMemberEp", "storageVirtualDrive", "storageVirtualDriveContainer", "storageVirtualDriveEp", "storageVirtualDriveRef", "storageVsanRef", "swAccessDomain", "swAccessDomainFsm", "swAccessDomainFsmStage", "swAccessDomainFsmTask", "swAccessEp", "swBorderDomain", "swBorderEp", "swBorderPc", "swCIoEp", "swCardEnvStats", "swCardEnvStatsHist", "swCmclan", "swDomain", "swEnvStats", "swEnvStatsHist", "swEstcEp", "swEthEstcEp", "swEthEstcPc", "swEthFlowMonSession", "swEthLanBorder", "swEthLanBorderFsm", "swEthLanBorderFsmStage", "swEthLanBorderFsmTask", "swEthLanEp", "swEthLanFlowMon", "swEthLanFlowMonExporter", "swEthLanFlowMonFsm", "swEthLanFlowMonFsmStage", "swEthLanFlowMonFsmTask", "swEthLanFlowMonitor", "swEthLanFlowRecordDef", "swEthLanMon", "swEthLanPc", "swEthMon", "swEthMonDestEp", "swEthMonFsm", "swEthMonFsmStage", "swEthMonFsmTask", "swEthMonSrcEp", "swEthTargetEp", "swEtherPort", "swExtUtility", "swExtUtilityFsm", "swExtUtilityFsmStage", "swExtUtilityFsmTask", "swFabricZoneNs", "swFabricZoneNsOverride", "swFcEndpoint", "swFcEstcEp", "swFcMon", "swFcMonDestEp", "swFcMonFsm", "swFcMonFsmStage", "swFcMonFsmTask", "swFcMonSrcEp", "swFcSanBorder", "swFcSanBorderFsm", "swFcSanBorderFsmStage", "swFcSanBorderFsmTask", "swFcSanEp", "swFcSanMon", "swFcSanPc", "swFcServerZoneGroup", "swFcUserZone", "swFcUserZoneGroup", "swFcZone", "swFcZoneMember", "swFcZoneSet", "swFcoeEstcEp", "swFcoeSanEp", "swFcoeSanPc", "swFlowMonExporter", "swFlowMonitor", "swFlowRecordDef", "swIpRoute", "swLanBorder", "swLanEp", "swLanMon", "swLanPc", "swMon", "swMonDestEp", "swMonDomain", "swMonSrcEp", "swNFExporterRef", "swNetflowExporter", "swNetflowMonSession", "swNetflowMonitor", "swNetflowMonitorRef", "swNetflowRecordDef", "swPIoEp", "swPhys", "swPhysEtherEp", "swPhysFcEp", "swPhysFsm", "swPhysFsmStage", "swPhysFsmTask", "swPortBreakout", "swPortDiscover", "swPortDiscoverFsm", "swPortDiscoverFsmStage", "swPortDiscoverFsmTask", "swSanBorder", "swSanEp", "swSanMon", "swSanPc", "swSubGroup", "swSystemStats", "swSystemStatsHist", "swTargetEp", "swUlan", "swUtilityDomain", "swUtilityDomainFsm", "swUtilityDomainFsmStage", "swUtilityDomainFsmTask", "swVIFRef", "swVirtL3Intf", "swVlan", "swVlanGroup", "swVlanPortNs", "swVlanPortNsOverride", "swVlanRef", "swVsan", "swZoneInitiatorMember", "swZoneTargetMember", "swatAction", "swatCondition", "swatInjection", "swatResultstats", "swatTarget", "swatTrigger", "syntheticDirectory", "syntheticFile", "syntheticFileSystem", "syntheticFsObj", "syntheticFsObjFsm", "syntheticFsObjFsmStage", "syntheticFsObjFsmTask", "syntheticTime", "sysdebugAutoCoreFileExportTarget", "sysdebugAutoCoreFileExportTargetFsm", "sysdebugAutoCoreFileExportTargetFsmStage", "sysdebugAutoCoreFileExportTargetFsmTask", "sysdebugBackupBehavior", "sysdebugCore", "sysdebugCoreFileExportTarget", "sysdebugCoreFileRepository", "sysdebugCoreFsm", "sysdebugCoreFsmStage", "sysdebugCoreFsmTask", "sysdebugDiagnosticLog", "sysdebugDiagnosticLogRepository", "sysdebugEp", "sysdebugExporter", "sysdebugFile", "sysdebugLogBehavior", "sysdebugLogControlDestinationFile", "sysdebugLogControlDestinationSyslog", "sysdebugLogControlDomain", "sysdebugLogControlEp", "sysdebugLogControlEpFsm", "sysdebugLogControlEpFsmStage", "sysdebugLogControlEpFsmTask", "sysdebugLogControlModule", "sysdebugLogExportPolicy", "sysdebugLogExportPolicyFsm", "sysdebugLogExportPolicyFsmStage", "sysdebugLogExportPolicyFsmTask", "sysdebugLogExportStatus", "sysdebugMEpLog", "sysdebugMEpLogDef", "sysdebugMEpLogPolicy", "sysdebugManualCoreFileExportTarget", "sysdebugManualCoreFileExportTargetFsm", "sysdebugManualCoreFileExportTargetFsmStage", "sysdebugManualCoreFileExportTargetFsmTask", "sysdebugRepository", "sysdebugTechSupFileRepository", "sysdebugTechSupport", "sysdebugTechSupportCmdOpt", "sysdebugTechSupportFsm", "sysdebugTechSupportFsmStage", "sysdebugTechSupportFsmTask", "sysfileDigest", "sysfileEp", "sysfileExporter", "sysfileImporter", "sysfileInstance", "sysfileMutation", "sysfileMutationFsm", "sysfileMutationFsmStage", "sysfileMutationFsmTask", "sysfileRepository", "topInfoPolicy", "topInfoSyncPolicy", "topMetaInf", "topRoot", "topSysDefaults", "topSystem", "trigAbsWindow", "trigAck", "trigBaseAbsWindow", "trigBaseRecurrWindow", "trigBaseSched", "trigClientToken", "trigConfAck", "trigInst", "trigLocalAbsWindow", "trigLocalSched", "trigMeta", "trigRecurrWindow", "trigResAck", "trigSched", "trigSchedWindow", "trigTest", "trigToken", "trigTriggerable", "trigTriggered", "trigWindow", "unspecified", "uuidpoolAddr", "uuidpoolBlock", "uuidpoolFormat", "uuidpoolPool", "uuidpoolPoolable", "uuidpoolPooled", "uuidpoolUniverse", "versionApplication", "versionEp", "versionVersion", "vmAdaptor", "vmClientContainer", "vmComputeEp", "vmCont", "vmDC", "vmDCOrg", "vmDirCont", "vmEp", "vmHba", "vmHv", "vmInstance", "vmLifeCyclePolicy", "vmLifeCyclePolicyFsm", "vmLifeCyclePolicyFsmStage", "vmLifeCyclePolicyFsmTask", "vmNic", "vmOrg", "vmSwitch", "vmVif", "vmVirtual", "vmVlan", "vmVnicProfCl", "vmVnicProfInst", "vmVsan", "vnicABeh", "vnicAEtherIf", "vnicAFcIf", "vnicAGroup", "vnicAIpcIf", "vnicAScsiIf", "vnicBootIpPolicy", "vnicBootTarget", "vnicConPolicyRef", "vnicConReq", "vnicConnDef", "vnicConnection", "vnicDefBeh", "vnicDynamicCon", "vnicDynamicConPolicy", "vnicDynamicConPolicyRef", "vnicDynamicConReq", "vnicDynamicIdUniverse", "vnicDynamicProvider", "vnicDynamicProviderEp", "vnicEthConfig", "vnicEthLif", "vnicEther", "vnicEtherBase", "vnicEtherBaseIf", "vnicEtherIf", "vnicFc", "vnicFcBase", "vnicFcGroupDef", "vnicFcGroupTempl", "vnicFcIf", "vnicFcLif", "vnicFcNode", "vnicFcOEIf", "vnicIPIf", "vnicIPv4Dhcp", "vnicIPv4Dns", "vnicIPv4If", "vnicIPv4IscsiAddr", "vnicIPv4PooledIscsiAddr", "vnicIPv4StaticRoute", "vnicIPv6If", "vnicIScsi", "vnicIScsiAutoTargetIf", "vnicIScsiBase", "vnicIScsiBootParams", "vnicIScsiBootVnic", "vnicIScsiConfig", "vnicIScsiInitAutoConfigPolicy", "vnicIScsiLCP", "vnicIScsiNode", "vnicIScsiStaticTargetIf", "vnicIScsiTargetIf", "vnicIf", "vnicIfRole", "vnicInitiatorAutoConfigPolicy", "vnicInternalProfile", "vnicIpAddr", "vnicIpV4Addr", "vnicIpV4AddrConf", "vnicIpV4AddrExplConf", "vnicIpV4History", "vnicIpV4MgmtPooledAddr", "vnicIpV4PooledAddr", "vnicIpV4ProfDerivedAddr", "vnicIpV4StaticAddr", "vnicIpV6Addr", "vnicIpV6AddrConf", "vnicIpV6AddrExplConf", "vnicIpV6History", "vnicIpV6MgmtPooledAddr", "vnicIpV6StaticAddr", "vnicIpc", "vnicIpcIf", "vnicIqnHistory", "vnicL2If", "vnicL2Lif", "vnicL3If", "vnicLanConnPolicy", "vnicLanConnTempl", "vnicLifVlan", "vnicLifVsan", "vnicLun", "vnicMacHistory", "vnicNicConn", "vnicOProfileAlias", "vnicProfile", "vnicProfileAlias", "vnicProfileRef", "vnicProfileSet", "vnicProfileSetFsm", "vnicProfileSetFsmStage", "vnicProfileSetFsmTask", "vnicRackServerDiscoveryProfile", "vnicSanConnPolicy", "vnicSanConnTempl", "vnicScsi", "vnicScsiIf", "vnicTempl", "vnicUsnicConPolicy", "vnicUsnicConPolicyRef", "vnicUsnicConReq", "vnicVProfileAlias", "vnicVhbaBehPolicy", "vnicVlan", "vnicVmqConPolicy", "vnicVmqConPolicyRef", "vnicVmqConReq", "vnicVnic", "vnicVnicBehPolicy", "vnicWwnnHistory", "vnicWwpnHistory"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version212a, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "guid": MoPropertyMeta("guid", "guid", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version212a, MoPropertyMeta.NAMING, 0x10, None, None, None, [], []),
        "old_centrale_mo_dn": MoPropertyMeta("old_centrale_mo_dn", "oldCentraleMoDn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "ref_obj_status": MoPropertyMeta("ref_obj_status", "refObjStatus", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["created", "deleted", "intent-deletion", "modified"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version212a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "ucsm_mo_dn": MoPropertyMeta("ucsm_mo_dn", "ucsmMoDn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
    }

    prop_map = {
        "centraleMoDn": "centrale_mo_dn", 
        "changedMoClassId": "changed_mo_class_id", 
        "childAction": "child_action", 
        "dn": "dn", 
        "guid": "guid", 
        "id": "id", 
        "oldCentraleMoDn": "old_centrale_mo_dn", 
        "refObjStatus": "ref_obj_status", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "ucsmMoDn": "ucsm_mo_dn", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.centrale_mo_dn = None
        self.changed_mo_class_id = None
        self.child_action = None
        self.guid = None
        self.old_centrale_mo_dn = None
        self.ref_obj_status = None
        self.sacl = None
        self.status = None
        self.ucsm_mo_dn = None

        ManagedObject.__init__(self, "ChangeChangedObjectRef", parent_mo_or_dn, **kwargs)
